# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import sys
import typing
from importlib import import_module

if sys.getrecursionlimit() < 10000:
    sys.setrecursionlimit(10000)
if typing.TYPE_CHECKING:
    from .types import (
        AccountChangeActivityId,
        ActorModel,
        AddChapterResponseModel,
        AddKnowledgeBaseResponseModel,
        AddProjectRequest,
        AddProjectResponseModel,
        AddPronunciationDictionaryResponseModel,
        AddPronunciationDictionaryResponseModelPermissionOnResource,
        AddSharingVoiceRequest,
        AddVoiceIvcResponseModel,
        AddVoiceResponseModel,
        AddWorkspaceGroupMemberResponseModel,
        AddWorkspaceInviteResponseModel,
        AdditionalFormatResponseModel,
        AdditionalFormats,
        AdhocAgentConfigOverrideForTestRequestModel,
        Age,
        AgentBranchBasicInfo,
        AgentBranchResponse,
        AgentBranchSummary,
        AgentCallLimits,
        AgentConfig,
        AgentConfigApiModelWorkflowOverrideInput,
        AgentConfigApiModelWorkflowOverrideOutput,
        AgentConfigOverrideConfig,
        AgentConfigOverrideInput,
        AgentConfigOverrideOutput,
        AgentDefinitionSource,
        AgentDeploymentPercentageStrategy,
        AgentDeploymentRequest,
        AgentDeploymentRequestItem,
        AgentDeploymentResponse,
        AgentFailureResponseExample,
        AgentMetadata,
        AgentMetadataDbModel,
        AgentMetadataResponseModel,
        AgentPlatformSettingsRequestModel,
        AgentPlatformSettingsResponseModel,
        AgentResponsePayload,
        AgentSimulatedChatTestResponseModel,
        AgentSortBy,
        AgentSuccessfulResponseExample,
        AgentSummaryBatchSuccessfulResponseModel,
        AgentSummaryResponseModel,
        AgentTestEntityType,
        AgentTestFolderPathSegmentResponseModel,
        AgentTestingSettings,
        AgentTopicResponseModel,
        AgentTransfer,
        AgentTrustContext,
        AgentVersionMetadata,
        AgentVersionParents,
        AgentWorkflowRequestModel,
        AgentWorkflowRequestModelNodesValue,
        AgentWorkflowRequestModelNodesValue_End,
        AgentWorkflowRequestModelNodesValue_OverrideAgent,
        AgentWorkflowRequestModelNodesValue_PhoneNumber,
        AgentWorkflowRequestModelNodesValue_StandaloneAgent,
        AgentWorkflowRequestModelNodesValue_Start,
        AgentWorkflowRequestModelNodesValue_Tool,
        AgentWorkflowResponseModel,
        AgentWorkflowResponseModelNodesValue,
        AgentWorkflowResponseModelNodesValue_End,
        AgentWorkflowResponseModelNodesValue_OverrideAgent,
        AgentWorkflowResponseModelNodesValue_PhoneNumber,
        AgentWorkflowResponseModelNodesValue_StandaloneAgent,
        AgentWorkflowResponseModelNodesValue_Start,
        AgentWorkflowResponseModelNodesValue_Tool,
        AgentWorkspaceOverridesInput,
        AgentWorkspaceOverridesOutput,
        AlertingMonitorConfig,
        AlertingSettings,
        AlertingWebhookNotifier,
        Alignment,
        AllowedOutputFormats,
        AllowlistItem,
        AnalysisProperty,
        AnalysisPropertyConstantValue,
        AnalysisPropertyType,
        AnalysisScope,
        ApiIntegrationOAuth2AuthCodeResponse,
        ApiIntegrationOAuth2AuthCodeResponseScopeSeparator,
        ApiIntegrationOAuth2CustomAppResponse,
        ApiIntegrationOAuth2CustomAppResponseScopeSeparator,
        ApiIntegrationWebhookOverrides,
        ApiIntegrationWebhookOverridesRequestHeadersValue,
        ApiIntegrationWebhookOverridesSchemaOverridesValue,
        ApiIntegrationWebhookOverridesSchemaOverridesValue_Constant,
        ApiIntegrationWebhookOverridesSchemaOverridesValue_DynamicVariable,
        ApiIntegrationWebhookOverridesSchemaOverridesValue_Llm,
        ApiIntegrationWebhookOverridesSchemaOverridesValue_Omit,
        ApiIntegrationWebhookToolConfigInput,
        ApiIntegrationWebhookToolConfigOutput,
        ArrayJsonSchemaPropertyInput,
        ArrayJsonSchemaPropertyInputConstantValueItem,
        ArrayJsonSchemaPropertyInputItems,
        ArrayJsonSchemaPropertyOutput,
        ArrayJsonSchemaPropertyOutputConstantValueItem,
        ArrayJsonSchemaPropertyOutputItems,
        AsrConversationalConfig,
        AsrConversationalConfigOverride,
        AsrConversationalConfigOverrideConfig,
        AsrConversationalConfigWorkflowOverride,
        AsrInputFormat,
        AsrProvider,
        AsrQuality,
        AssetTranscription,
        AssetTranscriptionData,
        AssetTranscriptionStatus,
        AstAdditionOperatorNodeInput,
        AstAdditionOperatorNodeOutput,
        AstAndOperatorNodeInput,
        AstAndOperatorNodeOutput,
        AstBooleanNodeInput,
        AstBooleanNodeOutput,
        AstConditionalOperatorNodeInput,
        AstConditionalOperatorNodeOutput,
        AstDivisionOperatorNodeInput,
        AstDivisionOperatorNodeOutput,
        AstDynamicVariableNodeInput,
        AstDynamicVariableNodeOutput,
        AstEqualsOperatorNodeInput,
        AstEqualsOperatorNodeOutput,
        AstGreaterThanOperatorNodeInput,
        AstGreaterThanOperatorNodeOutput,
        AstGreaterThanOrEqualsOperatorNodeInput,
        AstGreaterThanOrEqualsOperatorNodeOutput,
        AstLessThanOperatorNodeInput,
        AstLessThanOperatorNodeOutput,
        AstLessThanOrEqualsOperatorNodeInput,
        AstLessThanOrEqualsOperatorNodeOutput,
        AstMultiplicationOperatorNodeInput,
        AstMultiplicationOperatorNodeOutput,
        AstNodeInput,
        AstNodeInput_AddOperator,
        AstNodeInput_AndOperator,
        AstNodeInput_BooleanLiteral,
        AstNodeInput_ConditionalOperator,
        AstNodeInput_DivOperator,
        AstNodeInput_DynamicVariable,
        AstNodeInput_EqOperator,
        AstNodeInput_GtOperator,
        AstNodeInput_GteOperator,
        AstNodeInput_Llm,
        AstNodeInput_LtOperator,
        AstNodeInput_LteOperator,
        AstNodeInput_MulOperator,
        AstNodeInput_NeqOperator,
        AstNodeInput_NullLiteral,
        AstNodeInput_NumberLiteral,
        AstNodeInput_OrOperator,
        AstNodeInput_StringLiteral,
        AstNodeInput_SubOperator,
        AstNodeOutput,
        AstNodeOutput_AddOperator,
        AstNodeOutput_AndOperator,
        AstNodeOutput_BooleanLiteral,
        AstNodeOutput_ConditionalOperator,
        AstNodeOutput_DivOperator,
        AstNodeOutput_DynamicVariable,
        AstNodeOutput_EqOperator,
        AstNodeOutput_GtOperator,
        AstNodeOutput_GteOperator,
        AstNodeOutput_Llm,
        AstNodeOutput_LtOperator,
        AstNodeOutput_LteOperator,
        AstNodeOutput_MulOperator,
        AstNodeOutput_NeqOperator,
        AstNodeOutput_NullLiteral,
        AstNodeOutput_NumberLiteral,
        AstNodeOutput_OrOperator,
        AstNodeOutput_StringLiteral,
        AstNodeOutput_SubOperator,
        AstNotEqualsOperatorNodeInput,
        AstNotEqualsOperatorNodeOutput,
        AstNullNodeInput,
        AstNullNodeOutput,
        AstNumberNodeInput,
        AstNumberNodeOutput,
        AstOrOperatorNodeInput,
        AstOrOperatorNodeOutput,
        AstStringNodeInput,
        AstStringNodeOutput,
        AstSubtractionOperatorNodeInput,
        AstSubtractionOperatorNodeOutput,
        AstllmNodeInput,
        AstllmNodeInputPrompt,
        AstllmNodeInputValueSchema,
        AstllmNodeOutput,
        AsyncConversationMetadata,
        AsyncConversationMetadataDeliveryStatus,
        AttachedTestModel,
        AudioAnalysis,
        AudioAnalysisResult,
        AudioAnalysisStatus,
        AudioFormatEnum,
        AudioIsolationHistoryItemResponseModel,
        AudioKeyMoment,
        AudioNativeCreateProjectResponseModel,
        AudioNativeEditContentResponseModel,
        AudioNativeProjectSettingsResponseModel,
        AudioNativeProjectSettingsResponseModelStatus,
        AudioOutput,
        AudioOutputMulti,
        AudioRefChunk,
        AudioSegment,
        AudioWithTimestampsAndVoiceSegmentsResponseModel,
        AudioWithTimestampsResponse,
        AuthConnectionDependencies,
        AuthConnectionDependenciesMcpServersItem,
        AuthConnectionDependenciesMcpServersItem_Available,
        AuthConnectionDependenciesMcpServersItem_Unknown,
        AuthConnectionDependenciesToolsItem,
        AuthConnectionDependenciesToolsItem_Available,
        AuthConnectionDependenciesToolsItem_Unknown,
        AuthConnectionLocator,
        AuthSettings,
        AuthenticationActivityId,
        AuthorizationMethod,
        AutoSyncInfo,
        BackgroundSoundConfig,
        BackgroundSoundConfigWorkflowOverride,
        BackgroundSoundPresetId,
        BackgroundSoundSourceType,
        BackupLlmDefault,
        BackupLlmDisabled,
        BackupLlmOverride,
        BadRequestErrorBody,
        BaseTurnConfig,
        BasicAuthResponse,
        BatchCallDetailedResponse,
        BatchCallRecipientStatus,
        BatchCallResponse,
        BatchCallStatus,
        BatchCallWhatsAppParams,
        BatchFailureResponseModel,
        BearerAuthResponse,
        BehaviorOverride,
        BillingPeriod,
        BranchProtectionStatus,
        BreakdownTypes,
        BucketingStatus,
        BuiltInToolsInput,
        BuiltInToolsOutput,
        BuiltInToolsWorkflowOverrideInput,
        BuiltInToolsWorkflowOverrideOutput,
        CancelCalendarEventParams,
        CancelGroupSessionForAllParams,
        CancelGroupSessionRegistrationParams,
        CanvasPlacement,
        CaptionStyleCharacterAnimationModel,
        CaptionStyleCharacterAnimationModelEnterType,
        CaptionStyleCharacterAnimationModelExitType,
        CaptionStyleHorizontalPlacementModel,
        CaptionStyleHorizontalPlacementModelAlign,
        CaptionStyleModel,
        CaptionStyleModelTextAlign,
        CaptionStyleModelTextBlendMode,
        CaptionStyleModelTextStyle,
        CaptionStyleModelTextTransform,
        CaptionStyleModelTextWeight,
        CaptionStyleSectionAnimationModel,
        CaptionStyleSectionAnimationModelEnterType,
        CaptionStyleSectionAnimationModelExitType,
        CaptionStyleTemplateModel,
        CaptionStyleVerticalPlacementModel,
        CaptionStyleVerticalPlacementModelAlign,
        CaptionStyleWordAnimationModel,
        CaptionStyleWordAnimationModelEnterType,
        CaptionStyleWordAnimationModelExitType,
        ChapterContentBlockExtendableNodeResponseModel,
        ChapterContentBlockInputModel,
        ChapterContentBlockInputModelSubType,
        ChapterContentBlockResponseModel,
        ChapterContentBlockResponseModelNodesItem,
        ChapterContentBlockResponseModelNodesItem_Other,
        ChapterContentBlockResponseModelNodesItem_TtsNode,
        ChapterContentBlockTtsNodeResponseModel,
        ChapterContentInputModel,
        ChapterContentParagraphTtsNodeInputModel,
        ChapterContentResponseModel,
        ChapterResponse,
        ChapterSnapshotExtendedResponseModel,
        ChapterSnapshotResponse,
        ChapterSnapshotsResponse,
        ChapterState,
        ChapterStatisticsResponse,
        ChapterWithContentResponseModel,
        ChapterWithContentResponseModelState,
        CharacterAlignmentModel,
        CharacterAlignmentResponseModel,
        CharacterRefreshPeriod,
        CharacterUsageResponse,
        ChatSourceMedium,
        CheckServiceAvailabilityParams,
        ClientEvent,
        ClientToolConfigInput,
        ClientToolConfigOutput,
        ClipAnimation,
        ClipAnimationEnterEffect,
        ClipAnimationExitEffect,
        CloseConnection,
        CloseContext,
        ClosePayload,
        CloseSocket,
        ColumnFilter,
        ColumnFilterOperation,
        ColumnFilterValuesItem,
        ColumnUnit,
        CommittedTranscriptPayload,
        CommittedTranscriptWithTimestampsPayload,
        CompositionPlan,
        CompositionPlanChunksItem,
        ConfigEntityType,
        ConstantSchemaOverride,
        ConstantSchemaOverrideConstantValue,
        ConstantSchemaOverrideConstantValueFourItem,
        ContentConfig,
        ContentGuardrailInput,
        ContentGuardrailInputTriggerAction,
        ContentGuardrailInputTriggerAction_EndCall,
        ContentGuardrailInputTriggerAction_Retry,
        ContentGuardrailOutput,
        ContentGuardrailOutputTriggerAction,
        ContentGuardrailOutputTriggerAction_EndCall,
        ContentGuardrailOutputTriggerAction_Retry,
        ContentThresholdGuardrail,
        ContentThresholdGuardrailThreshold,
        ContextualUpdateInfo,
        Contributor,
        ConvAiDynamicVariable,
        ConvAiEnvVarLocator,
        ConvAiFileUploadResponseModel,
        ConvAiSecretLocator,
        ConvAiStoredSecretDependencies,
        ConvAiStoredSecretDependenciesAgentsItem,
        ConvAiStoredSecretDependenciesAgentsItem_Available,
        ConvAiStoredSecretDependenciesAgentsItem_Unknown,
        ConvAiStoredSecretDependenciesMcpServersItem,
        ConvAiStoredSecretDependenciesMcpServersItem_Available,
        ConvAiStoredSecretDependenciesMcpServersItem_Unknown,
        ConvAiStoredSecretDependenciesToolsItem,
        ConvAiStoredSecretDependenciesToolsItem_Available,
        ConvAiStoredSecretDependenciesToolsItem_Unknown,
        ConvAiUserSecretDbModel,
        ConvAiWebhooks,
        ConvAiWorkspaceStoredSecretConfig,
        ConversationAsrUsageModel,
        ConversationChargingCommonModel,
        ConversationConfigClientOverrideConfigInput,
        ConversationConfigClientOverrideConfigOutput,
        ConversationConfigClientOverrideInput,
        ConversationConfigClientOverrideOutput,
        ConversationConfigInput,
        ConversationConfigOutput,
        ConversationConfigOverride,
        ConversationConfigOverrideConfig,
        ConversationConfigWorkflowOverrideInput,
        ConversationConfigWorkflowOverrideOutput,
        ConversationDeletionSettings,
        ConversationFeedbackType,
        ConversationHistoryAnalysisCommonModel,
        ConversationHistoryBatchCallModel,
        ConversationHistoryElevenAssistantCommonModel,
        ConversationHistoryErrorCommonModel,
        ConversationHistoryEvaluationCriteriaResultCommonModel,
        ConversationHistoryExotelPhoneCallModel,
        ConversationHistoryFeedbackCommonModel,
        ConversationHistoryMetadataCommonModel,
        ConversationHistoryMetadataCommonModelPhoneCall,
        ConversationHistoryMetadataCommonModelPhoneCall_Exotel,
        ConversationHistoryMetadataCommonModelPhoneCall_SipTrunking,
        ConversationHistoryMetadataCommonModelPhoneCall_Twilio,
        ConversationHistoryMultivoiceMessageModel,
        ConversationHistoryMultivoiceMessagePartModel,
        ConversationHistoryRagUsageCommonModel,
        ConversationHistoryRedactionConfig,
        ConversationHistorySipTrunkingPhoneCallModel,
        ConversationHistoryTranscriptApiIntegrationWebhookToolsResultCommonModelInput,
        ConversationHistoryTranscriptApiIntegrationWebhookToolsResultCommonModelOutput,
        ConversationHistoryTranscriptCommonModelInput,
        ConversationHistoryTranscriptCommonModelInputRole,
        ConversationHistoryTranscriptCommonModelInputToolResultsItem,
        ConversationHistoryTranscriptCommonModelOutput,
        ConversationHistoryTranscriptCommonModelOutputRole,
        ConversationHistoryTranscriptCommonModelOutputToolResultsItem,
        ConversationHistoryTranscriptFileInputResponseModel,
        ConversationHistoryTranscriptOtherToolsResultCommonModel,
        ConversationHistoryTranscriptOtherToolsResultCommonModelType,
        ConversationHistoryTranscriptResponseModel,
        ConversationHistoryTranscriptResponseModelRole,
        ConversationHistoryTranscriptResponseModelToolResultsItem,
        ConversationHistoryTranscriptSystemToolResultCommonModelInput,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_EndCallSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_KnowledgeBaseRagSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_LanguageDetectionSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_PlayDtmfError,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_PlayDtmfSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_SkipTurnSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TestingToolResult,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToAgentError,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToAgentSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberError,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberExotelSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberSipSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberTwilioSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_VoicemailDetectionSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutput,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_EndCallSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_KnowledgeBaseRagSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_LanguageDetectionSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_PlayDtmfError,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_PlayDtmfSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_SkipTurnSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TestingToolResult,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToAgentError,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToAgentSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberError,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberExotelSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberSipSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberTwilioSuccess,
        ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_VoicemailDetectionSuccess,
        ConversationHistoryTranscriptToolCallApiIntegrationWebhookDetailsInput,
        ConversationHistoryTranscriptToolCallApiIntegrationWebhookDetailsOutput,
        ConversationHistoryTranscriptToolCallClientDetails,
        ConversationHistoryTranscriptToolCallCommonModelInput,
        ConversationHistoryTranscriptToolCallCommonModelInputToolDetails,
        ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_ApiIntegrationWebhook,
        ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_Client,
        ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_Mcp,
        ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_Webhook,
        ConversationHistoryTranscriptToolCallCommonModelOutput,
        ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails,
        ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_ApiIntegrationWebhook,
        ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_Client,
        ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_Mcp,
        ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_Webhook,
        ConversationHistoryTranscriptToolCallMcpDetails,
        ConversationHistoryTranscriptToolCallWebhookDetails,
        ConversationHistoryTranscriptWorkflowToolsResultCommonModelInput,
        ConversationHistoryTranscriptWorkflowToolsResultCommonModelOutput,
        ConversationHistoryTwilioPhoneCallModel,
        ConversationInitiationClientDataConfigInput,
        ConversationInitiationClientDataConfigOutput,
        ConversationInitiationClientDataInternal,
        ConversationInitiationClientDataRequestInput,
        ConversationInitiationClientDataRequestOutput,
        ConversationInitiationClientDataWebhook,
        ConversationInitiationClientDataWebhookRequestHeadersValue,
        ConversationInitiationSource,
        ConversationInitiationSourceInfo,
        ConversationProduct,
        ConversationSentimentAnalysis,
        ConversationSentimentAnalysisOverallLabel,
        ConversationSignedUrlResponseModel,
        ConversationSimulationSpecification,
        ConversationSource,
        ConversationSummaryResponseModel,
        ConversationSummaryResponseModelStatus,
        ConversationTagResponseModel,
        ConversationTokenPurpose,
        ConversationTokenResponseModel,
        ConversationTtsUsageModel,
        ConversationTurnMetrics,
        ConversationUserResponseModel,
        ConversationVoiceRewardModel,
        ConversationVoiceUsageModel,
        ConversationalConfig,
        ConversationalConfigApiModelWorkflowOverrideInput,
        ConversationalConfigApiModelWorkflowOverrideOutput,
        ConvertChapterResponseModel,
        ConvertProjectResponseModel,
        CreateAgentBranchResponseModel,
        CreateAgentResponseModel,
        CreateAgentRuleParams,
        CreateAgentTestFolderResponseModel,
        CreateAgentTestResponseModel,
        CreateAssetParams,
        CreateAudioNativeProjectRequest,
        CreateAuthConnectionEnvironmentVariableRequest,
        CreateBasicAuthRequest,
        CreateBearerAuthRequest,
        CreateClientAppointmentParams,
        CreateClientInteractionParams,
        CreateClientParams,
        CreateCustomHeaderAuthRequest,
        CreateExotelPhoneNumberRequest,
        CreateHolidayParams,
        CreateLocationParams,
        CreateMtlsAuthRequest,
        CreateOAuth2ClientCredsRequest,
        CreateOAuth2JwtRequest,
        CreateOAuth2JwtRequestAlgorithm,
        CreateOAuth2JwtRequestTokenResponseField,
        CreateOrderRequest,
        CreateOrderResponse,
        CreatePhoneNumberResponseModel,
        CreatePreviouslyGeneratedVoiceRequest,
        CreatePrivateKeyJwtRequest,
        CreatePrivateKeyJwtRequestAlgorithm,
        CreateProductParams,
        CreatePronunciationDictionaryResponseModel,
        CreateResponseUnitTestRequest,
        CreateSecretEnvironmentVariableRequest,
        CreateServiceParams,
        CreateSimulationTestRequest,
        CreateSipTrunkPhoneNumberRequest,
        CreateStaffParams,
        CreateStringEnvironmentVariableRequest,
        CreateToolCallUnitTestRequest,
        CreateTranscriptRequest,
        CreateTwilioPhoneNumberRequest,
        CueOptionsRequest,
        Currency,
        CustomGuardrailConfig,
        CustomGuardrailConfigModel,
        CustomGuardrailConfigTriggerAction,
        CustomGuardrailConfigTriggerAction_EndCall,
        CustomGuardrailConfigTriggerAction_Retry,
        CustomGuardrailInput,
        CustomGuardrailOutput,
        CustomGuardrailsConfigInput,
        CustomGuardrailsConfigOutput,
        CustomHeaderAuthResponse,
        CustomLlm,
        CustomLlmApiKey,
        CustomLlmAuthConnection,
        CustomLlmRequestHeadersValue,
        CustomLlmapiType,
        CustomSipHeader,
        CustomSipHeaderWithDynamicVariable,
        DashboardCallSuccessChartModel,
        DashboardCriteriaChartModel,
        DashboardDataCollectionChartModel,
        DataCollectionResultCommonModel,
        DefaultSharingGroupResponseModel,
        DefaultSharingGroupResponseModelPermissionLevel,
        DeleteAgentRuleParams,
        DeleteAssetParams,
        DeleteCalendarEventParams,
        DeleteChapterRequest,
        DeleteChapterResponseModel,
        DeleteClientInteractionParams,
        DeleteClientParams,
        DeleteDubbingResponseModel,
        DeleteGroupSessionParams,
        DeleteHistoryItemResponse,
        DeleteHolidayParams,
        DeleteLocationParams,
        DeleteProductParams,
        DeleteProjectRequest,
        DeleteProjectResponseModel,
        DeleteSampleResponse,
        DeleteServiceParams,
        DeleteStaffParams,
        DeleteVoiceResponseModel,
        DeleteVoiceSampleResponseModel,
        DeleteWorkspaceGroupMemberResponseModel,
        DeleteWorkspaceInviteResponseModel,
        DeleteWorkspaceWebhookResponseModel,
        DeliverableInfo,
        DependentAvailableAgentIdentifier,
        DependentAvailableAgentIdentifierAccessLevel,
        DependentAvailableMcpServerIdentifier,
        DependentAvailableMcpServerIdentifierAccessLevel,
        DependentAvailableToolIdentifier,
        DependentAvailableToolIdentifierAccessLevel,
        DependentBranchInfo,
        DependentIntegrationConnectionIdentifier,
        DependentPhoneNumberIdentifier,
        DependentUnknownAgentIdentifier,
        DependentUnknownMcpServerIdentifier,
        DependentUnknownToolIdentifier,
        DetailedMusicResponse,
        DetailedMusicResponseCompositionPlan,
        DetectedEntity,
        DeviceModel,
        DialogueInput,
        DialogueInputResponseModel,
        DialogueTextAlignment,
        DirectPublishingReadResponseModel,
        DirectPublishingReadResponseModelDisplayMode,
        DirectPublishingReadResponseModelGenreItem,
        DirectPublishingReadResponseModelPayoutType,
        DirectPublishingReadResponseModelTargetAudience,
        DiscountResponseModel,
        DoDubbingResponse,
        DocumentUsageModeEnum,
        DocxExportOptions,
        DtmfInputConfig,
        DubOrderItemRequest,
        DubbedSegment,
        DubbingMediaMetadata,
        DubbingMediaReference,
        DubbingMetadataPageResponseModel,
        DubbingMetadataResponse,
        DubbingRenderResponseModel,
        DubbingResource,
        DubbingTranscript,
        DubbingTranscriptCharacter,
        DubbingTranscriptResponseModel,
        DubbingTranscriptUtterance,
        DubbingTranscriptWord,
        DubbingTranscriptsResponseModel,
        DubbingTranscriptsResponseModelTranscriptFormat,
        DynamicVariableAssignment,
        DynamicVariableNestedValueTypeInput,
        DynamicVariableNestedValueTypeOutput,
        DynamicVariableSchemaOverride,
        DynamicVariableUpdateCommonModel,
        DynamicVariableValueTypeInput,
        DynamicVariableValueTypeOutput,
        DynamicVariablesConfigInput,
        DynamicVariablesConfigOutput,
        DynamicVariablesConfigWorkflowOverrideInput,
        DynamicVariablesConfigWorkflowOverrideOutput,
        Eagerness,
        EditChapterResponseModel,
        EditProjectResponseModel,
        EditVoiceResponseModel,
        EditVoiceSettingsRequest,
        EditVoiceSettingsResponseModel,
        EmbedVariant,
        EmbeddingModelEnum,
        EndCallToolConfig,
        EndCallToolResultModel,
        EndCallTriggerAction,
        EndProcedureToolConfigInput,
        EndProcedureToolConfigOutput,
        EndProcedureToolErrorStatus,
        EntityManagementActivityId,
        EntryBehavior,
        EnvironmentAuthConnectionLocator,
        EnvironmentVariableAuthConnectionValue,
        EnvironmentVariableAuthConnectionValueRequest,
        EnvironmentVariableResponse,
        EnvironmentVariableResponseType,
        EnvironmentVariableResponseValues,
        EnvironmentVariableSecretValue,
        EnvironmentVariableSecretValueRequest,
        EnvironmentVariablesListResponse,
        ErrorPayload,
        EvaluationSettingsInput,
        EvaluationSettingsOutput,
        EvaluationSuccessResult,
        ExactParameterEvaluationStrategy,
        ExotelApiSubdomain,
        ExotelOutboundCallResponse,
        ExportOptions,
        ExportOptions_Docx,
        ExportOptions_Html,
        ExportOptions_Pdf,
        ExportOptions_SegmentedJson,
        ExportOptions_Srt,
        ExportOptions_Txt,
        ExtendedSubscriptionResponseModelMaxCreditLimitExtension,
        ExtendedSubscriptionResponseModelPendingChange,
        ExternalFileSyncInfo,
        ExternalFolderSyncInfo,
        ExternalSyncType,
        FeatureStatusCommonModel,
        FeaturesUsageCommonModel,
        FeedbackItem,
        FileInputConfig,
        FileInputConfigWorkflowOverride,
        FinalOutput,
        FinalOutputMulti,
        FineTuningResponse,
        FineTuningResponseModelStateValue,
        FlushContext,
        FocusGuardrail,
        ForcedAlignmentCharacterResponseModel,
        ForcedAlignmentResponseModel,
        ForcedAlignmentWordResponseModel,
        Gender,
        GenerateVoiceRequest,
        GenerationChunkInput,
        GenerationChunkInputConditionStrength,
        GenerationChunkInputContextAdherence,
        GenerationChunkOutput,
        GenerationChunkOutputConditionStrength,
        GenerationChunkOutputContextAdherence,
        GenerationConfig,
        GenerationSourceContext,
        GenesysRegion,
        GetAgentEmbedResponseModel,
        GetAgentKnowledgebaseSizeResponseModel,
        GetAgentLinkResponseModel,
        GetAgentResponseModel,
        GetAgentResponseModelPhoneNumbersItem,
        GetAgentResponseModelPhoneNumbersItem_Exotel,
        GetAgentResponseModelPhoneNumbersItem_SipTrunk,
        GetAgentResponseModelPhoneNumbersItem_Twilio,
        GetAgentTestFolderResponseModel,
        GetAgentTopicsResponseModel,
        GetAgentsPageResponseModel,
        GetAnalyticsSummaryParams,
        GetAppointmentByConfirmationNumberParams,
        GetAudioIsolationHistoryResponseModel,
        GetAudioNativeProjectSettingsResponseModel,
        GetBookingPageSettingsParams,
        GetBookingSlugStatusParams,
        GetChapterRequest,
        GetChapterSnapshotsRequest,
        GetChaptersRequest,
        GetChaptersResponse,
        GetClientAppointmentsParams,
        GetClientByPhoneParams,
        GetConvAiDashboardSettingsResponseModel,
        GetConvAiDashboardSettingsResponseModelChartsItem,
        GetConvAiDashboardSettingsResponseModelChartsItem_CallSuccess,
        GetConvAiDashboardSettingsResponseModelChartsItem_Criteria,
        GetConvAiDashboardSettingsResponseModelChartsItem_DataCollection,
        GetConvAiSettingsResponseModel,
        GetConversationResponseModel,
        GetConversationResponseModelStatus,
        GetConversationTagsPageResponseModel,
        GetConversationUsersPageResponseModel,
        GetConversationsPageResponseModel,
        GetKnowledgeBaseDependentAgentsResponseModel,
        GetKnowledgeBaseDependentAgentsResponseModelAgentsItem,
        GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available,
        GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown,
        GetKnowledgeBaseFileResponseModel,
        GetKnowledgeBaseFolderResponseModel,
        GetKnowledgeBaseListResponseModel,
        GetKnowledgeBaseListResponseModelDocumentsItem,
        GetKnowledgeBaseListResponseModelDocumentsItem_File,
        GetKnowledgeBaseListResponseModelDocumentsItem_Folder,
        GetKnowledgeBaseListResponseModelDocumentsItem_Text,
        GetKnowledgeBaseListResponseModelDocumentsItem_Url,
        GetKnowledgeBaseSummaryFileResponseModel,
        GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem,
        GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available,
        GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown,
        GetKnowledgeBaseSummaryFolderResponseModel,
        GetKnowledgeBaseSummaryFolderResponseModelDependentAgentsItem,
        GetKnowledgeBaseSummaryFolderResponseModelDependentAgentsItem_Available,
        GetKnowledgeBaseSummaryFolderResponseModelDependentAgentsItem_Unknown,
        GetKnowledgeBaseSummaryTextResponseModel,
        GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem,
        GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Available,
        GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Unknown,
        GetKnowledgeBaseSummaryUrlResponseModel,
        GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem,
        GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available,
        GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown,
        GetKnowledgeBaseTextResponseModel,
        GetKnowledgeBaseUrlResponseModel,
        GetLibraryVoicesResponse,
        GetLiveCountResponse,
        GetOrCreateRagIndexRequestModel,
        GetPhoneNumberExotelResponseModel,
        GetPhoneNumberInboundSipTrunkConfigResponseModel,
        GetPhoneNumberOutboundSipTrunkConfigResponseModel,
        GetPhoneNumberResponse,
        GetPhoneNumberSipTrunkResponseModel,
        GetPhoneNumberTwilioResponseModel,
        GetProjectRequest,
        GetProjectsRequest,
        GetProjectsResponse,
        GetPronunciationDictionariesMetadataResponseModel,
        GetPronunciationDictionariesResponse,
        GetPronunciationDictionaryMetadataResponse,
        GetPronunciationDictionaryMetadataResponseModelPermissionOnResource,
        GetPronunciationDictionaryResponse,
        GetPronunciationDictionaryWithRulesResponseModel,
        GetPronunciationDictionaryWithRulesResponseModelPermissionOnResource,
        GetPronunciationDictionaryWithRulesResponseModelRulesItem,
        GetPronunciationDictionaryWithRulesResponseModelRulesItem_Alias,
        GetPronunciationDictionaryWithRulesResponseModelRulesItem_Phoneme,
        GetResponseUnitTestResponseModel,
        GetScheduleParams,
        GetSecretDependenciesResponseModel,
        GetSecretDependenciesResponseModelDependencies,
        GetSecretDependenciesResponseModelDependenciesOneItem,
        GetSecretDependenciesResponseModelDependenciesOneItem_Available,
        GetSecretDependenciesResponseModelDependenciesOneItem_Unknown,
        GetSecretDependenciesResponseModelDependenciesZeroItem,
        GetSecretDependenciesResponseModelDependenciesZeroItem_Available,
        GetSecretDependenciesResponseModelDependenciesZeroItem_Unknown,
        GetSimulationTestResponseModel,
        GetSipLogMessagesResponse,
        GetSpeechHistoryResponse,
        GetTestInvocationsPageResponseModel,
        GetTestSuiteInvocationResponseModel,
        GetTestsPageResponseModel,
        GetTestsSummariesByIdsResponseModel,
        GetToolCallUnitTestResponseModel,
        GetToolDependentAgentsResponseModel,
        GetToolDependentAgentsResponseModelAgentsItem,
        GetToolDependentAgentsResponseModelAgentsItem_Available,
        GetToolDependentAgentsResponseModelAgentsItem_Unknown,
        GetToolExecutionsPageResponseModel,
        GetVoicesResponse,
        GetVoicesV2Response,
        GetWhatsAppAccountResponse,
        GetWorkspaceSecretsResponseModel,
        GroupManagementActivityId,
        GuardrailExecutionMode,
        GuardrailsV1Input,
        GuardrailsV1Output,
        HistoryAlignmentResponseModel,
        HistoryAlignmentsResponseModel,
        HistoryItemResponse,
        HtmlExportOptions,
        HttpRequestModel,
        HttpValidationError,
        Icon,
        ImageAnalysis,
        ImageAnalysisResult,
        ImageAnalysisStatus,
        ImageAvatar,
        ImageSubject,
        InboundSipTrunkConfigRequestModel,
        InitPayload,
        InitialiseContext,
        InitializeConnection,
        InitializeConnectionMulti,
        InputAudioChunkPayload,
        IntegrationType,
        InteractionBudget,
        InvoiceResponse,
        InvoiceResponseModelPaymentIntentStatus,
        InvoiceResponseModelPaymentIntentStatussesItem,
        ItemId,
        KeepContextAlive,
        KnowledgeBaseContentSearchResponseModel,
        KnowledgeBaseContentSearchResult,
        KnowledgeBaseContentSearchResultDocument,
        KnowledgeBaseContentSearchResultDocument_File,
        KnowledgeBaseContentSearchResultDocument_Folder,
        KnowledgeBaseContentSearchResultDocument_Text,
        KnowledgeBaseContentSearchResultDocument_Url,
        KnowledgeBaseDependentType,
        KnowledgeBaseDocumentChunkResponseModel,
        KnowledgeBaseDocumentChunksResponseModel,
        KnowledgeBaseDocumentMetadataResponseModel,
        KnowledgeBaseDocumentType,
        KnowledgeBaseFolderPathSegmentResponseModel,
        KnowledgeBaseFolderPathSegmentSummaryResponseModel,
        KnowledgeBaseLocator,
        KnowledgeBaseRagToolConfig,
        KnowledgeBaseRagToolResultModel,
        KnowledgeBaseRagToolStatus,
        KnowledgeBaseSortBy,
        KnowledgeBaseSourceFileUrlResponseModel,
        KnowledgeBaseSummaryBatchSuccessfulResponseModel,
        KnowledgeBaseSummaryBatchSuccessfulResponseModelData,
        KnowledgeBaseSummaryBatchSuccessfulResponseModelData_File,
        KnowledgeBaseSummaryBatchSuccessfulResponseModelData_Folder,
        KnowledgeBaseSummaryBatchSuccessfulResponseModelData_Text,
        KnowledgeBaseSummaryBatchSuccessfulResponseModelData_Url,
        LanguageAddedResponse,
        LanguageDetectionToolConfig,
        LanguageDetectionToolResultModel,
        LanguageInfo,
        LanguagePairInfo,
        LanguagePresetInput,
        LanguagePresetOutput,
        LanguagePresetTranslation,
        LanguageResponse,
        LanguagesResponse,
        LanguagesResponse_Pair,
        LanguagesResponse_Single,
        LeaveMessageParams,
        LibraryVoiceResponse,
        LibraryVoiceResponseModelCategory,
        ListAgentRulesParams,
        ListAssetsParams,
        ListAuthConnectionsResponse,
        ListAuthConnectionsResponseAuthConnectionsItem,
        ListAuthConnectionsResponseAuthConnectionsItem_ApiIntegrationOauth2AuthCode,
        ListAuthConnectionsResponseAuthConnectionsItem_ApiIntegrationOauth2CustomApp,
        ListAuthConnectionsResponseAuthConnectionsItem_BasicAuth,
        ListAuthConnectionsResponseAuthConnectionsItem_BearerAuth,
        ListAuthConnectionsResponseAuthConnectionsItem_CustomHeaderAuth,
        ListAuthConnectionsResponseAuthConnectionsItem_Mtls,
        ListAuthConnectionsResponseAuthConnectionsItem_Oauth2ClientCredentials,
        ListAuthConnectionsResponseAuthConnectionsItem_Oauth2Jwt,
        ListAuthConnectionsResponseAuthConnectionsItem_PrivateKeyJwt,
        ListAuthConnectionsResponseAuthConnectionsItem_SlackBotAuth,
        ListAuthConnectionsResponseAuthConnectionsItem_UrlSecret,
        ListAuthConnectionsResponseAuthConnectionsItem_WhatsappAuth,
        ListCalendarEventsParams,
        ListClientInteractionsParams,
        ListClientsParams,
        ListCustomerFacingAgentsParams,
        ListGroupSessionsParams,
        ListHolidaysParams,
        ListLocationsParams,
        ListMcpToolsResponseModel,
        ListOrdersResponse,
        ListProductsParams,
        ListResponseAgentBranchSummary,
        ListResponseMeta,
        ListServicesParams,
        ListSpeechEnginesResponse,
        ListStaffParams,
        ListWhatsAppAccountsResponse,
        LiteralJsonSchemaProperty,
        LiteralJsonSchemaPropertyConstantValue,
        LiteralJsonSchemaPropertyType,
        LivekitStackType,
        Llm,
        LlmCategoryUsage,
        LlmDeprecationConfigModel,
        LlmDeprecationInfoModel,
        LlmInfoModelInput,
        LlmInfoModelOutput,
        LlmInputOutputTokensUsage,
        LlmListResponseModelInput,
        LlmListResponseModelOutput,
        LlmLiteralJsonSchemaProperty,
        LlmLiteralJsonSchemaPropertyType,
        LlmParameterEvaluationStrategy,
        LlmReasoningEffort,
        LlmSchemaOverride,
        LlmTokensCategoryUsage,
        LlmUsageCalculatorLlmResponseModel,
        LlmUsageCalculatorResponseModel,
        LlmUsageInput,
        LlmUsageOutput,
        LoadMemoryEntryToolErrorStatus,
        LoadableMemoryEntry,
        LockReason,
        ManualSource,
        ManualVerificationFileResponse,
        ManualVerificationResponse,
        MatchAnythingParameterEvaluationStrategy,
        McpApprovalPolicy,
        McpServerConfigInput,
        McpServerConfigInputAuthConnection,
        McpServerConfigInputRequestHeadersValue,
        McpServerConfigInputSecretToken,
        McpServerConfigInputUrl,
        McpServerConfigOutput,
        McpServerConfigOutputAuthConnection,
        McpServerConfigOutputRequestHeadersValue,
        McpServerConfigOutputSecretToken,
        McpServerConfigOutputUrl,
        McpServerMetadataResponseModel,
        McpServerResponseModel,
        McpServerResponseModelDependentAgentsItem,
        McpServerResponseModelDependentAgentsItem_Available,
        McpServerResponseModelDependentAgentsItem_Unknown,
        McpServerTransport,
        McpServersResponseModel,
        McpToolApprovalHash,
        McpToolApprovalPolicy,
        McpToolConfigOverrideInput,
        McpToolConfigOverrideInputInputOverridesValue,
        McpToolConfigOverrideInputInputOverridesValue_Constant,
        McpToolConfigOverrideInputInputOverridesValue_DynamicVariable,
        McpToolConfigOverrideInputInputOverridesValue_Llm,
        McpToolConfigOverrideInputInputOverridesValue_Omit,
        McpToolConfigOverrideOutput,
        McpToolConfigOverrideOutputInputOverridesValue,
        McpToolConfigOverrideOutputInputOverridesValue_Constant,
        McpToolConfigOverrideOutputInputOverridesValue_DynamicVariable,
        McpToolConfigOverrideOutputInputOverridesValue_Llm,
        McpToolConfigOverrideOutputInputOverridesValue_Omit,
        MediaCodec,
        MediaId,
        MemoryEntrySearchResult,
        MemoryEntrySearchResultSource,
        MessageSearchSortBy,
        MessagesSearchResponse,
        MessagesSearchResult,
        MetricRecord,
        MetricType,
        MockNoMatchBehavior,
        MockingStrategy,
        Model,
        ModelRatesResponseModel,
        ModelSettingsResponseModel,
        ModerationConfig,
        ModerationGuardrailInput,
        ModerationGuardrailOutput,
        MtlsAuthResponse,
        MultichannelSpeechToTextResponseModel,
        MultipartMusicResponse,
        MusicAllowedOutputFormats,
        MusicExploreSongSourceContext,
        MusicGenerationMode,
        MusicOnlyOutputFormats,
        MusicOutputFormat,
        MusicPrompt,
        MusicUploadResponse,
        MusicUploadResponseCompositionPlan,
        NonStreamingOutputFormats,
        NormalizedAlignment,
        OAuth2ClientCredsResponse,
        OAuth2JwtResponse,
        OAuth2JwtResponseAlgorithm,
        OAuth2JwtResponseTokenResponseField,
        OAuthConnectionStatus,
        ObjectJsonSchemaPropertyInput,
        ObjectJsonSchemaPropertyInputPropertiesValue,
        ObjectJsonSchemaPropertyOutput,
        ObjectJsonSchemaPropertyOutputPropertiesValue,
        OmitSchemaOverride,
        OpenAiAudioConfig,
        OpenAiAudioFormat,
        OpenAiAudioInputConfig,
        OpenAiAudioInputFormat,
        OpenAiAudioOutputConfig,
        OpenAiAudioOutputFormat,
        OpenAiFunctionTool,
        OpenAiSessionConfig,
        OpenAiSessionConfigMaxResponseOutputTokens,
        OpenAiSessionConfigToolChoice,
        OpenAiSessionConfigToolsItem,
        OpenAiSessionConfigToolsItem_Function,
        OpenAiSessionConfigToolsItem_Mcp,
        OpenAiToolChoiceFunction,
        OpenAiToolChoiceFunctionInner,
        OpenAiTurnDetection,
        OpenAimcpTool,
        OpenAimcpToolRequireApproval,
        OptInSmsReminderParams,
        OptOutSmsReminderParams,
        OrbAvatar,
        OrchestratorToolMockBehaviorConfig,
        OrderDeliverablesResponse,
        OrderId,
        OrderItemInfo,
        OrderItemKind,
        OrderItemRequestInput,
        OrderItemRequestInput_Dub,
        OrderItemRequestInput_Subtitles,
        OrderItemRequestOutput,
        OrderItemRequestOutput_Dub,
        OrderItemRequestOutput_Subtitles,
        OrderMediaResponse,
        OrderRequestState,
        OrderResponse,
        OrderState,
        OrderSummary,
        OutboundCallRecipient,
        OutboundCallRecipientResponseModel,
        OutboundSipTrunkConfigRequestModel,
        OutputFormat,
        PairedLanguagesResponse,
        PartialTranscriptPayload,
        PatchWorkspaceWebhookResponseModel,
        PdfExportOptions,
        PendingBlocksMetadataModel,
        PendingCancellationResponseModel,
        PendingClipTask,
        PendingClipTaskType,
        PendingExternalAudiosMetadataModel,
        PendingSubscriptionSwitchResponseModel,
        PendingSubscriptionSwitchResponseModelNextTier,
        PermissionType,
        PhoneNumberAgentInfo,
        PhoneNumberDynamicVariableTransferDestination,
        PhoneNumberTransfer,
        PhoneNumberTransferCustomSipHeadersItem,
        PhoneNumberTransferCustomSipHeadersItem_Dynamic,
        PhoneNumberTransferCustomSipHeadersItem_Static,
        PhoneNumberTransferDestination,
        PhoneNumberTransferPostDialDigits,
        PhoneNumberTransferPostDialDigits_Dynamic,
        PhoneNumberTransferPostDialDigits_Static,
        PhoneNumberTransferTransferDestination,
        PhoneNumberTransferTransferDestination_Phone,
        PhoneNumberTransferTransferDestination_PhoneDynamicVariable,
        PhoneNumberTransferTransferDestination_SipUri,
        PhoneNumberTransferTransferDestination_SipUriDynamicVariable,
        PingPayload,
        PlayDtmfResultErrorModel,
        PlayDtmfResultSuccessModel,
        PlayDtmfToolConfig,
        PodcastBulletinMode,
        PodcastBulletinModeData,
        PodcastConversationMode,
        PodcastConversationModeData,
        PodcastProjectResponseModel,
        PodcastTextSource,
        PodcastUrlSource,
        PongPayload,
        PositionInput,
        PositionOutput,
        PostAgentAvatarResponseModel,
        PostDialDigitsDynamicVariable,
        PostDialDigitsStatic,
        PostWorkspaceSecretResponseModel,
        PreToolSpeechMode,
        PreviewAudioDbModel,
        Price,
        PrivacyConfigInput,
        PrivacyConfigOutput,
        PrivateKeyJwtResponse,
        PrivateKeyJwtResponseAlgorithm,
        ProcedureAtVersionInput,
        ProcedureAtVersionOutput,
        ProcedureRefResponseModel,
        ProcedureType,
        ProjectCreationMetaResponseModel,
        ProjectCreationMetaResponseModelStatus,
        ProjectCreationMetaResponseModelType,
        ProjectExtendedResponse,
        ProjectExtendedResponseModelAccessLevel,
        ProjectExtendedResponseModelApplyTextNormalization,
        ProjectExtendedResponseModelAspectRatio,
        ProjectExtendedResponseModelAssetsItem,
        ProjectExtendedResponseModelAssetsItem_Audio,
        ProjectExtendedResponseModelAssetsItem_Image,
        ProjectExtendedResponseModelAssetsItem_Video,
        ProjectExtendedResponseModelFiction,
        ProjectExtendedResponseModelSourceType,
        ProjectExtendedResponseModelTargetAudience,
        ProjectExternalAudioResponseModel,
        ProjectExternalAudioResponseModelSourceContext,
        ProjectExternalAudioResponseModelSourceContext_MusicExploreSong,
        ProjectExternalAudioResponseModelSourceContext_Sfx,
        ProjectExternalAudioResponseModelSourceContext_Song,
        ProjectImageResponseModel,
        ProjectMutedTracksResponseModel,
        ProjectResponse,
        ProjectResponseModelAccessLevel,
        ProjectResponseModelAspectRatio,
        ProjectResponseModelFiction,
        ProjectResponseModelSourceType,
        ProjectResponseModelTargetAudience,
        ProjectSnapshotExtendedResponseModel,
        ProjectSnapshotResponse,
        ProjectSnapshotsResponse,
        ProjectState,
        ProjectVideoResponseModel,
        ProjectVideoThumbnailSheetResponseModel,
        ProjectVoiceResponseModel,
        PromptAgent,
        PromptAgentApiModelInput,
        PromptAgentApiModelInputBackupLlmConfig,
        PromptAgentApiModelInputBackupLlmConfig_Default,
        PromptAgentApiModelInputBackupLlmConfig_Disabled,
        PromptAgentApiModelInputBackupLlmConfig_Override,
        PromptAgentApiModelInputToolsItem,
        PromptAgentApiModelInputToolsItem_ApiIntegrationWebhook,
        PromptAgentApiModelInputToolsItem_Client,
        PromptAgentApiModelInputToolsItem_Mcp,
        PromptAgentApiModelInputToolsItem_Smb,
        PromptAgentApiModelInputToolsItem_System,
        PromptAgentApiModelInputToolsItem_Webhook,
        PromptAgentApiModelOutput,
        PromptAgentApiModelOutputBackupLlmConfig,
        PromptAgentApiModelOutputBackupLlmConfig_Default,
        PromptAgentApiModelOutputBackupLlmConfig_Disabled,
        PromptAgentApiModelOutputBackupLlmConfig_Override,
        PromptAgentApiModelOutputToolsItem,
        PromptAgentApiModelOutputToolsItem_ApiIntegrationWebhook,
        PromptAgentApiModelOutputToolsItem_Client,
        PromptAgentApiModelOutputToolsItem_Mcp,
        PromptAgentApiModelOutputToolsItem_Smb,
        PromptAgentApiModelOutputToolsItem_System,
        PromptAgentApiModelOutputToolsItem_Webhook,
        PromptAgentApiModelOverrideConfig,
        PromptAgentApiModelOverrideInput,
        PromptAgentApiModelOverrideOutput,
        PromptAgentApiModelWorkflowOverrideInput,
        PromptAgentApiModelWorkflowOverrideInputBackupLlmConfig,
        PromptAgentApiModelWorkflowOverrideInputToolsItem,
        PromptAgentApiModelWorkflowOverrideInputToolsItem_ApiIntegrationWebhook,
        PromptAgentApiModelWorkflowOverrideInputToolsItem_Client,
        PromptAgentApiModelWorkflowOverrideInputToolsItem_Mcp,
        PromptAgentApiModelWorkflowOverrideInputToolsItem_Smb,
        PromptAgentApiModelWorkflowOverrideInputToolsItem_System,
        PromptAgentApiModelWorkflowOverrideInputToolsItem_Webhook,
        PromptAgentApiModelWorkflowOverrideOutput,
        PromptAgentApiModelWorkflowOverrideOutputBackupLlmConfig,
        PromptAgentApiModelWorkflowOverrideOutputToolsItem,
        PromptAgentApiModelWorkflowOverrideOutputToolsItem_ApiIntegrationWebhook,
        PromptAgentApiModelWorkflowOverrideOutputToolsItem_Client,
        PromptAgentApiModelWorkflowOverrideOutputToolsItem_Mcp,
        PromptAgentApiModelWorkflowOverrideOutputToolsItem_Smb,
        PromptAgentApiModelWorkflowOverrideOutputToolsItem_System,
        PromptAgentApiModelWorkflowOverrideOutputToolsItem_Webhook,
        PromptAgentDbModel,
        PromptEvaluationCriteria,
        PromptInjectionGuardrail,
        PronunciationDictionaryAliasRuleRequestModel,
        PronunciationDictionaryAliasRuleResponseModel,
        PronunciationDictionaryLocator,
        PronunciationDictionaryLocatorResponseModel,
        PronunciationDictionaryPhonemeRuleRequestModel,
        PronunciationDictionaryPhonemeRuleResponseModel,
        PronunciationDictionaryRulesResponseModel,
        PronunciationDictionaryVersionLocator,
        PronunciationDictionaryVersionResponseModel,
        PronunciationDictionaryVersionResponseModelPermissionOnResource,
        PydanticPronunciationDictionaryVersionLocator,
        QualityPresetType,
        QueryParamsJsonSchema,
        QuoteInfo,
        RagChunkMetadata,
        RagConfig,
        RagConfigWorkflowOverride,
        RagDocumentIndexResponseModel,
        RagDocumentIndexUsage,
        RagDocumentIndexesResponseModel,
        RagIndexBatchSuccessfulResponseModel,
        RagIndexOverviewEmbeddingModelResponseModel,
        RagIndexOverviewResponseModel,
        RagIndexStatus,
        RagRetrievalInfo,
        ReadLegalTerms,
        ReadMetadataChapterDbModel,
        ReaderResourceResponseModel,
        ReaderResourceResponseModelResourceType,
        RealtimeConfigSnapshot,
        RealtimeConfigSnapshotParents,
        RealtimeVoiceSettings,
        RecordingResponse,
        ReferenceVideo,
        ReferencedToolCommonModel,
        ReferencedToolCommonModelType,
        RegexParameterEvaluationStrategy,
        RegionConfigRequest,
        RegionalProcessingSurchargeInfo,
        RegisterForGroupSessionParams,
        RegisterMediaResponse,
        RemoveMemberFromGroupRequest,
        RemoveOrderItemResponse,
        Render,
        RenderStatus,
        RenderType,
        ReportKnowledgeGapParams,
        RequestPvcManualVerificationResponseModel,
        RequiredConstraint,
        RequiredConstraints,
        ResourceAccessInfo,
        ResourceAccessInfoAccessSource,
        ResourceAccessInfoAnonymousAccessLevelOverride,
        ResourceAccessInfoRole,
        ResourceMetadataResponseModel,
        ResourceMetadataResponseModelAnonymousAccessLevelOverride,
        ResponseFilter,
        ResponseFilterMode,
        ResponseUnitTestModel,
        RestoreCalendarEventParams,
        RetryTriggerAction,
        ReviewResponseModel,
        ReviewResponseModelRejectReasonsItem,
        ReviewResponseModelReviewStatus,
        ReviewStatus,
        RttAudioPayload,
        RttEndOfStreamPayload,
        RttErrorPayload,
        RttFinalTranscriptPayload,
        RttInputAudioChunkPayload,
        RttInputFormatEnum,
        RttOutputFormatEnum,
        RttPartialTranscriptPayload,
        RttSessionStartedPayload,
        RttStatusPayload,
        RttTranslationPayload,
        SafetyCommonModelInput,
        SafetyCommonModelOutput,
        SafetyEvaluation,
        SafetyResponseModel,
        SafetyRule,
        SampleConfigDbModel,
        SampleConfigDbModelParentType,
        SaveVoicePreviewRequest,
        SayNodeLiteralMessageInput,
        SayNodeLiteralMessageOutput,
        SayNodePromptMessageInput,
        SayNodePromptMessageOutput,
        ScheduleGroupSessionParams,
        ScopedAnalysisResult,
        ScribeAuthErrorPayload,
        ScribeChunkSizeExceededErrorPayload,
        ScribeErrorPayload,
        ScribeInputErrorPayload,
        ScribeInsufficientAudioActivityErrorPayload,
        ScribeQueueOverflowErrorPayload,
        ScribeQuotaExceededErrorPayload,
        ScribeRateLimitedErrorPayload,
        ScribeResourceExhaustedErrorPayload,
        ScribeSessionTimeLimitExceededErrorPayload,
        ScribeThrottledErrorPayload,
        ScribeTranscriberErrorPayload,
        ScribeUnacceptedTermsErrorPayload,
        SearchClientsParams,
        SearchHighlightSegment,
        SeatType,
        SecretDependencyResourceType,
        SecretDependencyType,
        SectionSource,
        SegmentCreateResponse,
        SegmentDeleteResponse,
        SegmentDubResponse,
        SegmentMigrationResponse,
        SegmentSubtitleFrame,
        SegmentTranscriptionResponse,
        SegmentTranslationResponse,
        SegmentUpdateResponse,
        SegmentedJsonExportOptions,
        SendText,
        SendTextMulti,
        SessionStartedPayload,
        SessionStartedPayloadConfig,
        SessionStartedPayloadConfigCommitStrategy,
        SetBookingSlugParams,
        SeverityId,
        SfxSourceContext,
        ShareOptionResponseModel,
        ShareOptionResponseModelType,
        SimilarVoice,
        SimilarVoicesForSpeakerResponse,
        SimulationTestModel,
        SimulationToolMockBehaviorConfig,
        SingleLanguagesResponse,
        SingleTestRunRequestModel,
        SingleUseTokenResponseModel,
        SingleUseTokenType,
        SipLogMessage,
        SipLogMessageDirection,
        SipMediaEncryptionEnum,
        SipTrunkCredentialsRequestModel,
        SipTrunkOutboundCallResponse,
        SipTrunkTransportEnum,
        SipUriDynamicVariableTransferDestination,
        SipUriTransferDestination,
        SkipTurnToolConfig,
        SkipTurnToolResponseModel,
        SlackBotAuthResponse,
        SmsConversationInfo,
        SmsConversationInfoDirection,
        SoftTimeoutConfig,
        SoftTimeoutConfigOverride,
        SoftTimeoutConfigOverrideConfig,
        SoftTimeoutConfigWorkflowOverride,
        SongMetadata,
        SongSection,
        SongSourceContext,
        SortDirection,
        SpeakerAudioResponseModel,
        SpeakerCreatedResponse,
        SpeakerResponseModel,
        SpeakerSegment,
        SpeakerSeparationResponseModel,
        SpeakerSeparationResponseModelStatus,
        SpeakerTrack,
        SpeakerUpdatedResponse,
        SpeechEngineConfig,
        SpeechEngineConfigRequestHeadersValue,
        SpeechEngineConversationInitiationClientDataConfig,
        SpeechEngineResponse,
        SpeechEngineSummaryResponse,
        SpeechHistoryItemResponse,
        SpeechHistoryItemResponseModelSource,
        SpeechHistoryItemResponseModelVoiceCategory,
        SpeechToTextCharacterResponseModel,
        SpeechToTextChunkResponseModel,
        SpeechToTextWebhookResponseModel,
        SpeechToTextWordResponseModel,
        SpeechToTextWordResponseModelType,
        SpellingPatience,
        SrtExportOptions,
        StartProcedureToolConfigInput,
        StartProcedureToolConfigOutput,
        StartProcedureToolErrorStatus,
        StartPvcVoiceTrainingResponseModel,
        StartSpeakerSeparationResponseModel,
        StatusId,
        StreamingAudioChunkWithTimestampsAndVoiceSegmentsResponseModel,
        StreamingAudioChunkWithTimestampsResponse,
        StudioAgentSettingsModel,
        StudioAgentToolSettingsModel,
        StudioClipReference,
        StudioClipReferenceClipType,
        StudioTextStyleOutlineModel,
        StudioTextStyleShadowModel,
        SubmitBusinessInfoParams,
        SubmitOrderResponse,
        Subscription,
        SubscriptionResponse,
        SubscriptionResponseModelMaxCreditLimitExtension,
        SubscriptionStatusType,
        SubtitleOrderItemRequest,
        SuggestedAudioTag,
        SupportedVoice,
        SystemEvaluationCriteria,
        SystemToolConfigInput,
        SystemToolConfigInputParams,
        SystemToolConfigInputParams_EndCall,
        SystemToolConfigInputParams_EndProcedure,
        SystemToolConfigInputParams_KnowledgeBaseRag,
        SystemToolConfigInputParams_LanguageDetection,
        SystemToolConfigInputParams_PlayKeypadTouchTone,
        SystemToolConfigInputParams_SkipTurn,
        SystemToolConfigInputParams_StartProcedure,
        SystemToolConfigInputParams_TransferToAgent,
        SystemToolConfigInputParams_TransferToNumber,
        SystemToolConfigInputParams_VoicemailDetection,
        SystemToolConfigOutput,
        SystemToolConfigOutputParams,
        SystemToolConfigOutputParams_EndCall,
        SystemToolConfigOutputParams_EndProcedure,
        SystemToolConfigOutputParams_KnowledgeBaseRag,
        SystemToolConfigOutputParams_LanguageDetection,
        SystemToolConfigOutputParams_PlayKeypadTouchTone,
        SystemToolConfigOutputParams_SkipTurn,
        SystemToolConfigOutputParams_StartProcedure,
        SystemToolConfigOutputParams_TransferToAgent,
        SystemToolConfigOutputParams_TransferToNumber,
        SystemToolConfigOutputParams_VoicemailDetection,
        TelephonyCallConfig,
        TelephonyDirection,
        TelephonyProvider,
        TestConditionRationaleCommonModel,
        TestConditionResultCommonModel,
        TestFromConversationMetadataInput,
        TestFromConversationMetadataOutput,
        TestInvocationSummaryResponseModel,
        TestRunMetadata,
        TestRunMetadataTestType,
        TestRunResultBucket,
        TestRunResultSummary,
        TestRunStatus,
        TestSharingMode,
        TestToolResultModel,
        TestType,
        TestsFeatureUsageCommonModel,
        TextNormalisationType,
        TextToDialogueWebsocketApplyTextNormalizationEnum,
        TextToDialogueWebsocketAudioChunk,
        TextToDialogueWebsocketClientMessage,
        TextToDialogueWebsocketError,
        TextToDialogueWebsocketFinal,
        TextToDialogueWebsocketFinalAudioForTurn,
        TextToDialogueWebsocketOutputFormatEnum,
        TextToDialogueWebsocketVoiceInput,
        TextToDialogueWebsocketVoiceSettings,
        TextToSpeechApplyTextNormalizationEnum,
        TextToSpeechOutputFormatEnum,
        TextToSpeechRequest,
        TextToSpeechStreamRequest,
        TextToSpeechStreamWithTimestampsRequest,
        TextToSpeechWithTimestampsRequest,
        ThresholdGuardrail,
        TimeRange,
        ToDialogueSettingsResponseModel,
        TokenResponseModel,
        Tool,
        ToolAnnotations,
        ToolCallSoundBehavior,
        ToolCallSoundType,
        ToolCallUnitTestModel,
        ToolErrorHandlingMode,
        ToolExecution,
        ToolExecutionMode,
        ToolExecutionResponseModel,
        ToolExecutionResponseModelToolCallDetails,
        ToolExecutionResponseModelToolCallDetails_ApiIntegrationWebhook,
        ToolExecutionResponseModelToolCallDetails_Client,
        ToolExecutionResponseModelToolCallDetails_Mcp,
        ToolExecutionResponseModelToolCallDetails_Webhook,
        ToolExecutionTaskSupport,
        ToolMockConfig,
        ToolRequestModel,
        ToolRequestModelToolConfig,
        ToolRequestModelToolConfig_Client,
        ToolRequestModelToolConfig_Mcp,
        ToolRequestModelToolConfig_System,
        ToolRequestModelToolConfig_Webhook,
        ToolResponseMockConfigInput,
        ToolResponseMockConfigOutput,
        ToolResponseModel,
        ToolResponseModelToolConfig,
        ToolResponseModelToolConfig_Client,
        ToolResponseModelToolConfig_Mcp,
        ToolResponseModelToolConfig_System,
        ToolResponseModelToolConfig_Webhook,
        ToolSortBy,
        ToolType,
        ToolTypeFilter,
        ToolUsageStatsResponseModel,
        ToolsResponseModel,
        TopicDiscoverySettings,
        TranscriptMessage,
        TranscriptMessageRole,
        TranscriptionWord,
        TranscriptionWordType,
        TransferBranchInfoDefaultingToMain,
        TransferBranchInfoTrafficSplit,
        TransferToAgentToolConfig,
        TransferToAgentToolResultErrorModel,
        TransferToAgentToolResultSuccessModel,
        TransferToAgentToolResultSuccessModelBranchInfo,
        TransferToAgentToolResultSuccessModelBranchInfo_DefaultingToMain,
        TransferToAgentToolResultSuccessModelBranchInfo_TrafficSplit,
        TransferToNumberResultErrorModel,
        TransferToNumberResultExotelSuccessModel,
        TransferToNumberResultSipSuccessModel,
        TransferToNumberResultTwilioSuccessModel,
        TransferToNumberToolConfigInput,
        TransferToNumberToolConfigOutput,
        TransferTypeEnum,
        TtsConversationalConfigInput,
        TtsConversationalConfigOutput,
        TtsConversationalConfigOverride,
        TtsConversationalConfigOverrideConfig,
        TtsConversationalConfigWorkflowOverrideInput,
        TtsConversationalConfigWorkflowOverrideOutput,
        TtsConversationalModel,
        TtsModelFamily,
        TtsOptimizeStreamingLatency,
        TtsOutputFormat,
        TurnConfig,
        TurnConfigOverride,
        TurnConfigOverrideConfig,
        TurnConfigWorkflowOverride,
        TurnDetectionType,
        TurnEagerness,
        TurnMode,
        TurnModel,
        TwilioEdgeLocation,
        TwilioOutboundCallResponse,
        TwilioRegionId,
        TxtExportOptions,
        UnitTestRunResponseModel,
        UnitTestRunResponseModelTestInfo,
        UnitTestRunResponseModelTestInfo_Llm,
        UnitTestRunResponseModelTestInfo_Simulation,
        UnitTestRunResponseModelTestInfo_Tool,
        UnitTestSummaryResponseModel,
        UnitTestToolCallEvaluationModelInput,
        UnitTestToolCallEvaluationModelOutput,
        UnitTestToolCallParameter,
        UnitTestToolCallParameterEval,
        UnitTestToolCallParameterEval_Anything,
        UnitTestToolCallParameterEval_Exact,
        UnitTestToolCallParameterEval_Llm,
        UnitTestToolCallParameterEval_Regex,
        UnitTestWorkflowNodeTransitionEvaluationNodeId,
        UpdateAgentRuleParams,
        UpdateAssetParams,
        UpdateAudioNativeProjectRequest,
        UpdateBasicAuthRequest,
        UpdateBookingPageAppearanceParams,
        UpdateBookingPageSettingsParams,
        UpdateBusinessInfoParams,
        UpdateCalendarEventParams,
        UpdateChapterRequest,
        UpdateClientParams,
        UpdateCustomerFacingConfigParams,
        UpdateGroupSessionSeatsParams,
        UpdateHolidayParams,
        UpdateLocationParams,
        UpdateOAuth2ClientCredsRequest,
        UpdateOAuth2JwtRequest,
        UpdateOAuth2JwtRequestAlgorithm,
        UpdateOAuth2JwtRequestTokenResponseField,
        UpdateOrderRequest,
        UpdateOrderResponse,
        UpdateProductParams,
        UpdateProjectRequest,
        UpdatePronunciationDictionariesRequest,
        UpdateResponseUnitTestRequest,
        UpdateServiceParams,
        UpdateSimulationTestRequest,
        UpdateStaffParams,
        UpdateToolCallUnitTestRequest,
        UpdateWorkspaceMemberResponseModel,
        UpsertOrderItemRequest,
        UpsertOrderItemResponse,
        UrlAvatar,
        UrlModel,
        UrlSecretAuthResponse,
        UsageAggregationInterval,
        UsageCharactersResponseModel,
        User,
        UserAccessManagementActivityId,
        UserFeedback,
        UserFeedbackScore,
        UserModel,
        UserTranscriptPayload,
        UserTypeId,
        UsersSortBy,
        UtteranceResponseModel,
        VadConfig,
        VadConfigWorkflowOverride,
        ValidationError,
        ValidationErrorLocItem,
        Verbosity,
        VerificationAttemptResponse,
        VerifiedVoiceLanguageResponseModel,
        VerifyPvcVoiceCaptchaResponseModel,
        VideoAnalysis,
        VideoAnalysisResult,
        VideoAnalysisStatus,
        VideoKeyMoment,
        VideoSegment,
        VideoSubject,
        VisitedAgentRef,
        Voice,
        VoiceCategory,
        VoiceDesignPreviewResponse,
        VoiceGenerationParameterOptionResponse,
        VoiceGenerationParameterResponse,
        VoiceMailDetectionResultSuccessModel,
        VoicePreviewResponseModel,
        VoiceResponseModelCategory,
        VoiceResponseModelLabellingStatus,
        VoiceResponseModelRecordingQuality,
        VoiceResponseModelSafetyControl,
        VoiceSample,
        VoiceSamplePreviewResponseModel,
        VoiceSampleVisualWaveformResponseModel,
        VoiceSegment,
        VoiceSettings,
        VoiceSharingModerationCheckResponseModel,
        VoiceSharingResponse,
        VoiceSharingResponseModelCategory,
        VoiceSharingState,
        VoiceStatisticsResponseModel,
        VoiceVerificationResponse,
        VoicemailDetectionToolConfig,
        WebhookAuthMethodType,
        WebhookEventType,
        WebhookHmacSettings,
        WebhookToolApiSchemaConfigInput,
        WebhookToolApiSchemaConfigInputAuthConnection,
        WebhookToolApiSchemaConfigInputContentType,
        WebhookToolApiSchemaConfigInputMethod,
        WebhookToolApiSchemaConfigInputRequestHeadersValue,
        WebhookToolApiSchemaConfigOutput,
        WebhookToolApiSchemaConfigOutputAuthConnection,
        WebhookToolApiSchemaConfigOutputContentType,
        WebhookToolApiSchemaConfigOutputMethod,
        WebhookToolApiSchemaConfigOutputRequestHeadersValue,
        WebhookToolConfigInput,
        WebhookToolConfigOutput,
        WebhookTranscriptFormat,
        WebhookUsageType,
        WebsocketTtsClientMessageMulti,
        WebsocketTtsServerMessageMulti,
        WhatsAppAuthResponse,
        WhatsAppConversationInfo,
        WhatsAppConversationInfoDirection,
        WhatsAppOutboundCallResponse,
        WhatsAppOutboundMessageResponse,
        WhatsAppTemplateBodyComponentParams,
        WhatsAppTemplateButtonComponentParams,
        WhatsAppTemplateDocumentParam,
        WhatsAppTemplateDocumentParamDetails,
        WhatsAppTemplateHeaderComponentParams,
        WhatsAppTemplateHeaderComponentParamsParametersItem,
        WhatsAppTemplateHeaderComponentParamsParametersItem_Document,
        WhatsAppTemplateHeaderComponentParamsParametersItem_Image,
        WhatsAppTemplateHeaderComponentParamsParametersItem_Location,
        WhatsAppTemplateHeaderComponentParamsParametersItem_Text,
        WhatsAppTemplateImageParam,
        WhatsAppTemplateImageParamDetails,
        WhatsAppTemplateLocationParam,
        WhatsAppTemplateLocationParamDetails,
        WhatsAppTemplateTextParam,
        WidgetConfig,
        WidgetConfigInputAvatar,
        WidgetConfigInputAvatar_Image,
        WidgetConfigInputAvatar_Orb,
        WidgetConfigInputAvatar_Url,
        WidgetConfigInputSyntaxHighlightTheme,
        WidgetConfigOutputAvatar,
        WidgetConfigOutputAvatar_Image,
        WidgetConfigOutputAvatar_Orb,
        WidgetConfigOutputAvatar_Url,
        WidgetConfigOutputSyntaxHighlightTheme,
        WidgetConfigResponse,
        WidgetConfigResponseModelAvatar,
        WidgetConfigResponseModelAvatar_Image,
        WidgetConfigResponseModelAvatar_Orb,
        WidgetConfigResponseModelAvatar_Url,
        WidgetConfigResponseModelSyntaxHighlightTheme,
        WidgetEndFeedbackConfig,
        WidgetEndFeedbackType,
        WidgetExpandable,
        WidgetFeedbackMode,
        WidgetLanguagePreset,
        WidgetLanguagePresetResponse,
        WidgetPlacement,
        WidgetStyles,
        WidgetTermsTranslation,
        WidgetTextContents,
        WordTimestamp,
        WorkflowEdgeModelInput,
        WorkflowEdgeModelInputBackwardCondition,
        WorkflowEdgeModelInputBackwardCondition_Expression,
        WorkflowEdgeModelInputBackwardCondition_Llm,
        WorkflowEdgeModelInputBackwardCondition_Result,
        WorkflowEdgeModelInputBackwardCondition_Unconditional,
        WorkflowEdgeModelInputForwardCondition,
        WorkflowEdgeModelInputForwardCondition_Expression,
        WorkflowEdgeModelInputForwardCondition_Llm,
        WorkflowEdgeModelInputForwardCondition_Result,
        WorkflowEdgeModelInputForwardCondition_Unconditional,
        WorkflowEdgeModelOutput,
        WorkflowEdgeModelOutputBackwardCondition,
        WorkflowEdgeModelOutputBackwardCondition_Expression,
        WorkflowEdgeModelOutputBackwardCondition_Llm,
        WorkflowEdgeModelOutputBackwardCondition_Result,
        WorkflowEdgeModelOutputBackwardCondition_Unconditional,
        WorkflowEdgeModelOutputForwardCondition,
        WorkflowEdgeModelOutputForwardCondition_Expression,
        WorkflowEdgeModelOutputForwardCondition_Llm,
        WorkflowEdgeModelOutputForwardCondition_Result,
        WorkflowEdgeModelOutputForwardCondition_Unconditional,
        WorkflowEndNodeModelInput,
        WorkflowEndNodeModelOutput,
        WorkflowExpressionConditionModelInput,
        WorkflowExpressionConditionModelOutput,
        WorkflowFeaturesUsageCommonModel,
        WorkflowLlmConditionModelInput,
        WorkflowLlmConditionModelOutput,
        WorkflowOverrideAgentNodeModelInput,
        WorkflowOverrideAgentNodeModelOutput,
        WorkflowPhoneNumberNodeModelInput,
        WorkflowPhoneNumberNodeModelInputCustomSipHeadersItem,
        WorkflowPhoneNumberNodeModelInputCustomSipHeadersItem_Dynamic,
        WorkflowPhoneNumberNodeModelInputCustomSipHeadersItem_Static,
        WorkflowPhoneNumberNodeModelInputPostDialDigits,
        WorkflowPhoneNumberNodeModelInputPostDialDigits_Dynamic,
        WorkflowPhoneNumberNodeModelInputPostDialDigits_Static,
        WorkflowPhoneNumberNodeModelInputTransferDestination,
        WorkflowPhoneNumberNodeModelInputTransferDestination_Phone,
        WorkflowPhoneNumberNodeModelInputTransferDestination_PhoneDynamicVariable,
        WorkflowPhoneNumberNodeModelInputTransferDestination_SipUri,
        WorkflowPhoneNumberNodeModelInputTransferDestination_SipUriDynamicVariable,
        WorkflowPhoneNumberNodeModelOutput,
        WorkflowPhoneNumberNodeModelOutputCustomSipHeadersItem,
        WorkflowPhoneNumberNodeModelOutputCustomSipHeadersItem_Dynamic,
        WorkflowPhoneNumberNodeModelOutputCustomSipHeadersItem_Static,
        WorkflowPhoneNumberNodeModelOutputPostDialDigits,
        WorkflowPhoneNumberNodeModelOutputPostDialDigits_Dynamic,
        WorkflowPhoneNumberNodeModelOutputPostDialDigits_Static,
        WorkflowPhoneNumberNodeModelOutputTransferDestination,
        WorkflowPhoneNumberNodeModelOutputTransferDestination_Phone,
        WorkflowPhoneNumberNodeModelOutputTransferDestination_PhoneDynamicVariable,
        WorkflowPhoneNumberNodeModelOutputTransferDestination_SipUri,
        WorkflowPhoneNumberNodeModelOutputTransferDestination_SipUriDynamicVariable,
        WorkflowResultConditionModelInput,
        WorkflowResultConditionModelOutput,
        WorkflowStandaloneAgentNodeModelInput,
        WorkflowStandaloneAgentNodeModelOutput,
        WorkflowStartNodeModelInput,
        WorkflowStartNodeModelOutput,
        WorkflowToolEdgeStepModel,
        WorkflowToolLocator,
        WorkflowToolMaxIterationsExceededStepModel,
        WorkflowToolNestedToolsStepModelInput,
        WorkflowToolNestedToolsStepModelInputResultsItem,
        WorkflowToolNestedToolsStepModelOutput,
        WorkflowToolNestedToolsStepModelOutputResultsItem,
        WorkflowToolNodeModelInput,
        WorkflowToolNodeModelOutput,
        WorkflowToolResponseModelInput,
        WorkflowToolResponseModelInputStepsItem,
        WorkflowToolResponseModelInputStepsItem_Edge,
        WorkflowToolResponseModelInputStepsItem_MaxIterationsExceeded,
        WorkflowToolResponseModelInputStepsItem_NestedTools,
        WorkflowToolResponseModelOutput,
        WorkflowToolResponseModelOutputStepsItem,
        WorkflowToolResponseModelOutputStepsItem_Edge,
        WorkflowToolResponseModelOutputStepsItem_MaxIterationsExceeded,
        WorkflowToolResponseModelOutputStepsItem_NestedTools,
        WorkflowUnconditionalModelInput,
        WorkflowUnconditionalModelOutput,
        WorkspaceAnalyticsQueryResponseModel,
        WorkspaceAnalyticsQueryResponseModelColumnTypesItem,
        WorkspaceAnalyticsQueryResponseModelRowsItemItem,
        WorkspaceApiKeyListResponseModel,
        WorkspaceApiKeyResponseModel,
        WorkspaceAuditLogEntryResponse,
        WorkspaceAuditLogEntryResponseActivityId,
        WorkspaceAuditLogsPageResponse,
        WorkspaceBatchCallsResponse,
        WorkspaceCreateApiKeyResponseModel,
        WorkspaceCreateWebhookResponseModel,
        WorkspaceGroupByNameResponseModel,
        WorkspaceGroupPermission,
        WorkspaceGroupResponseModel,
        WorkspaceGroupResponseModelGroupPvcLimit,
        WorkspaceGroupResponseModelGroupUsageLimit,
        WorkspaceResourceType,
        WorkspaceServiceAccountListResponseModel,
        WorkspaceServiceAccountResponseModel,
        WorkspaceWebhookListResponseModel,
        WorkspaceWebhookResponseModel,
        WorkspaceWebhookUsageResponseModel,
    )
    from .errors import (
        BadRequestError,
        ConflictError,
        ForbiddenError,
        NotFoundError,
        TooEarlyError,
        UnauthorizedError,
        UnprocessableEntityError,
    )
    from . import (
        audio_isolation,
        audio_native,
        conversational_ai,
        dubbing,
        environment_variables,
        forced_alignment,
        history,
        models,
        music,
        productions,
        pronunciation_dictionaries,
        samples,
        service_accounts,
        speech_engine,
        speech_engine_upstream,
        speech_to_speech,
        speech_to_text,
        studio,
        text_to_dialogue,
        text_to_sound_effects,
        text_to_speech,
        text_to_voice,
        tokens,
        usage,
        user,
        v_1_realtime_translation,
        v_1_speech_to_text_realtime,
        v_1_text_to_dialogue_stream_input,
        v_1_text_to_speech_voice_id_multi_stream_input,
        v_1_text_to_speech_voice_id_stream_input,
        voices,
        webhooks,
        workspace,
        workspaces,
    )
    from .audio_isolation import AudioIsolationConvertRequestFileFormat, AudioIsolationStreamRequestFileFormat
    from .audio_native import AudioNativeCreateRequestApplyTextNormalization
    from .client import AsyncElevenLabs, ElevenLabs
    from .dubbing import (
        DubbingCreateRequestMode,
        DubbingListRequestCreationSourcesItem,
        DubbingListRequestDubbingModelsItem,
        DubbingListRequestDubbingStatus,
        DubbingListRequestDubbingStatusesItem,
        DubbingListRequestFilterByCreator,
        DubbingListRequestOrderBy,
        DubbingListRequestOrderDirection,
    )
    from .environment import ElevenLabsEnvironment
    from .environment_variables import (
        EnvironmentVariablesCreateRequestBody,
        EnvironmentVariablesCreateRequestBody_AuthConnection,
        EnvironmentVariablesCreateRequestBody_Secret,
        EnvironmentVariablesCreateRequestBody_String,
        EnvironmentVariablesListRequestType,
        UpdateEnvironmentVariableRequestValuesValue,
    )
    from .history import HistoryListRequestSortDirection, HistoryListRequestSource
    from .music import (
        BodyComposeMusicV1MusicPostCompositionPlan,
        BodyComposeMusicV1MusicPostModelId,
        BodyComposeMusicWithADetailedResponseV1MusicDetailedPostCompositionPlan,
        BodyComposeMusicWithADetailedResponseV1MusicDetailedPostModelId,
        BodyStreamComposedMusicV1MusicStreamPostCompositionPlan,
        BodyStreamComposedMusicV1MusicStreamPostModelId,
        MusicComposeDetailedRequestOutputFormat,
        MusicComposeRequestOutputFormat,
        MusicSeparateStemsRequestStemVariationId,
        MusicStreamRequestOutputFormat,
        MusicVideoToMusicRequestModelId,
    )
    from .play import play, save, stream
    from .pronunciation_dictionaries import (
        BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem,
        BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias,
        BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme,
        BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess,
        PronunciationDictionariesCreateFromFileRequestWorkspaceAccess,
        PronunciationDictionariesListRequestSort,
    )
    from .realtime import (
        AudioFormat,
        CommitStrategy,
        RealtimeAudioOptions,
        RealtimeConnection,
        RealtimeEvents,
        RealtimeUrlOptions,
    )
    from .speech_engine_upstream import ReceiveUpstreamMessage, SendUpstreamMessage
    from .speech_to_speech import (
        SpeechToSpeechConvertRequestFileFormat,
        SpeechToSpeechConvertRequestOutputFormat,
        SpeechToSpeechStreamRequestFileFormat,
        SpeechToSpeechStreamRequestOutputFormat,
    )
    from .speech_to_text import (
        SpeechToTextConvertRequestEntityDetection,
        SpeechToTextConvertRequestEntityRedaction,
        SpeechToTextConvertRequestFileFormat,
        SpeechToTextConvertRequestModelId,
        SpeechToTextConvertRequestTimestampsGranularity,
        SpeechToTextConvertRequestWebhookMetadata,
        SpeechToTextConvertResponse,
    )
    from .studio import (
        BodyCreatePodcastV1StudioPodcastsPostApplyTextNormalization,
        BodyCreatePodcastV1StudioPodcastsPostDurationScale,
        BodyCreatePodcastV1StudioPodcastsPostMode,
        BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin,
        BodyCreatePodcastV1StudioPodcastsPostMode_Conversation,
        BodyCreatePodcastV1StudioPodcastsPostSource,
        BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem,
        BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Text,
        BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Url,
    )
    from .text_to_dialogue import (
        BodyTextToDialogueFullWithTimestampsApplyTextNormalization,
        BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPostApplyTextNormalization,
        BodyTextToDialogueMultiVoiceV1TextToDialoguePostApplyTextNormalization,
        BodyTextToDialogueStreamWithTimestampsApplyTextNormalization,
        TextToDialogueConvertRequestOutputFormat,
        TextToDialogueConvertWithTimestampsRequestOutputFormat,
    )
    from .text_to_speech import (
        BodyTextToSpeechFullApplyTextNormalization,
        BodyTextToSpeechFullWithTimestampsApplyTextNormalization,
        BodyTextToSpeechStreamApplyTextNormalization,
        BodyTextToSpeechStreamWithTimestampsApplyTextNormalization,
        TextToSpeechConvertRequestOutputFormat,
        TextToSpeechConvertWithTimestampsRequestOutputFormat,
        TextToSpeechStreamRequestOutputFormat,
        TextToSpeechStreamWithTimestampsRequestOutputFormat,
    )
    from .text_to_voice import VoiceDesignRequestModelModelId
    from .v_1_realtime_translation import ReceiveRttMessage, SendRttMessage
    from .v_1_speech_to_text_realtime import ReceiveTranscription, TextToSpeechCommitStrategy
    from .v_1_text_to_dialogue_stream_input import ReceiveTextToDialogueWebsocketMessage
    from .v_1_text_to_speech_voice_id_multi_stream_input import ReceiveMessageMulti, SendMessageMulti
    from .v_1_text_to_speech_voice_id_stream_input import ReceiveMessage, SendMessage
    from .version import __version__
    from .voices import VoicesGetSharedRequestCategory, VoicesGetSharedRequestSort, VoicesUpdateRequestLabels
_dynamic_imports: typing.Dict[str, str] = {
    "AccountChangeActivityId": ".types",
    "ActorModel": ".types",
    "AddChapterResponseModel": ".types",
    "AddKnowledgeBaseResponseModel": ".types",
    "AddProjectRequest": ".types",
    "AddProjectResponseModel": ".types",
    "AddPronunciationDictionaryResponseModel": ".types",
    "AddPronunciationDictionaryResponseModelPermissionOnResource": ".types",
    "AddSharingVoiceRequest": ".types",
    "AddVoiceIvcResponseModel": ".types",
    "AddVoiceResponseModel": ".types",
    "AddWorkspaceGroupMemberResponseModel": ".types",
    "AddWorkspaceInviteResponseModel": ".types",
    "AdditionalFormatResponseModel": ".types",
    "AdditionalFormats": ".types",
    "AdhocAgentConfigOverrideForTestRequestModel": ".types",
    "Age": ".types",
    "AgentBranchBasicInfo": ".types",
    "AgentBranchResponse": ".types",
    "AgentBranchSummary": ".types",
    "AgentCallLimits": ".types",
    "AgentConfig": ".types",
    "AgentConfigApiModelWorkflowOverrideInput": ".types",
    "AgentConfigApiModelWorkflowOverrideOutput": ".types",
    "AgentConfigOverrideConfig": ".types",
    "AgentConfigOverrideInput": ".types",
    "AgentConfigOverrideOutput": ".types",
    "AgentDefinitionSource": ".types",
    "AgentDeploymentPercentageStrategy": ".types",
    "AgentDeploymentRequest": ".types",
    "AgentDeploymentRequestItem": ".types",
    "AgentDeploymentResponse": ".types",
    "AgentFailureResponseExample": ".types",
    "AgentMetadata": ".types",
    "AgentMetadataDbModel": ".types",
    "AgentMetadataResponseModel": ".types",
    "AgentPlatformSettingsRequestModel": ".types",
    "AgentPlatformSettingsResponseModel": ".types",
    "AgentResponsePayload": ".types",
    "AgentSimulatedChatTestResponseModel": ".types",
    "AgentSortBy": ".types",
    "AgentSuccessfulResponseExample": ".types",
    "AgentSummaryBatchSuccessfulResponseModel": ".types",
    "AgentSummaryResponseModel": ".types",
    "AgentTestEntityType": ".types",
    "AgentTestFolderPathSegmentResponseModel": ".types",
    "AgentTestingSettings": ".types",
    "AgentTopicResponseModel": ".types",
    "AgentTransfer": ".types",
    "AgentTrustContext": ".types",
    "AgentVersionMetadata": ".types",
    "AgentVersionParents": ".types",
    "AgentWorkflowRequestModel": ".types",
    "AgentWorkflowRequestModelNodesValue": ".types",
    "AgentWorkflowRequestModelNodesValue_End": ".types",
    "AgentWorkflowRequestModelNodesValue_OverrideAgent": ".types",
    "AgentWorkflowRequestModelNodesValue_PhoneNumber": ".types",
    "AgentWorkflowRequestModelNodesValue_StandaloneAgent": ".types",
    "AgentWorkflowRequestModelNodesValue_Start": ".types",
    "AgentWorkflowRequestModelNodesValue_Tool": ".types",
    "AgentWorkflowResponseModel": ".types",
    "AgentWorkflowResponseModelNodesValue": ".types",
    "AgentWorkflowResponseModelNodesValue_End": ".types",
    "AgentWorkflowResponseModelNodesValue_OverrideAgent": ".types",
    "AgentWorkflowResponseModelNodesValue_PhoneNumber": ".types",
    "AgentWorkflowResponseModelNodesValue_StandaloneAgent": ".types",
    "AgentWorkflowResponseModelNodesValue_Start": ".types",
    "AgentWorkflowResponseModelNodesValue_Tool": ".types",
    "AgentWorkspaceOverridesInput": ".types",
    "AgentWorkspaceOverridesOutput": ".types",
    "AlertingMonitorConfig": ".types",
    "AlertingSettings": ".types",
    "AlertingWebhookNotifier": ".types",
    "Alignment": ".types",
    "AllowedOutputFormats": ".types",
    "AllowlistItem": ".types",
    "AnalysisProperty": ".types",
    "AnalysisPropertyConstantValue": ".types",
    "AnalysisPropertyType": ".types",
    "AnalysisScope": ".types",
    "ApiIntegrationOAuth2AuthCodeResponse": ".types",
    "ApiIntegrationOAuth2AuthCodeResponseScopeSeparator": ".types",
    "ApiIntegrationOAuth2CustomAppResponse": ".types",
    "ApiIntegrationOAuth2CustomAppResponseScopeSeparator": ".types",
    "ApiIntegrationWebhookOverrides": ".types",
    "ApiIntegrationWebhookOverridesRequestHeadersValue": ".types",
    "ApiIntegrationWebhookOverridesSchemaOverridesValue": ".types",
    "ApiIntegrationWebhookOverridesSchemaOverridesValue_Constant": ".types",
    "ApiIntegrationWebhookOverridesSchemaOverridesValue_DynamicVariable": ".types",
    "ApiIntegrationWebhookOverridesSchemaOverridesValue_Llm": ".types",
    "ApiIntegrationWebhookOverridesSchemaOverridesValue_Omit": ".types",
    "ApiIntegrationWebhookToolConfigInput": ".types",
    "ApiIntegrationWebhookToolConfigOutput": ".types",
    "ArrayJsonSchemaPropertyInput": ".types",
    "ArrayJsonSchemaPropertyInputConstantValueItem": ".types",
    "ArrayJsonSchemaPropertyInputItems": ".types",
    "ArrayJsonSchemaPropertyOutput": ".types",
    "ArrayJsonSchemaPropertyOutputConstantValueItem": ".types",
    "ArrayJsonSchemaPropertyOutputItems": ".types",
    "AsrConversationalConfig": ".types",
    "AsrConversationalConfigOverride": ".types",
    "AsrConversationalConfigOverrideConfig": ".types",
    "AsrConversationalConfigWorkflowOverride": ".types",
    "AsrInputFormat": ".types",
    "AsrProvider": ".types",
    "AsrQuality": ".types",
    "AssetTranscription": ".types",
    "AssetTranscriptionData": ".types",
    "AssetTranscriptionStatus": ".types",
    "AstAdditionOperatorNodeInput": ".types",
    "AstAdditionOperatorNodeOutput": ".types",
    "AstAndOperatorNodeInput": ".types",
    "AstAndOperatorNodeOutput": ".types",
    "AstBooleanNodeInput": ".types",
    "AstBooleanNodeOutput": ".types",
    "AstConditionalOperatorNodeInput": ".types",
    "AstConditionalOperatorNodeOutput": ".types",
    "AstDivisionOperatorNodeInput": ".types",
    "AstDivisionOperatorNodeOutput": ".types",
    "AstDynamicVariableNodeInput": ".types",
    "AstDynamicVariableNodeOutput": ".types",
    "AstEqualsOperatorNodeInput": ".types",
    "AstEqualsOperatorNodeOutput": ".types",
    "AstGreaterThanOperatorNodeInput": ".types",
    "AstGreaterThanOperatorNodeOutput": ".types",
    "AstGreaterThanOrEqualsOperatorNodeInput": ".types",
    "AstGreaterThanOrEqualsOperatorNodeOutput": ".types",
    "AstLessThanOperatorNodeInput": ".types",
    "AstLessThanOperatorNodeOutput": ".types",
    "AstLessThanOrEqualsOperatorNodeInput": ".types",
    "AstLessThanOrEqualsOperatorNodeOutput": ".types",
    "AstMultiplicationOperatorNodeInput": ".types",
    "AstMultiplicationOperatorNodeOutput": ".types",
    "AstNodeInput": ".types",
    "AstNodeInput_AddOperator": ".types",
    "AstNodeInput_AndOperator": ".types",
    "AstNodeInput_BooleanLiteral": ".types",
    "AstNodeInput_ConditionalOperator": ".types",
    "AstNodeInput_DivOperator": ".types",
    "AstNodeInput_DynamicVariable": ".types",
    "AstNodeInput_EqOperator": ".types",
    "AstNodeInput_GtOperator": ".types",
    "AstNodeInput_GteOperator": ".types",
    "AstNodeInput_Llm": ".types",
    "AstNodeInput_LtOperator": ".types",
    "AstNodeInput_LteOperator": ".types",
    "AstNodeInput_MulOperator": ".types",
    "AstNodeInput_NeqOperator": ".types",
    "AstNodeInput_NullLiteral": ".types",
    "AstNodeInput_NumberLiteral": ".types",
    "AstNodeInput_OrOperator": ".types",
    "AstNodeInput_StringLiteral": ".types",
    "AstNodeInput_SubOperator": ".types",
    "AstNodeOutput": ".types",
    "AstNodeOutput_AddOperator": ".types",
    "AstNodeOutput_AndOperator": ".types",
    "AstNodeOutput_BooleanLiteral": ".types",
    "AstNodeOutput_ConditionalOperator": ".types",
    "AstNodeOutput_DivOperator": ".types",
    "AstNodeOutput_DynamicVariable": ".types",
    "AstNodeOutput_EqOperator": ".types",
    "AstNodeOutput_GtOperator": ".types",
    "AstNodeOutput_GteOperator": ".types",
    "AstNodeOutput_Llm": ".types",
    "AstNodeOutput_LtOperator": ".types",
    "AstNodeOutput_LteOperator": ".types",
    "AstNodeOutput_MulOperator": ".types",
    "AstNodeOutput_NeqOperator": ".types",
    "AstNodeOutput_NullLiteral": ".types",
    "AstNodeOutput_NumberLiteral": ".types",
    "AstNodeOutput_OrOperator": ".types",
    "AstNodeOutput_StringLiteral": ".types",
    "AstNodeOutput_SubOperator": ".types",
    "AstNotEqualsOperatorNodeInput": ".types",
    "AstNotEqualsOperatorNodeOutput": ".types",
    "AstNullNodeInput": ".types",
    "AstNullNodeOutput": ".types",
    "AstNumberNodeInput": ".types",
    "AstNumberNodeOutput": ".types",
    "AstOrOperatorNodeInput": ".types",
    "AstOrOperatorNodeOutput": ".types",
    "AstStringNodeInput": ".types",
    "AstStringNodeOutput": ".types",
    "AstSubtractionOperatorNodeInput": ".types",
    "AstSubtractionOperatorNodeOutput": ".types",
    "AstllmNodeInput": ".types",
    "AstllmNodeInputPrompt": ".types",
    "AstllmNodeInputValueSchema": ".types",
    "AstllmNodeOutput": ".types",
    "AsyncConversationMetadata": ".types",
    "AsyncConversationMetadataDeliveryStatus": ".types",
    "AsyncElevenLabs": ".client",
    "AttachedTestModel": ".types",
    "AudioAnalysis": ".types",
    "AudioAnalysisResult": ".types",
    "AudioAnalysisStatus": ".types",
    "AudioFormat": ".realtime",
    "AudioFormatEnum": ".types",
    "AudioIsolationConvertRequestFileFormat": ".audio_isolation",
    "AudioIsolationHistoryItemResponseModel": ".types",
    "AudioIsolationStreamRequestFileFormat": ".audio_isolation",
    "AudioKeyMoment": ".types",
    "AudioNativeCreateProjectResponseModel": ".types",
    "AudioNativeCreateRequestApplyTextNormalization": ".audio_native",
    "AudioNativeEditContentResponseModel": ".types",
    "AudioNativeProjectSettingsResponseModel": ".types",
    "AudioNativeProjectSettingsResponseModelStatus": ".types",
    "AudioOutput": ".types",
    "AudioOutputMulti": ".types",
    "AudioRefChunk": ".types",
    "AudioSegment": ".types",
    "AudioWithTimestampsAndVoiceSegmentsResponseModel": ".types",
    "AudioWithTimestampsResponse": ".types",
    "AuthConnectionDependencies": ".types",
    "AuthConnectionDependenciesMcpServersItem": ".types",
    "AuthConnectionDependenciesMcpServersItem_Available": ".types",
    "AuthConnectionDependenciesMcpServersItem_Unknown": ".types",
    "AuthConnectionDependenciesToolsItem": ".types",
    "AuthConnectionDependenciesToolsItem_Available": ".types",
    "AuthConnectionDependenciesToolsItem_Unknown": ".types",
    "AuthConnectionLocator": ".types",
    "AuthSettings": ".types",
    "AuthenticationActivityId": ".types",
    "AuthorizationMethod": ".types",
    "AutoSyncInfo": ".types",
    "BackgroundSoundConfig": ".types",
    "BackgroundSoundConfigWorkflowOverride": ".types",
    "BackgroundSoundPresetId": ".types",
    "BackgroundSoundSourceType": ".types",
    "BackupLlmDefault": ".types",
    "BackupLlmDisabled": ".types",
    "BackupLlmOverride": ".types",
    "BadRequestError": ".errors",
    "BadRequestErrorBody": ".types",
    "BaseTurnConfig": ".types",
    "BasicAuthResponse": ".types",
    "BatchCallDetailedResponse": ".types",
    "BatchCallRecipientStatus": ".types",
    "BatchCallResponse": ".types",
    "BatchCallStatus": ".types",
    "BatchCallWhatsAppParams": ".types",
    "BatchFailureResponseModel": ".types",
    "BearerAuthResponse": ".types",
    "BehaviorOverride": ".types",
    "BillingPeriod": ".types",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem": ".pronunciation_dictionaries",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias": ".pronunciation_dictionaries",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme": ".pronunciation_dictionaries",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess": ".pronunciation_dictionaries",
    "BodyComposeMusicV1MusicPostCompositionPlan": ".music",
    "BodyComposeMusicV1MusicPostModelId": ".music",
    "BodyComposeMusicWithADetailedResponseV1MusicDetailedPostCompositionPlan": ".music",
    "BodyComposeMusicWithADetailedResponseV1MusicDetailedPostModelId": ".music",
    "BodyCreatePodcastV1StudioPodcastsPostApplyTextNormalization": ".studio",
    "BodyCreatePodcastV1StudioPodcastsPostDurationScale": ".studio",
    "BodyCreatePodcastV1StudioPodcastsPostMode": ".studio",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin": ".studio",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Conversation": ".studio",
    "BodyCreatePodcastV1StudioPodcastsPostSource": ".studio",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem": ".studio",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Text": ".studio",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Url": ".studio",
    "BodyStreamComposedMusicV1MusicStreamPostCompositionPlan": ".music",
    "BodyStreamComposedMusicV1MusicStreamPostModelId": ".music",
    "BodyTextToDialogueFullWithTimestampsApplyTextNormalization": ".text_to_dialogue",
    "BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPostApplyTextNormalization": ".text_to_dialogue",
    "BodyTextToDialogueMultiVoiceV1TextToDialoguePostApplyTextNormalization": ".text_to_dialogue",
    "BodyTextToDialogueStreamWithTimestampsApplyTextNormalization": ".text_to_dialogue",
    "BodyTextToSpeechFullApplyTextNormalization": ".text_to_speech",
    "BodyTextToSpeechFullWithTimestampsApplyTextNormalization": ".text_to_speech",
    "BodyTextToSpeechStreamApplyTextNormalization": ".text_to_speech",
    "BodyTextToSpeechStreamWithTimestampsApplyTextNormalization": ".text_to_speech",
    "BranchProtectionStatus": ".types",
    "BreakdownTypes": ".types",
    "BucketingStatus": ".types",
    "BuiltInToolsInput": ".types",
    "BuiltInToolsOutput": ".types",
    "BuiltInToolsWorkflowOverrideInput": ".types",
    "BuiltInToolsWorkflowOverrideOutput": ".types",
    "CancelCalendarEventParams": ".types",
    "CancelGroupSessionForAllParams": ".types",
    "CancelGroupSessionRegistrationParams": ".types",
    "CanvasPlacement": ".types",
    "CaptionStyleCharacterAnimationModel": ".types",
    "CaptionStyleCharacterAnimationModelEnterType": ".types",
    "CaptionStyleCharacterAnimationModelExitType": ".types",
    "CaptionStyleHorizontalPlacementModel": ".types",
    "CaptionStyleHorizontalPlacementModelAlign": ".types",
    "CaptionStyleModel": ".types",
    "CaptionStyleModelTextAlign": ".types",
    "CaptionStyleModelTextBlendMode": ".types",
    "CaptionStyleModelTextStyle": ".types",
    "CaptionStyleModelTextTransform": ".types",
    "CaptionStyleModelTextWeight": ".types",
    "CaptionStyleSectionAnimationModel": ".types",
    "CaptionStyleSectionAnimationModelEnterType": ".types",
    "CaptionStyleSectionAnimationModelExitType": ".types",
    "CaptionStyleTemplateModel": ".types",
    "CaptionStyleVerticalPlacementModel": ".types",
    "CaptionStyleVerticalPlacementModelAlign": ".types",
    "CaptionStyleWordAnimationModel": ".types",
    "CaptionStyleWordAnimationModelEnterType": ".types",
    "CaptionStyleWordAnimationModelExitType": ".types",
    "ChapterContentBlockExtendableNodeResponseModel": ".types",
    "ChapterContentBlockInputModel": ".types",
    "ChapterContentBlockInputModelSubType": ".types",
    "ChapterContentBlockResponseModel": ".types",
    "ChapterContentBlockResponseModelNodesItem": ".types",
    "ChapterContentBlockResponseModelNodesItem_Other": ".types",
    "ChapterContentBlockResponseModelNodesItem_TtsNode": ".types",
    "ChapterContentBlockTtsNodeResponseModel": ".types",
    "ChapterContentInputModel": ".types",
    "ChapterContentParagraphTtsNodeInputModel": ".types",
    "ChapterContentResponseModel": ".types",
    "ChapterResponse": ".types",
    "ChapterSnapshotExtendedResponseModel": ".types",
    "ChapterSnapshotResponse": ".types",
    "ChapterSnapshotsResponse": ".types",
    "ChapterState": ".types",
    "ChapterStatisticsResponse": ".types",
    "ChapterWithContentResponseModel": ".types",
    "ChapterWithContentResponseModelState": ".types",
    "CharacterAlignmentModel": ".types",
    "CharacterAlignmentResponseModel": ".types",
    "CharacterRefreshPeriod": ".types",
    "CharacterUsageResponse": ".types",
    "ChatSourceMedium": ".types",
    "CheckServiceAvailabilityParams": ".types",
    "ClientEvent": ".types",
    "ClientToolConfigInput": ".types",
    "ClientToolConfigOutput": ".types",
    "ClipAnimation": ".types",
    "ClipAnimationEnterEffect": ".types",
    "ClipAnimationExitEffect": ".types",
    "CloseConnection": ".types",
    "CloseContext": ".types",
    "ClosePayload": ".types",
    "CloseSocket": ".types",
    "ColumnFilter": ".types",
    "ColumnFilterOperation": ".types",
    "ColumnFilterValuesItem": ".types",
    "ColumnUnit": ".types",
    "CommitStrategy": ".realtime",
    "CommittedTranscriptPayload": ".types",
    "CommittedTranscriptWithTimestampsPayload": ".types",
    "CompositionPlan": ".types",
    "CompositionPlanChunksItem": ".types",
    "ConfigEntityType": ".types",
    "ConflictError": ".errors",
    "ConstantSchemaOverride": ".types",
    "ConstantSchemaOverrideConstantValue": ".types",
    "ConstantSchemaOverrideConstantValueFourItem": ".types",
    "ContentConfig": ".types",
    "ContentGuardrailInput": ".types",
    "ContentGuardrailInputTriggerAction": ".types",
    "ContentGuardrailInputTriggerAction_EndCall": ".types",
    "ContentGuardrailInputTriggerAction_Retry": ".types",
    "ContentGuardrailOutput": ".types",
    "ContentGuardrailOutputTriggerAction": ".types",
    "ContentGuardrailOutputTriggerAction_EndCall": ".types",
    "ContentGuardrailOutputTriggerAction_Retry": ".types",
    "ContentThresholdGuardrail": ".types",
    "ContentThresholdGuardrailThreshold": ".types",
    "ContextualUpdateInfo": ".types",
    "Contributor": ".types",
    "ConvAiDynamicVariable": ".types",
    "ConvAiEnvVarLocator": ".types",
    "ConvAiFileUploadResponseModel": ".types",
    "ConvAiSecretLocator": ".types",
    "ConvAiStoredSecretDependencies": ".types",
    "ConvAiStoredSecretDependenciesAgentsItem": ".types",
    "ConvAiStoredSecretDependenciesAgentsItem_Available": ".types",
    "ConvAiStoredSecretDependenciesAgentsItem_Unknown": ".types",
    "ConvAiStoredSecretDependenciesMcpServersItem": ".types",
    "ConvAiStoredSecretDependenciesMcpServersItem_Available": ".types",
    "ConvAiStoredSecretDependenciesMcpServersItem_Unknown": ".types",
    "ConvAiStoredSecretDependenciesToolsItem": ".types",
    "ConvAiStoredSecretDependenciesToolsItem_Available": ".types",
    "ConvAiStoredSecretDependenciesToolsItem_Unknown": ".types",
    "ConvAiUserSecretDbModel": ".types",
    "ConvAiWebhooks": ".types",
    "ConvAiWorkspaceStoredSecretConfig": ".types",
    "ConversationAsrUsageModel": ".types",
    "ConversationChargingCommonModel": ".types",
    "ConversationConfigClientOverrideConfigInput": ".types",
    "ConversationConfigClientOverrideConfigOutput": ".types",
    "ConversationConfigClientOverrideInput": ".types",
    "ConversationConfigClientOverrideOutput": ".types",
    "ConversationConfigInput": ".types",
    "ConversationConfigOutput": ".types",
    "ConversationConfigOverride": ".types",
    "ConversationConfigOverrideConfig": ".types",
    "ConversationConfigWorkflowOverrideInput": ".types",
    "ConversationConfigWorkflowOverrideOutput": ".types",
    "ConversationDeletionSettings": ".types",
    "ConversationFeedbackType": ".types",
    "ConversationHistoryAnalysisCommonModel": ".types",
    "ConversationHistoryBatchCallModel": ".types",
    "ConversationHistoryElevenAssistantCommonModel": ".types",
    "ConversationHistoryErrorCommonModel": ".types",
    "ConversationHistoryEvaluationCriteriaResultCommonModel": ".types",
    "ConversationHistoryExotelPhoneCallModel": ".types",
    "ConversationHistoryFeedbackCommonModel": ".types",
    "ConversationHistoryMetadataCommonModel": ".types",
    "ConversationHistoryMetadataCommonModelPhoneCall": ".types",
    "ConversationHistoryMetadataCommonModelPhoneCall_Exotel": ".types",
    "ConversationHistoryMetadataCommonModelPhoneCall_SipTrunking": ".types",
    "ConversationHistoryMetadataCommonModelPhoneCall_Twilio": ".types",
    "ConversationHistoryMultivoiceMessageModel": ".types",
    "ConversationHistoryMultivoiceMessagePartModel": ".types",
    "ConversationHistoryRagUsageCommonModel": ".types",
    "ConversationHistoryRedactionConfig": ".types",
    "ConversationHistorySipTrunkingPhoneCallModel": ".types",
    "ConversationHistoryTranscriptApiIntegrationWebhookToolsResultCommonModelInput": ".types",
    "ConversationHistoryTranscriptApiIntegrationWebhookToolsResultCommonModelOutput": ".types",
    "ConversationHistoryTranscriptCommonModelInput": ".types",
    "ConversationHistoryTranscriptCommonModelInputRole": ".types",
    "ConversationHistoryTranscriptCommonModelInputToolResultsItem": ".types",
    "ConversationHistoryTranscriptCommonModelOutput": ".types",
    "ConversationHistoryTranscriptCommonModelOutputRole": ".types",
    "ConversationHistoryTranscriptCommonModelOutputToolResultsItem": ".types",
    "ConversationHistoryTranscriptFileInputResponseModel": ".types",
    "ConversationHistoryTranscriptOtherToolsResultCommonModel": ".types",
    "ConversationHistoryTranscriptOtherToolsResultCommonModelType": ".types",
    "ConversationHistoryTranscriptResponseModel": ".types",
    "ConversationHistoryTranscriptResponseModelRole": ".types",
    "ConversationHistoryTranscriptResponseModelToolResultsItem": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInput": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_EndCallSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_KnowledgeBaseRagSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_LanguageDetectionSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_PlayDtmfError": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_PlayDtmfSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_SkipTurnSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TestingToolResult": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToAgentError": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToAgentSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberError": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberExotelSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberSipSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberTwilioSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_VoicemailDetectionSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutput": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_EndCallSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_KnowledgeBaseRagSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_LanguageDetectionSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_PlayDtmfError": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_PlayDtmfSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_SkipTurnSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TestingToolResult": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToAgentError": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToAgentSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberError": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberExotelSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberSipSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberTwilioSuccess": ".types",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_VoicemailDetectionSuccess": ".types",
    "ConversationHistoryTranscriptToolCallApiIntegrationWebhookDetailsInput": ".types",
    "ConversationHistoryTranscriptToolCallApiIntegrationWebhookDetailsOutput": ".types",
    "ConversationHistoryTranscriptToolCallClientDetails": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelInput": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelInputToolDetails": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_ApiIntegrationWebhook": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_Client": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_Mcp": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_Webhook": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelOutput": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_ApiIntegrationWebhook": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_Client": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_Mcp": ".types",
    "ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_Webhook": ".types",
    "ConversationHistoryTranscriptToolCallMcpDetails": ".types",
    "ConversationHistoryTranscriptToolCallWebhookDetails": ".types",
    "ConversationHistoryTranscriptWorkflowToolsResultCommonModelInput": ".types",
    "ConversationHistoryTranscriptWorkflowToolsResultCommonModelOutput": ".types",
    "ConversationHistoryTwilioPhoneCallModel": ".types",
    "ConversationInitiationClientDataConfigInput": ".types",
    "ConversationInitiationClientDataConfigOutput": ".types",
    "ConversationInitiationClientDataInternal": ".types",
    "ConversationInitiationClientDataRequestInput": ".types",
    "ConversationInitiationClientDataRequestOutput": ".types",
    "ConversationInitiationClientDataWebhook": ".types",
    "ConversationInitiationClientDataWebhookRequestHeadersValue": ".types",
    "ConversationInitiationSource": ".types",
    "ConversationInitiationSourceInfo": ".types",
    "ConversationProduct": ".types",
    "ConversationSentimentAnalysis": ".types",
    "ConversationSentimentAnalysisOverallLabel": ".types",
    "ConversationSignedUrlResponseModel": ".types",
    "ConversationSimulationSpecification": ".types",
    "ConversationSource": ".types",
    "ConversationSummaryResponseModel": ".types",
    "ConversationSummaryResponseModelStatus": ".types",
    "ConversationTagResponseModel": ".types",
    "ConversationTokenPurpose": ".types",
    "ConversationTokenResponseModel": ".types",
    "ConversationTtsUsageModel": ".types",
    "ConversationTurnMetrics": ".types",
    "ConversationUserResponseModel": ".types",
    "ConversationVoiceRewardModel": ".types",
    "ConversationVoiceUsageModel": ".types",
    "ConversationalConfig": ".types",
    "ConversationalConfigApiModelWorkflowOverrideInput": ".types",
    "ConversationalConfigApiModelWorkflowOverrideOutput": ".types",
    "ConvertChapterResponseModel": ".types",
    "ConvertProjectResponseModel": ".types",
    "CreateAgentBranchResponseModel": ".types",
    "CreateAgentResponseModel": ".types",
    "CreateAgentRuleParams": ".types",
    "CreateAgentTestFolderResponseModel": ".types",
    "CreateAgentTestResponseModel": ".types",
    "CreateAssetParams": ".types",
    "CreateAudioNativeProjectRequest": ".types",
    "CreateAuthConnectionEnvironmentVariableRequest": ".types",
    "CreateBasicAuthRequest": ".types",
    "CreateBearerAuthRequest": ".types",
    "CreateClientAppointmentParams": ".types",
    "CreateClientInteractionParams": ".types",
    "CreateClientParams": ".types",
    "CreateCustomHeaderAuthRequest": ".types",
    "CreateExotelPhoneNumberRequest": ".types",
    "CreateHolidayParams": ".types",
    "CreateLocationParams": ".types",
    "CreateMtlsAuthRequest": ".types",
    "CreateOAuth2ClientCredsRequest": ".types",
    "CreateOAuth2JwtRequest": ".types",
    "CreateOAuth2JwtRequestAlgorithm": ".types",
    "CreateOAuth2JwtRequestTokenResponseField": ".types",
    "CreateOrderRequest": ".types",
    "CreateOrderResponse": ".types",
    "CreatePhoneNumberResponseModel": ".types",
    "CreatePreviouslyGeneratedVoiceRequest": ".types",
    "CreatePrivateKeyJwtRequest": ".types",
    "CreatePrivateKeyJwtRequestAlgorithm": ".types",
    "CreateProductParams": ".types",
    "CreatePronunciationDictionaryResponseModel": ".types",
    "CreateResponseUnitTestRequest": ".types",
    "CreateSecretEnvironmentVariableRequest": ".types",
    "CreateServiceParams": ".types",
    "CreateSimulationTestRequest": ".types",
    "CreateSipTrunkPhoneNumberRequest": ".types",
    "CreateStaffParams": ".types",
    "CreateStringEnvironmentVariableRequest": ".types",
    "CreateToolCallUnitTestRequest": ".types",
    "CreateTranscriptRequest": ".types",
    "CreateTwilioPhoneNumberRequest": ".types",
    "CueOptionsRequest": ".types",
    "Currency": ".types",
    "CustomGuardrailConfig": ".types",
    "CustomGuardrailConfigModel": ".types",
    "CustomGuardrailConfigTriggerAction": ".types",
    "CustomGuardrailConfigTriggerAction_EndCall": ".types",
    "CustomGuardrailConfigTriggerAction_Retry": ".types",
    "CustomGuardrailInput": ".types",
    "CustomGuardrailOutput": ".types",
    "CustomGuardrailsConfigInput": ".types",
    "CustomGuardrailsConfigOutput": ".types",
    "CustomHeaderAuthResponse": ".types",
    "CustomLlm": ".types",
    "CustomLlmApiKey": ".types",
    "CustomLlmAuthConnection": ".types",
    "CustomLlmRequestHeadersValue": ".types",
    "CustomLlmapiType": ".types",
    "CustomSipHeader": ".types",
    "CustomSipHeaderWithDynamicVariable": ".types",
    "DashboardCallSuccessChartModel": ".types",
    "DashboardCriteriaChartModel": ".types",
    "DashboardDataCollectionChartModel": ".types",
    "DataCollectionResultCommonModel": ".types",
    "DefaultSharingGroupResponseModel": ".types",
    "DefaultSharingGroupResponseModelPermissionLevel": ".types",
    "DeleteAgentRuleParams": ".types",
    "DeleteAssetParams": ".types",
    "DeleteCalendarEventParams": ".types",
    "DeleteChapterRequest": ".types",
    "DeleteChapterResponseModel": ".types",
    "DeleteClientInteractionParams": ".types",
    "DeleteClientParams": ".types",
    "DeleteDubbingResponseModel": ".types",
    "DeleteGroupSessionParams": ".types",
    "DeleteHistoryItemResponse": ".types",
    "DeleteHolidayParams": ".types",
    "DeleteLocationParams": ".types",
    "DeleteProductParams": ".types",
    "DeleteProjectRequest": ".types",
    "DeleteProjectResponseModel": ".types",
    "DeleteSampleResponse": ".types",
    "DeleteServiceParams": ".types",
    "DeleteStaffParams": ".types",
    "DeleteVoiceResponseModel": ".types",
    "DeleteVoiceSampleResponseModel": ".types",
    "DeleteWorkspaceGroupMemberResponseModel": ".types",
    "DeleteWorkspaceInviteResponseModel": ".types",
    "DeleteWorkspaceWebhookResponseModel": ".types",
    "DeliverableInfo": ".types",
    "DependentAvailableAgentIdentifier": ".types",
    "DependentAvailableAgentIdentifierAccessLevel": ".types",
    "DependentAvailableMcpServerIdentifier": ".types",
    "DependentAvailableMcpServerIdentifierAccessLevel": ".types",
    "DependentAvailableToolIdentifier": ".types",
    "DependentAvailableToolIdentifierAccessLevel": ".types",
    "DependentBranchInfo": ".types",
    "DependentIntegrationConnectionIdentifier": ".types",
    "DependentPhoneNumberIdentifier": ".types",
    "DependentUnknownAgentIdentifier": ".types",
    "DependentUnknownMcpServerIdentifier": ".types",
    "DependentUnknownToolIdentifier": ".types",
    "DetailedMusicResponse": ".types",
    "DetailedMusicResponseCompositionPlan": ".types",
    "DetectedEntity": ".types",
    "DeviceModel": ".types",
    "DialogueInput": ".types",
    "DialogueInputResponseModel": ".types",
    "DialogueTextAlignment": ".types",
    "DirectPublishingReadResponseModel": ".types",
    "DirectPublishingReadResponseModelDisplayMode": ".types",
    "DirectPublishingReadResponseModelGenreItem": ".types",
    "DirectPublishingReadResponseModelPayoutType": ".types",
    "DirectPublishingReadResponseModelTargetAudience": ".types",
    "DiscountResponseModel": ".types",
    "DoDubbingResponse": ".types",
    "DocumentUsageModeEnum": ".types",
    "DocxExportOptions": ".types",
    "DtmfInputConfig": ".types",
    "DubOrderItemRequest": ".types",
    "DubbedSegment": ".types",
    "DubbingCreateRequestMode": ".dubbing",
    "DubbingListRequestCreationSourcesItem": ".dubbing",
    "DubbingListRequestDubbingModelsItem": ".dubbing",
    "DubbingListRequestDubbingStatus": ".dubbing",
    "DubbingListRequestDubbingStatusesItem": ".dubbing",
    "DubbingListRequestFilterByCreator": ".dubbing",
    "DubbingListRequestOrderBy": ".dubbing",
    "DubbingListRequestOrderDirection": ".dubbing",
    "DubbingMediaMetadata": ".types",
    "DubbingMediaReference": ".types",
    "DubbingMetadataPageResponseModel": ".types",
    "DubbingMetadataResponse": ".types",
    "DubbingRenderResponseModel": ".types",
    "DubbingResource": ".types",
    "DubbingTranscript": ".types",
    "DubbingTranscriptCharacter": ".types",
    "DubbingTranscriptResponseModel": ".types",
    "DubbingTranscriptUtterance": ".types",
    "DubbingTranscriptWord": ".types",
    "DubbingTranscriptsResponseModel": ".types",
    "DubbingTranscriptsResponseModelTranscriptFormat": ".types",
    "DynamicVariableAssignment": ".types",
    "DynamicVariableNestedValueTypeInput": ".types",
    "DynamicVariableNestedValueTypeOutput": ".types",
    "DynamicVariableSchemaOverride": ".types",
    "DynamicVariableUpdateCommonModel": ".types",
    "DynamicVariableValueTypeInput": ".types",
    "DynamicVariableValueTypeOutput": ".types",
    "DynamicVariablesConfigInput": ".types",
    "DynamicVariablesConfigOutput": ".types",
    "DynamicVariablesConfigWorkflowOverrideInput": ".types",
    "DynamicVariablesConfigWorkflowOverrideOutput": ".types",
    "Eagerness": ".types",
    "EditChapterResponseModel": ".types",
    "EditProjectResponseModel": ".types",
    "EditVoiceResponseModel": ".types",
    "EditVoiceSettingsRequest": ".types",
    "EditVoiceSettingsResponseModel": ".types",
    "ElevenLabs": ".client",
    "ElevenLabsEnvironment": ".environment",
    "EmbedVariant": ".types",
    "EmbeddingModelEnum": ".types",
    "EndCallToolConfig": ".types",
    "EndCallToolResultModel": ".types",
    "EndCallTriggerAction": ".types",
    "EndProcedureToolConfigInput": ".types",
    "EndProcedureToolConfigOutput": ".types",
    "EndProcedureToolErrorStatus": ".types",
    "EntityManagementActivityId": ".types",
    "EntryBehavior": ".types",
    "EnvironmentAuthConnectionLocator": ".types",
    "EnvironmentVariableAuthConnectionValue": ".types",
    "EnvironmentVariableAuthConnectionValueRequest": ".types",
    "EnvironmentVariableResponse": ".types",
    "EnvironmentVariableResponseType": ".types",
    "EnvironmentVariableResponseValues": ".types",
    "EnvironmentVariableSecretValue": ".types",
    "EnvironmentVariableSecretValueRequest": ".types",
    "EnvironmentVariablesCreateRequestBody": ".environment_variables",
    "EnvironmentVariablesCreateRequestBody_AuthConnection": ".environment_variables",
    "EnvironmentVariablesCreateRequestBody_Secret": ".environment_variables",
    "EnvironmentVariablesCreateRequestBody_String": ".environment_variables",
    "EnvironmentVariablesListRequestType": ".environment_variables",
    "EnvironmentVariablesListResponse": ".types",
    "ErrorPayload": ".types",
    "EvaluationSettingsInput": ".types",
    "EvaluationSettingsOutput": ".types",
    "EvaluationSuccessResult": ".types",
    "ExactParameterEvaluationStrategy": ".types",
    "ExotelApiSubdomain": ".types",
    "ExotelOutboundCallResponse": ".types",
    "ExportOptions": ".types",
    "ExportOptions_Docx": ".types",
    "ExportOptions_Html": ".types",
    "ExportOptions_Pdf": ".types",
    "ExportOptions_SegmentedJson": ".types",
    "ExportOptions_Srt": ".types",
    "ExportOptions_Txt": ".types",
    "ExtendedSubscriptionResponseModelMaxCreditLimitExtension": ".types",
    "ExtendedSubscriptionResponseModelPendingChange": ".types",
    "ExternalFileSyncInfo": ".types",
    "ExternalFolderSyncInfo": ".types",
    "ExternalSyncType": ".types",
    "FeatureStatusCommonModel": ".types",
    "FeaturesUsageCommonModel": ".types",
    "FeedbackItem": ".types",
    "FileInputConfig": ".types",
    "FileInputConfigWorkflowOverride": ".types",
    "FinalOutput": ".types",
    "FinalOutputMulti": ".types",
    "FineTuningResponse": ".types",
    "FineTuningResponseModelStateValue": ".types",
    "FlushContext": ".types",
    "FocusGuardrail": ".types",
    "ForbiddenError": ".errors",
    "ForcedAlignmentCharacterResponseModel": ".types",
    "ForcedAlignmentResponseModel": ".types",
    "ForcedAlignmentWordResponseModel": ".types",
    "Gender": ".types",
    "GenerateVoiceRequest": ".types",
    "GenerationChunkInput": ".types",
    "GenerationChunkInputConditionStrength": ".types",
    "GenerationChunkInputContextAdherence": ".types",
    "GenerationChunkOutput": ".types",
    "GenerationChunkOutputConditionStrength": ".types",
    "GenerationChunkOutputContextAdherence": ".types",
    "GenerationConfig": ".types",
    "GenerationSourceContext": ".types",
    "GenesysRegion": ".types",
    "GetAgentEmbedResponseModel": ".types",
    "GetAgentKnowledgebaseSizeResponseModel": ".types",
    "GetAgentLinkResponseModel": ".types",
    "GetAgentResponseModel": ".types",
    "GetAgentResponseModelPhoneNumbersItem": ".types",
    "GetAgentResponseModelPhoneNumbersItem_Exotel": ".types",
    "GetAgentResponseModelPhoneNumbersItem_SipTrunk": ".types",
    "GetAgentResponseModelPhoneNumbersItem_Twilio": ".types",
    "GetAgentTestFolderResponseModel": ".types",
    "GetAgentTopicsResponseModel": ".types",
    "GetAgentsPageResponseModel": ".types",
    "GetAnalyticsSummaryParams": ".types",
    "GetAppointmentByConfirmationNumberParams": ".types",
    "GetAudioIsolationHistoryResponseModel": ".types",
    "GetAudioNativeProjectSettingsResponseModel": ".types",
    "GetBookingPageSettingsParams": ".types",
    "GetBookingSlugStatusParams": ".types",
    "GetChapterRequest": ".types",
    "GetChapterSnapshotsRequest": ".types",
    "GetChaptersRequest": ".types",
    "GetChaptersResponse": ".types",
    "GetClientAppointmentsParams": ".types",
    "GetClientByPhoneParams": ".types",
    "GetConvAiDashboardSettingsResponseModel": ".types",
    "GetConvAiDashboardSettingsResponseModelChartsItem": ".types",
    "GetConvAiDashboardSettingsResponseModelChartsItem_CallSuccess": ".types",
    "GetConvAiDashboardSettingsResponseModelChartsItem_Criteria": ".types",
    "GetConvAiDashboardSettingsResponseModelChartsItem_DataCollection": ".types",
    "GetConvAiSettingsResponseModel": ".types",
    "GetConversationResponseModel": ".types",
    "GetConversationResponseModelStatus": ".types",
    "GetConversationTagsPageResponseModel": ".types",
    "GetConversationUsersPageResponseModel": ".types",
    "GetConversationsPageResponseModel": ".types",
    "GetKnowledgeBaseDependentAgentsResponseModel": ".types",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem": ".types",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available": ".types",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown": ".types",
    "GetKnowledgeBaseFileResponseModel": ".types",
    "GetKnowledgeBaseFolderResponseModel": ".types",
    "GetKnowledgeBaseListResponseModel": ".types",
    "GetKnowledgeBaseListResponseModelDocumentsItem": ".types",
    "GetKnowledgeBaseListResponseModelDocumentsItem_File": ".types",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Folder": ".types",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Text": ".types",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Url": ".types",
    "GetKnowledgeBaseSummaryFileResponseModel": ".types",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem": ".types",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available": ".types",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown": ".types",
    "GetKnowledgeBaseSummaryFolderResponseModel": ".types",
    "GetKnowledgeBaseSummaryFolderResponseModelDependentAgentsItem": ".types",
    "GetKnowledgeBaseSummaryFolderResponseModelDependentAgentsItem_Available": ".types",
    "GetKnowledgeBaseSummaryFolderResponseModelDependentAgentsItem_Unknown": ".types",
    "GetKnowledgeBaseSummaryTextResponseModel": ".types",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem": ".types",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Available": ".types",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Unknown": ".types",
    "GetKnowledgeBaseSummaryUrlResponseModel": ".types",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem": ".types",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available": ".types",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown": ".types",
    "GetKnowledgeBaseTextResponseModel": ".types",
    "GetKnowledgeBaseUrlResponseModel": ".types",
    "GetLibraryVoicesResponse": ".types",
    "GetLiveCountResponse": ".types",
    "GetOrCreateRagIndexRequestModel": ".types",
    "GetPhoneNumberExotelResponseModel": ".types",
    "GetPhoneNumberInboundSipTrunkConfigResponseModel": ".types",
    "GetPhoneNumberOutboundSipTrunkConfigResponseModel": ".types",
    "GetPhoneNumberResponse": ".types",
    "GetPhoneNumberSipTrunkResponseModel": ".types",
    "GetPhoneNumberTwilioResponseModel": ".types",
    "GetProjectRequest": ".types",
    "GetProjectsRequest": ".types",
    "GetProjectsResponse": ".types",
    "GetPronunciationDictionariesMetadataResponseModel": ".types",
    "GetPronunciationDictionariesResponse": ".types",
    "GetPronunciationDictionaryMetadataResponse": ".types",
    "GetPronunciationDictionaryMetadataResponseModelPermissionOnResource": ".types",
    "GetPronunciationDictionaryResponse": ".types",
    "GetPronunciationDictionaryWithRulesResponseModel": ".types",
    "GetPronunciationDictionaryWithRulesResponseModelPermissionOnResource": ".types",
    "GetPronunciationDictionaryWithRulesResponseModelRulesItem": ".types",
    "GetPronunciationDictionaryWithRulesResponseModelRulesItem_Alias": ".types",
    "GetPronunciationDictionaryWithRulesResponseModelRulesItem_Phoneme": ".types",
    "GetResponseUnitTestResponseModel": ".types",
    "GetScheduleParams": ".types",
    "GetSecretDependenciesResponseModel": ".types",
    "GetSecretDependenciesResponseModelDependencies": ".types",
    "GetSecretDependenciesResponseModelDependenciesOneItem": ".types",
    "GetSecretDependenciesResponseModelDependenciesOneItem_Available": ".types",
    "GetSecretDependenciesResponseModelDependenciesOneItem_Unknown": ".types",
    "GetSecretDependenciesResponseModelDependenciesZeroItem": ".types",
    "GetSecretDependenciesResponseModelDependenciesZeroItem_Available": ".types",
    "GetSecretDependenciesResponseModelDependenciesZeroItem_Unknown": ".types",
    "GetSimulationTestResponseModel": ".types",
    "GetSipLogMessagesResponse": ".types",
    "GetSpeechHistoryResponse": ".types",
    "GetTestInvocationsPageResponseModel": ".types",
    "GetTestSuiteInvocationResponseModel": ".types",
    "GetTestsPageResponseModel": ".types",
    "GetTestsSummariesByIdsResponseModel": ".types",
    "GetToolCallUnitTestResponseModel": ".types",
    "GetToolDependentAgentsResponseModel": ".types",
    "GetToolDependentAgentsResponseModelAgentsItem": ".types",
    "GetToolDependentAgentsResponseModelAgentsItem_Available": ".types",
    "GetToolDependentAgentsResponseModelAgentsItem_Unknown": ".types",
    "GetToolExecutionsPageResponseModel": ".types",
    "GetVoicesResponse": ".types",
    "GetVoicesV2Response": ".types",
    "GetWhatsAppAccountResponse": ".types",
    "GetWorkspaceSecretsResponseModel": ".types",
    "GroupManagementActivityId": ".types",
    "GuardrailExecutionMode": ".types",
    "GuardrailsV1Input": ".types",
    "GuardrailsV1Output": ".types",
    "HistoryAlignmentResponseModel": ".types",
    "HistoryAlignmentsResponseModel": ".types",
    "HistoryItemResponse": ".types",
    "HistoryListRequestSortDirection": ".history",
    "HistoryListRequestSource": ".history",
    "HtmlExportOptions": ".types",
    "HttpRequestModel": ".types",
    "HttpValidationError": ".types",
    "Icon": ".types",
    "ImageAnalysis": ".types",
    "ImageAnalysisResult": ".types",
    "ImageAnalysisStatus": ".types",
    "ImageAvatar": ".types",
    "ImageSubject": ".types",
    "InboundSipTrunkConfigRequestModel": ".types",
    "InitPayload": ".types",
    "InitialiseContext": ".types",
    "InitializeConnection": ".types",
    "InitializeConnectionMulti": ".types",
    "InputAudioChunkPayload": ".types",
    "IntegrationType": ".types",
    "InteractionBudget": ".types",
    "InvoiceResponse": ".types",
    "InvoiceResponseModelPaymentIntentStatus": ".types",
    "InvoiceResponseModelPaymentIntentStatussesItem": ".types",
    "ItemId": ".types",
    "KeepContextAlive": ".types",
    "KnowledgeBaseContentSearchResponseModel": ".types",
    "KnowledgeBaseContentSearchResult": ".types",
    "KnowledgeBaseContentSearchResultDocument": ".types",
    "KnowledgeBaseContentSearchResultDocument_File": ".types",
    "KnowledgeBaseContentSearchResultDocument_Folder": ".types",
    "KnowledgeBaseContentSearchResultDocument_Text": ".types",
    "KnowledgeBaseContentSearchResultDocument_Url": ".types",
    "KnowledgeBaseDependentType": ".types",
    "KnowledgeBaseDocumentChunkResponseModel": ".types",
    "KnowledgeBaseDocumentChunksResponseModel": ".types",
    "KnowledgeBaseDocumentMetadataResponseModel": ".types",
    "KnowledgeBaseDocumentType": ".types",
    "KnowledgeBaseFolderPathSegmentResponseModel": ".types",
    "KnowledgeBaseFolderPathSegmentSummaryResponseModel": ".types",
    "KnowledgeBaseLocator": ".types",
    "KnowledgeBaseRagToolConfig": ".types",
    "KnowledgeBaseRagToolResultModel": ".types",
    "KnowledgeBaseRagToolStatus": ".types",
    "KnowledgeBaseSortBy": ".types",
    "KnowledgeBaseSourceFileUrlResponseModel": ".types",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModel": ".types",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModelData": ".types",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModelData_File": ".types",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModelData_Folder": ".types",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModelData_Text": ".types",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModelData_Url": ".types",
    "LanguageAddedResponse": ".types",
    "LanguageDetectionToolConfig": ".types",
    "LanguageDetectionToolResultModel": ".types",
    "LanguageInfo": ".types",
    "LanguagePairInfo": ".types",
    "LanguagePresetInput": ".types",
    "LanguagePresetOutput": ".types",
    "LanguagePresetTranslation": ".types",
    "LanguageResponse": ".types",
    "LanguagesResponse": ".types",
    "LanguagesResponse_Pair": ".types",
    "LanguagesResponse_Single": ".types",
    "LeaveMessageParams": ".types",
    "LibraryVoiceResponse": ".types",
    "LibraryVoiceResponseModelCategory": ".types",
    "ListAgentRulesParams": ".types",
    "ListAssetsParams": ".types",
    "ListAuthConnectionsResponse": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_ApiIntegrationOauth2AuthCode": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_ApiIntegrationOauth2CustomApp": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_BasicAuth": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_BearerAuth": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_CustomHeaderAuth": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_Mtls": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_Oauth2ClientCredentials": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_Oauth2Jwt": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_PrivateKeyJwt": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_SlackBotAuth": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_UrlSecret": ".types",
    "ListAuthConnectionsResponseAuthConnectionsItem_WhatsappAuth": ".types",
    "ListCalendarEventsParams": ".types",
    "ListClientInteractionsParams": ".types",
    "ListClientsParams": ".types",
    "ListCustomerFacingAgentsParams": ".types",
    "ListGroupSessionsParams": ".types",
    "ListHolidaysParams": ".types",
    "ListLocationsParams": ".types",
    "ListMcpToolsResponseModel": ".types",
    "ListOrdersResponse": ".types",
    "ListProductsParams": ".types",
    "ListResponseAgentBranchSummary": ".types",
    "ListResponseMeta": ".types",
    "ListServicesParams": ".types",
    "ListSpeechEnginesResponse": ".types",
    "ListStaffParams": ".types",
    "ListWhatsAppAccountsResponse": ".types",
    "LiteralJsonSchemaProperty": ".types",
    "LiteralJsonSchemaPropertyConstantValue": ".types",
    "LiteralJsonSchemaPropertyType": ".types",
    "LivekitStackType": ".types",
    "Llm": ".types",
    "LlmCategoryUsage": ".types",
    "LlmDeprecationConfigModel": ".types",
    "LlmDeprecationInfoModel": ".types",
    "LlmInfoModelInput": ".types",
    "LlmInfoModelOutput": ".types",
    "LlmInputOutputTokensUsage": ".types",
    "LlmListResponseModelInput": ".types",
    "LlmListResponseModelOutput": ".types",
    "LlmLiteralJsonSchemaProperty": ".types",
    "LlmLiteralJsonSchemaPropertyType": ".types",
    "LlmParameterEvaluationStrategy": ".types",
    "LlmReasoningEffort": ".types",
    "LlmSchemaOverride": ".types",
    "LlmTokensCategoryUsage": ".types",
    "LlmUsageCalculatorLlmResponseModel": ".types",
    "LlmUsageCalculatorResponseModel": ".types",
    "LlmUsageInput": ".types",
    "LlmUsageOutput": ".types",
    "LoadMemoryEntryToolErrorStatus": ".types",
    "LoadableMemoryEntry": ".types",
    "LockReason": ".types",
    "ManualSource": ".types",
    "ManualVerificationFileResponse": ".types",
    "ManualVerificationResponse": ".types",
    "MatchAnythingParameterEvaluationStrategy": ".types",
    "McpApprovalPolicy": ".types",
    "McpServerConfigInput": ".types",
    "McpServerConfigInputAuthConnection": ".types",
    "McpServerConfigInputRequestHeadersValue": ".types",
    "McpServerConfigInputSecretToken": ".types",
    "McpServerConfigInputUrl": ".types",
    "McpServerConfigOutput": ".types",
    "McpServerConfigOutputAuthConnection": ".types",
    "McpServerConfigOutputRequestHeadersValue": ".types",
    "McpServerConfigOutputSecretToken": ".types",
    "McpServerConfigOutputUrl": ".types",
    "McpServerMetadataResponseModel": ".types",
    "McpServerResponseModel": ".types",
    "McpServerResponseModelDependentAgentsItem": ".types",
    "McpServerResponseModelDependentAgentsItem_Available": ".types",
    "McpServerResponseModelDependentAgentsItem_Unknown": ".types",
    "McpServerTransport": ".types",
    "McpServersResponseModel": ".types",
    "McpToolApprovalHash": ".types",
    "McpToolApprovalPolicy": ".types",
    "McpToolConfigOverrideInput": ".types",
    "McpToolConfigOverrideInputInputOverridesValue": ".types",
    "McpToolConfigOverrideInputInputOverridesValue_Constant": ".types",
    "McpToolConfigOverrideInputInputOverridesValue_DynamicVariable": ".types",
    "McpToolConfigOverrideInputInputOverridesValue_Llm": ".types",
    "McpToolConfigOverrideInputInputOverridesValue_Omit": ".types",
    "McpToolConfigOverrideOutput": ".types",
    "McpToolConfigOverrideOutputInputOverridesValue": ".types",
    "McpToolConfigOverrideOutputInputOverridesValue_Constant": ".types",
    "McpToolConfigOverrideOutputInputOverridesValue_DynamicVariable": ".types",
    "McpToolConfigOverrideOutputInputOverridesValue_Llm": ".types",
    "McpToolConfigOverrideOutputInputOverridesValue_Omit": ".types",
    "MediaCodec": ".types",
    "MediaId": ".types",
    "MemoryEntrySearchResult": ".types",
    "MemoryEntrySearchResultSource": ".types",
    "MessageSearchSortBy": ".types",
    "MessagesSearchResponse": ".types",
    "MessagesSearchResult": ".types",
    "MetricRecord": ".types",
    "MetricType": ".types",
    "MockNoMatchBehavior": ".types",
    "MockingStrategy": ".types",
    "Model": ".types",
    "ModelRatesResponseModel": ".types",
    "ModelSettingsResponseModel": ".types",
    "ModerationConfig": ".types",
    "ModerationGuardrailInput": ".types",
    "ModerationGuardrailOutput": ".types",
    "MtlsAuthResponse": ".types",
    "MultichannelSpeechToTextResponseModel": ".types",
    "MultipartMusicResponse": ".types",
    "MusicAllowedOutputFormats": ".types",
    "MusicComposeDetailedRequestOutputFormat": ".music",
    "MusicComposeRequestOutputFormat": ".music",
    "MusicExploreSongSourceContext": ".types",
    "MusicGenerationMode": ".types",
    "MusicOnlyOutputFormats": ".types",
    "MusicOutputFormat": ".types",
    "MusicPrompt": ".types",
    "MusicSeparateStemsRequestStemVariationId": ".music",
    "MusicStreamRequestOutputFormat": ".music",
    "MusicUploadResponse": ".types",
    "MusicUploadResponseCompositionPlan": ".types",
    "MusicVideoToMusicRequestModelId": ".music",
    "NonStreamingOutputFormats": ".types",
    "NormalizedAlignment": ".types",
    "NotFoundError": ".errors",
    "OAuth2ClientCredsResponse": ".types",
    "OAuth2JwtResponse": ".types",
    "OAuth2JwtResponseAlgorithm": ".types",
    "OAuth2JwtResponseTokenResponseField": ".types",
    "OAuthConnectionStatus": ".types",
    "ObjectJsonSchemaPropertyInput": ".types",
    "ObjectJsonSchemaPropertyInputPropertiesValue": ".types",
    "ObjectJsonSchemaPropertyOutput": ".types",
    "ObjectJsonSchemaPropertyOutputPropertiesValue": ".types",
    "OmitSchemaOverride": ".types",
    "OpenAiAudioConfig": ".types",
    "OpenAiAudioFormat": ".types",
    "OpenAiAudioInputConfig": ".types",
    "OpenAiAudioInputFormat": ".types",
    "OpenAiAudioOutputConfig": ".types",
    "OpenAiAudioOutputFormat": ".types",
    "OpenAiFunctionTool": ".types",
    "OpenAiSessionConfig": ".types",
    "OpenAiSessionConfigMaxResponseOutputTokens": ".types",
    "OpenAiSessionConfigToolChoice": ".types",
    "OpenAiSessionConfigToolsItem": ".types",
    "OpenAiSessionConfigToolsItem_Function": ".types",
    "OpenAiSessionConfigToolsItem_Mcp": ".types",
    "OpenAiToolChoiceFunction": ".types",
    "OpenAiToolChoiceFunctionInner": ".types",
    "OpenAiTurnDetection": ".types",
    "OpenAimcpTool": ".types",
    "OpenAimcpToolRequireApproval": ".types",
    "OptInSmsReminderParams": ".types",
    "OptOutSmsReminderParams": ".types",
    "OrbAvatar": ".types",
    "OrchestratorToolMockBehaviorConfig": ".types",
    "OrderDeliverablesResponse": ".types",
    "OrderId": ".types",
    "OrderItemInfo": ".types",
    "OrderItemKind": ".types",
    "OrderItemRequestInput": ".types",
    "OrderItemRequestInput_Dub": ".types",
    "OrderItemRequestInput_Subtitles": ".types",
    "OrderItemRequestOutput": ".types",
    "OrderItemRequestOutput_Dub": ".types",
    "OrderItemRequestOutput_Subtitles": ".types",
    "OrderMediaResponse": ".types",
    "OrderRequestState": ".types",
    "OrderResponse": ".types",
    "OrderState": ".types",
    "OrderSummary": ".types",
    "OutboundCallRecipient": ".types",
    "OutboundCallRecipientResponseModel": ".types",
    "OutboundSipTrunkConfigRequestModel": ".types",
    "OutputFormat": ".types",
    "PairedLanguagesResponse": ".types",
    "PartialTranscriptPayload": ".types",
    "PatchWorkspaceWebhookResponseModel": ".types",
    "PdfExportOptions": ".types",
    "PendingBlocksMetadataModel": ".types",
    "PendingCancellationResponseModel": ".types",
    "PendingClipTask": ".types",
    "PendingClipTaskType": ".types",
    "PendingExternalAudiosMetadataModel": ".types",
    "PendingSubscriptionSwitchResponseModel": ".types",
    "PendingSubscriptionSwitchResponseModelNextTier": ".types",
    "PermissionType": ".types",
    "PhoneNumberAgentInfo": ".types",
    "PhoneNumberDynamicVariableTransferDestination": ".types",
    "PhoneNumberTransfer": ".types",
    "PhoneNumberTransferCustomSipHeadersItem": ".types",
    "PhoneNumberTransferCustomSipHeadersItem_Dynamic": ".types",
    "PhoneNumberTransferCustomSipHeadersItem_Static": ".types",
    "PhoneNumberTransferDestination": ".types",
    "PhoneNumberTransferPostDialDigits": ".types",
    "PhoneNumberTransferPostDialDigits_Dynamic": ".types",
    "PhoneNumberTransferPostDialDigits_Static": ".types",
    "PhoneNumberTransferTransferDestination": ".types",
    "PhoneNumberTransferTransferDestination_Phone": ".types",
    "PhoneNumberTransferTransferDestination_PhoneDynamicVariable": ".types",
    "PhoneNumberTransferTransferDestination_SipUri": ".types",
    "PhoneNumberTransferTransferDestination_SipUriDynamicVariable": ".types",
    "PingPayload": ".types",
    "PlayDtmfResultErrorModel": ".types",
    "PlayDtmfResultSuccessModel": ".types",
    "PlayDtmfToolConfig": ".types",
    "PodcastBulletinMode": ".types",
    "PodcastBulletinModeData": ".types",
    "PodcastConversationMode": ".types",
    "PodcastConversationModeData": ".types",
    "PodcastProjectResponseModel": ".types",
    "PodcastTextSource": ".types",
    "PodcastUrlSource": ".types",
    "PongPayload": ".types",
    "PositionInput": ".types",
    "PositionOutput": ".types",
    "PostAgentAvatarResponseModel": ".types",
    "PostDialDigitsDynamicVariable": ".types",
    "PostDialDigitsStatic": ".types",
    "PostWorkspaceSecretResponseModel": ".types",
    "PreToolSpeechMode": ".types",
    "PreviewAudioDbModel": ".types",
    "Price": ".types",
    "PrivacyConfigInput": ".types",
    "PrivacyConfigOutput": ".types",
    "PrivateKeyJwtResponse": ".types",
    "PrivateKeyJwtResponseAlgorithm": ".types",
    "ProcedureAtVersionInput": ".types",
    "ProcedureAtVersionOutput": ".types",
    "ProcedureRefResponseModel": ".types",
    "ProcedureType": ".types",
    "ProjectCreationMetaResponseModel": ".types",
    "ProjectCreationMetaResponseModelStatus": ".types",
    "ProjectCreationMetaResponseModelType": ".types",
    "ProjectExtendedResponse": ".types",
    "ProjectExtendedResponseModelAccessLevel": ".types",
    "ProjectExtendedResponseModelApplyTextNormalization": ".types",
    "ProjectExtendedResponseModelAspectRatio": ".types",
    "ProjectExtendedResponseModelAssetsItem": ".types",
    "ProjectExtendedResponseModelAssetsItem_Audio": ".types",
    "ProjectExtendedResponseModelAssetsItem_Image": ".types",
    "ProjectExtendedResponseModelAssetsItem_Video": ".types",
    "ProjectExtendedResponseModelFiction": ".types",
    "ProjectExtendedResponseModelSourceType": ".types",
    "ProjectExtendedResponseModelTargetAudience": ".types",
    "ProjectExternalAudioResponseModel": ".types",
    "ProjectExternalAudioResponseModelSourceContext": ".types",
    "ProjectExternalAudioResponseModelSourceContext_MusicExploreSong": ".types",
    "ProjectExternalAudioResponseModelSourceContext_Sfx": ".types",
    "ProjectExternalAudioResponseModelSourceContext_Song": ".types",
    "ProjectImageResponseModel": ".types",
    "ProjectMutedTracksResponseModel": ".types",
    "ProjectResponse": ".types",
    "ProjectResponseModelAccessLevel": ".types",
    "ProjectResponseModelAspectRatio": ".types",
    "ProjectResponseModelFiction": ".types",
    "ProjectResponseModelSourceType": ".types",
    "ProjectResponseModelTargetAudience": ".types",
    "ProjectSnapshotExtendedResponseModel": ".types",
    "ProjectSnapshotResponse": ".types",
    "ProjectSnapshotsResponse": ".types",
    "ProjectState": ".types",
    "ProjectVideoResponseModel": ".types",
    "ProjectVideoThumbnailSheetResponseModel": ".types",
    "ProjectVoiceResponseModel": ".types",
    "PromptAgent": ".types",
    "PromptAgentApiModelInput": ".types",
    "PromptAgentApiModelInputBackupLlmConfig": ".types",
    "PromptAgentApiModelInputBackupLlmConfig_Default": ".types",
    "PromptAgentApiModelInputBackupLlmConfig_Disabled": ".types",
    "PromptAgentApiModelInputBackupLlmConfig_Override": ".types",
    "PromptAgentApiModelInputToolsItem": ".types",
    "PromptAgentApiModelInputToolsItem_ApiIntegrationWebhook": ".types",
    "PromptAgentApiModelInputToolsItem_Client": ".types",
    "PromptAgentApiModelInputToolsItem_Mcp": ".types",
    "PromptAgentApiModelInputToolsItem_Smb": ".types",
    "PromptAgentApiModelInputToolsItem_System": ".types",
    "PromptAgentApiModelInputToolsItem_Webhook": ".types",
    "PromptAgentApiModelOutput": ".types",
    "PromptAgentApiModelOutputBackupLlmConfig": ".types",
    "PromptAgentApiModelOutputBackupLlmConfig_Default": ".types",
    "PromptAgentApiModelOutputBackupLlmConfig_Disabled": ".types",
    "PromptAgentApiModelOutputBackupLlmConfig_Override": ".types",
    "PromptAgentApiModelOutputToolsItem": ".types",
    "PromptAgentApiModelOutputToolsItem_ApiIntegrationWebhook": ".types",
    "PromptAgentApiModelOutputToolsItem_Client": ".types",
    "PromptAgentApiModelOutputToolsItem_Mcp": ".types",
    "PromptAgentApiModelOutputToolsItem_Smb": ".types",
    "PromptAgentApiModelOutputToolsItem_System": ".types",
    "PromptAgentApiModelOutputToolsItem_Webhook": ".types",
    "PromptAgentApiModelOverrideConfig": ".types",
    "PromptAgentApiModelOverrideInput": ".types",
    "PromptAgentApiModelOverrideOutput": ".types",
    "PromptAgentApiModelWorkflowOverrideInput": ".types",
    "PromptAgentApiModelWorkflowOverrideInputBackupLlmConfig": ".types",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem": ".types",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_ApiIntegrationWebhook": ".types",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_Client": ".types",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_Mcp": ".types",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_Smb": ".types",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_System": ".types",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_Webhook": ".types",
    "PromptAgentApiModelWorkflowOverrideOutput": ".types",
    "PromptAgentApiModelWorkflowOverrideOutputBackupLlmConfig": ".types",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem": ".types",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_ApiIntegrationWebhook": ".types",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_Client": ".types",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_Mcp": ".types",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_Smb": ".types",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_System": ".types",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_Webhook": ".types",
    "PromptAgentDbModel": ".types",
    "PromptEvaluationCriteria": ".types",
    "PromptInjectionGuardrail": ".types",
    "PronunciationDictionariesCreateFromFileRequestWorkspaceAccess": ".pronunciation_dictionaries",
    "PronunciationDictionariesListRequestSort": ".pronunciation_dictionaries",
    "PronunciationDictionaryAliasRuleRequestModel": ".types",
    "PronunciationDictionaryAliasRuleResponseModel": ".types",
    "PronunciationDictionaryLocator": ".types",
    "PronunciationDictionaryLocatorResponseModel": ".types",
    "PronunciationDictionaryPhonemeRuleRequestModel": ".types",
    "PronunciationDictionaryPhonemeRuleResponseModel": ".types",
    "PronunciationDictionaryRulesResponseModel": ".types",
    "PronunciationDictionaryVersionLocator": ".types",
    "PronunciationDictionaryVersionResponseModel": ".types",
    "PronunciationDictionaryVersionResponseModelPermissionOnResource": ".types",
    "PydanticPronunciationDictionaryVersionLocator": ".types",
    "QualityPresetType": ".types",
    "QueryParamsJsonSchema": ".types",
    "QuoteInfo": ".types",
    "RagChunkMetadata": ".types",
    "RagConfig": ".types",
    "RagConfigWorkflowOverride": ".types",
    "RagDocumentIndexResponseModel": ".types",
    "RagDocumentIndexUsage": ".types",
    "RagDocumentIndexesResponseModel": ".types",
    "RagIndexBatchSuccessfulResponseModel": ".types",
    "RagIndexOverviewEmbeddingModelResponseModel": ".types",
    "RagIndexOverviewResponseModel": ".types",
    "RagIndexStatus": ".types",
    "RagRetrievalInfo": ".types",
    "ReadLegalTerms": ".types",
    "ReadMetadataChapterDbModel": ".types",
    "ReaderResourceResponseModel": ".types",
    "ReaderResourceResponseModelResourceType": ".types",
    "RealtimeAudioOptions": ".realtime",
    "RealtimeConfigSnapshot": ".types",
    "RealtimeConfigSnapshotParents": ".types",
    "RealtimeConnection": ".realtime",
    "RealtimeEvents": ".realtime",
    "RealtimeUrlOptions": ".realtime",
    "RealtimeVoiceSettings": ".types",
    "ReceiveMessage": ".v_1_text_to_speech_voice_id_stream_input",
    "ReceiveMessageMulti": ".v_1_text_to_speech_voice_id_multi_stream_input",
    "ReceiveRttMessage": ".v_1_realtime_translation",
    "ReceiveTextToDialogueWebsocketMessage": ".v_1_text_to_dialogue_stream_input",
    "ReceiveTranscription": ".v_1_speech_to_text_realtime",
    "ReceiveUpstreamMessage": ".speech_engine_upstream",
    "RecordingResponse": ".types",
    "ReferenceVideo": ".types",
    "ReferencedToolCommonModel": ".types",
    "ReferencedToolCommonModelType": ".types",
    "RegexParameterEvaluationStrategy": ".types",
    "RegionConfigRequest": ".types",
    "RegionalProcessingSurchargeInfo": ".types",
    "RegisterForGroupSessionParams": ".types",
    "RegisterMediaResponse": ".types",
    "RemoveMemberFromGroupRequest": ".types",
    "RemoveOrderItemResponse": ".types",
    "Render": ".types",
    "RenderStatus": ".types",
    "RenderType": ".types",
    "ReportKnowledgeGapParams": ".types",
    "RequestPvcManualVerificationResponseModel": ".types",
    "RequiredConstraint": ".types",
    "RequiredConstraints": ".types",
    "ResourceAccessInfo": ".types",
    "ResourceAccessInfoAccessSource": ".types",
    "ResourceAccessInfoAnonymousAccessLevelOverride": ".types",
    "ResourceAccessInfoRole": ".types",
    "ResourceMetadataResponseModel": ".types",
    "ResourceMetadataResponseModelAnonymousAccessLevelOverride": ".types",
    "ResponseFilter": ".types",
    "ResponseFilterMode": ".types",
    "ResponseUnitTestModel": ".types",
    "RestoreCalendarEventParams": ".types",
    "RetryTriggerAction": ".types",
    "ReviewResponseModel": ".types",
    "ReviewResponseModelRejectReasonsItem": ".types",
    "ReviewResponseModelReviewStatus": ".types",
    "ReviewStatus": ".types",
    "RttAudioPayload": ".types",
    "RttEndOfStreamPayload": ".types",
    "RttErrorPayload": ".types",
    "RttFinalTranscriptPayload": ".types",
    "RttInputAudioChunkPayload": ".types",
    "RttInputFormatEnum": ".types",
    "RttOutputFormatEnum": ".types",
    "RttPartialTranscriptPayload": ".types",
    "RttSessionStartedPayload": ".types",
    "RttStatusPayload": ".types",
    "RttTranslationPayload": ".types",
    "SafetyCommonModelInput": ".types",
    "SafetyCommonModelOutput": ".types",
    "SafetyEvaluation": ".types",
    "SafetyResponseModel": ".types",
    "SafetyRule": ".types",
    "SampleConfigDbModel": ".types",
    "SampleConfigDbModelParentType": ".types",
    "SaveVoicePreviewRequest": ".types",
    "SayNodeLiteralMessageInput": ".types",
    "SayNodeLiteralMessageOutput": ".types",
    "SayNodePromptMessageInput": ".types",
    "SayNodePromptMessageOutput": ".types",
    "ScheduleGroupSessionParams": ".types",
    "ScopedAnalysisResult": ".types",
    "ScribeAuthErrorPayload": ".types",
    "ScribeChunkSizeExceededErrorPayload": ".types",
    "ScribeErrorPayload": ".types",
    "ScribeInputErrorPayload": ".types",
    "ScribeInsufficientAudioActivityErrorPayload": ".types",
    "ScribeQueueOverflowErrorPayload": ".types",
    "ScribeQuotaExceededErrorPayload": ".types",
    "ScribeRateLimitedErrorPayload": ".types",
    "ScribeResourceExhaustedErrorPayload": ".types",
    "ScribeSessionTimeLimitExceededErrorPayload": ".types",
    "ScribeThrottledErrorPayload": ".types",
    "ScribeTranscriberErrorPayload": ".types",
    "ScribeUnacceptedTermsErrorPayload": ".types",
    "SearchClientsParams": ".types",
    "SearchHighlightSegment": ".types",
    "SeatType": ".types",
    "SecretDependencyResourceType": ".types",
    "SecretDependencyType": ".types",
    "SectionSource": ".types",
    "SegmentCreateResponse": ".types",
    "SegmentDeleteResponse": ".types",
    "SegmentDubResponse": ".types",
    "SegmentMigrationResponse": ".types",
    "SegmentSubtitleFrame": ".types",
    "SegmentTranscriptionResponse": ".types",
    "SegmentTranslationResponse": ".types",
    "SegmentUpdateResponse": ".types",
    "SegmentedJsonExportOptions": ".types",
    "SendMessage": ".v_1_text_to_speech_voice_id_stream_input",
    "SendMessageMulti": ".v_1_text_to_speech_voice_id_multi_stream_input",
    "SendRttMessage": ".v_1_realtime_translation",
    "SendText": ".types",
    "SendTextMulti": ".types",
    "SendUpstreamMessage": ".speech_engine_upstream",
    "SessionStartedPayload": ".types",
    "SessionStartedPayloadConfig": ".types",
    "SessionStartedPayloadConfigCommitStrategy": ".types",
    "SetBookingSlugParams": ".types",
    "SeverityId": ".types",
    "SfxSourceContext": ".types",
    "ShareOptionResponseModel": ".types",
    "ShareOptionResponseModelType": ".types",
    "SimilarVoice": ".types",
    "SimilarVoicesForSpeakerResponse": ".types",
    "SimulationTestModel": ".types",
    "SimulationToolMockBehaviorConfig": ".types",
    "SingleLanguagesResponse": ".types",
    "SingleTestRunRequestModel": ".types",
    "SingleUseTokenResponseModel": ".types",
    "SingleUseTokenType": ".types",
    "SipLogMessage": ".types",
    "SipLogMessageDirection": ".types",
    "SipMediaEncryptionEnum": ".types",
    "SipTrunkCredentialsRequestModel": ".types",
    "SipTrunkOutboundCallResponse": ".types",
    "SipTrunkTransportEnum": ".types",
    "SipUriDynamicVariableTransferDestination": ".types",
    "SipUriTransferDestination": ".types",
    "SkipTurnToolConfig": ".types",
    "SkipTurnToolResponseModel": ".types",
    "SlackBotAuthResponse": ".types",
    "SmsConversationInfo": ".types",
    "SmsConversationInfoDirection": ".types",
    "SoftTimeoutConfig": ".types",
    "SoftTimeoutConfigOverride": ".types",
    "SoftTimeoutConfigOverrideConfig": ".types",
    "SoftTimeoutConfigWorkflowOverride": ".types",
    "SongMetadata": ".types",
    "SongSection": ".types",
    "SongSourceContext": ".types",
    "SortDirection": ".types",
    "SpeakerAudioResponseModel": ".types",
    "SpeakerCreatedResponse": ".types",
    "SpeakerResponseModel": ".types",
    "SpeakerSegment": ".types",
    "SpeakerSeparationResponseModel": ".types",
    "SpeakerSeparationResponseModelStatus": ".types",
    "SpeakerTrack": ".types",
    "SpeakerUpdatedResponse": ".types",
    "SpeechEngineConfig": ".types",
    "SpeechEngineConfigRequestHeadersValue": ".types",
    "SpeechEngineConversationInitiationClientDataConfig": ".types",
    "SpeechEngineResponse": ".types",
    "SpeechEngineSummaryResponse": ".types",
    "SpeechHistoryItemResponse": ".types",
    "SpeechHistoryItemResponseModelSource": ".types",
    "SpeechHistoryItemResponseModelVoiceCategory": ".types",
    "SpeechToSpeechConvertRequestFileFormat": ".speech_to_speech",
    "SpeechToSpeechConvertRequestOutputFormat": ".speech_to_speech",
    "SpeechToSpeechStreamRequestFileFormat": ".speech_to_speech",
    "SpeechToSpeechStreamRequestOutputFormat": ".speech_to_speech",
    "SpeechToTextCharacterResponseModel": ".types",
    "SpeechToTextChunkResponseModel": ".types",
    "SpeechToTextConvertRequestEntityDetection": ".speech_to_text",
    "SpeechToTextConvertRequestEntityRedaction": ".speech_to_text",
    "SpeechToTextConvertRequestFileFormat": ".speech_to_text",
    "SpeechToTextConvertRequestModelId": ".speech_to_text",
    "SpeechToTextConvertRequestTimestampsGranularity": ".speech_to_text",
    "SpeechToTextConvertRequestWebhookMetadata": ".speech_to_text",
    "SpeechToTextConvertResponse": ".speech_to_text",
    "SpeechToTextWebhookResponseModel": ".types",
    "SpeechToTextWordResponseModel": ".types",
    "SpeechToTextWordResponseModelType": ".types",
    "SpellingPatience": ".types",
    "SrtExportOptions": ".types",
    "StartProcedureToolConfigInput": ".types",
    "StartProcedureToolConfigOutput": ".types",
    "StartProcedureToolErrorStatus": ".types",
    "StartPvcVoiceTrainingResponseModel": ".types",
    "StartSpeakerSeparationResponseModel": ".types",
    "StatusId": ".types",
    "StreamingAudioChunkWithTimestampsAndVoiceSegmentsResponseModel": ".types",
    "StreamingAudioChunkWithTimestampsResponse": ".types",
    "StudioAgentSettingsModel": ".types",
    "StudioAgentToolSettingsModel": ".types",
    "StudioClipReference": ".types",
    "StudioClipReferenceClipType": ".types",
    "StudioTextStyleOutlineModel": ".types",
    "StudioTextStyleShadowModel": ".types",
    "SubmitBusinessInfoParams": ".types",
    "SubmitOrderResponse": ".types",
    "Subscription": ".types",
    "SubscriptionResponse": ".types",
    "SubscriptionResponseModelMaxCreditLimitExtension": ".types",
    "SubscriptionStatusType": ".types",
    "SubtitleOrderItemRequest": ".types",
    "SuggestedAudioTag": ".types",
    "SupportedVoice": ".types",
    "SystemEvaluationCriteria": ".types",
    "SystemToolConfigInput": ".types",
    "SystemToolConfigInputParams": ".types",
    "SystemToolConfigInputParams_EndCall": ".types",
    "SystemToolConfigInputParams_EndProcedure": ".types",
    "SystemToolConfigInputParams_KnowledgeBaseRag": ".types",
    "SystemToolConfigInputParams_LanguageDetection": ".types",
    "SystemToolConfigInputParams_PlayKeypadTouchTone": ".types",
    "SystemToolConfigInputParams_SkipTurn": ".types",
    "SystemToolConfigInputParams_StartProcedure": ".types",
    "SystemToolConfigInputParams_TransferToAgent": ".types",
    "SystemToolConfigInputParams_TransferToNumber": ".types",
    "SystemToolConfigInputParams_VoicemailDetection": ".types",
    "SystemToolConfigOutput": ".types",
    "SystemToolConfigOutputParams": ".types",
    "SystemToolConfigOutputParams_EndCall": ".types",
    "SystemToolConfigOutputParams_EndProcedure": ".types",
    "SystemToolConfigOutputParams_KnowledgeBaseRag": ".types",
    "SystemToolConfigOutputParams_LanguageDetection": ".types",
    "SystemToolConfigOutputParams_PlayKeypadTouchTone": ".types",
    "SystemToolConfigOutputParams_SkipTurn": ".types",
    "SystemToolConfigOutputParams_StartProcedure": ".types",
    "SystemToolConfigOutputParams_TransferToAgent": ".types",
    "SystemToolConfigOutputParams_TransferToNumber": ".types",
    "SystemToolConfigOutputParams_VoicemailDetection": ".types",
    "TelephonyCallConfig": ".types",
    "TelephonyDirection": ".types",
    "TelephonyProvider": ".types",
    "TestConditionRationaleCommonModel": ".types",
    "TestConditionResultCommonModel": ".types",
    "TestFromConversationMetadataInput": ".types",
    "TestFromConversationMetadataOutput": ".types",
    "TestInvocationSummaryResponseModel": ".types",
    "TestRunMetadata": ".types",
    "TestRunMetadataTestType": ".types",
    "TestRunResultBucket": ".types",
    "TestRunResultSummary": ".types",
    "TestRunStatus": ".types",
    "TestSharingMode": ".types",
    "TestToolResultModel": ".types",
    "TestType": ".types",
    "TestsFeatureUsageCommonModel": ".types",
    "TextNormalisationType": ".types",
    "TextToDialogueConvertRequestOutputFormat": ".text_to_dialogue",
    "TextToDialogueConvertWithTimestampsRequestOutputFormat": ".text_to_dialogue",
    "TextToDialogueWebsocketApplyTextNormalizationEnum": ".types",
    "TextToDialogueWebsocketAudioChunk": ".types",
    "TextToDialogueWebsocketClientMessage": ".types",
    "TextToDialogueWebsocketError": ".types",
    "TextToDialogueWebsocketFinal": ".types",
    "TextToDialogueWebsocketFinalAudioForTurn": ".types",
    "TextToDialogueWebsocketOutputFormatEnum": ".types",
    "TextToDialogueWebsocketVoiceInput": ".types",
    "TextToDialogueWebsocketVoiceSettings": ".types",
    "TextToSpeechApplyTextNormalizationEnum": ".types",
    "TextToSpeechCommitStrategy": ".v_1_speech_to_text_realtime",
    "TextToSpeechConvertRequestOutputFormat": ".text_to_speech",
    "TextToSpeechConvertWithTimestampsRequestOutputFormat": ".text_to_speech",
    "TextToSpeechOutputFormatEnum": ".types",
    "TextToSpeechRequest": ".types",
    "TextToSpeechStreamRequest": ".types",
    "TextToSpeechStreamRequestOutputFormat": ".text_to_speech",
    "TextToSpeechStreamWithTimestampsRequest": ".types",
    "TextToSpeechStreamWithTimestampsRequestOutputFormat": ".text_to_speech",
    "TextToSpeechWithTimestampsRequest": ".types",
    "ThresholdGuardrail": ".types",
    "TimeRange": ".types",
    "ToDialogueSettingsResponseModel": ".types",
    "TokenResponseModel": ".types",
    "TooEarlyError": ".errors",
    "Tool": ".types",
    "ToolAnnotations": ".types",
    "ToolCallSoundBehavior": ".types",
    "ToolCallSoundType": ".types",
    "ToolCallUnitTestModel": ".types",
    "ToolErrorHandlingMode": ".types",
    "ToolExecution": ".types",
    "ToolExecutionMode": ".types",
    "ToolExecutionResponseModel": ".types",
    "ToolExecutionResponseModelToolCallDetails": ".types",
    "ToolExecutionResponseModelToolCallDetails_ApiIntegrationWebhook": ".types",
    "ToolExecutionResponseModelToolCallDetails_Client": ".types",
    "ToolExecutionResponseModelToolCallDetails_Mcp": ".types",
    "ToolExecutionResponseModelToolCallDetails_Webhook": ".types",
    "ToolExecutionTaskSupport": ".types",
    "ToolMockConfig": ".types",
    "ToolRequestModel": ".types",
    "ToolRequestModelToolConfig": ".types",
    "ToolRequestModelToolConfig_Client": ".types",
    "ToolRequestModelToolConfig_Mcp": ".types",
    "ToolRequestModelToolConfig_System": ".types",
    "ToolRequestModelToolConfig_Webhook": ".types",
    "ToolResponseMockConfigInput": ".types",
    "ToolResponseMockConfigOutput": ".types",
    "ToolResponseModel": ".types",
    "ToolResponseModelToolConfig": ".types",
    "ToolResponseModelToolConfig_Client": ".types",
    "ToolResponseModelToolConfig_Mcp": ".types",
    "ToolResponseModelToolConfig_System": ".types",
    "ToolResponseModelToolConfig_Webhook": ".types",
    "ToolSortBy": ".types",
    "ToolType": ".types",
    "ToolTypeFilter": ".types",
    "ToolUsageStatsResponseModel": ".types",
    "ToolsResponseModel": ".types",
    "TopicDiscoverySettings": ".types",
    "TranscriptMessage": ".types",
    "TranscriptMessageRole": ".types",
    "TranscriptionWord": ".types",
    "TranscriptionWordType": ".types",
    "TransferBranchInfoDefaultingToMain": ".types",
    "TransferBranchInfoTrafficSplit": ".types",
    "TransferToAgentToolConfig": ".types",
    "TransferToAgentToolResultErrorModel": ".types",
    "TransferToAgentToolResultSuccessModel": ".types",
    "TransferToAgentToolResultSuccessModelBranchInfo": ".types",
    "TransferToAgentToolResultSuccessModelBranchInfo_DefaultingToMain": ".types",
    "TransferToAgentToolResultSuccessModelBranchInfo_TrafficSplit": ".types",
    "TransferToNumberResultErrorModel": ".types",
    "TransferToNumberResultExotelSuccessModel": ".types",
    "TransferToNumberResultSipSuccessModel": ".types",
    "TransferToNumberResultTwilioSuccessModel": ".types",
    "TransferToNumberToolConfigInput": ".types",
    "TransferToNumberToolConfigOutput": ".types",
    "TransferTypeEnum": ".types",
    "TtsConversationalConfigInput": ".types",
    "TtsConversationalConfigOutput": ".types",
    "TtsConversationalConfigOverride": ".types",
    "TtsConversationalConfigOverrideConfig": ".types",
    "TtsConversationalConfigWorkflowOverrideInput": ".types",
    "TtsConversationalConfigWorkflowOverrideOutput": ".types",
    "TtsConversationalModel": ".types",
    "TtsModelFamily": ".types",
    "TtsOptimizeStreamingLatency": ".types",
    "TtsOutputFormat": ".types",
    "TurnConfig": ".types",
    "TurnConfigOverride": ".types",
    "TurnConfigOverrideConfig": ".types",
    "TurnConfigWorkflowOverride": ".types",
    "TurnDetectionType": ".types",
    "TurnEagerness": ".types",
    "TurnMode": ".types",
    "TurnModel": ".types",
    "TwilioEdgeLocation": ".types",
    "TwilioOutboundCallResponse": ".types",
    "TwilioRegionId": ".types",
    "TxtExportOptions": ".types",
    "UnauthorizedError": ".errors",
    "UnitTestRunResponseModel": ".types",
    "UnitTestRunResponseModelTestInfo": ".types",
    "UnitTestRunResponseModelTestInfo_Llm": ".types",
    "UnitTestRunResponseModelTestInfo_Simulation": ".types",
    "UnitTestRunResponseModelTestInfo_Tool": ".types",
    "UnitTestSummaryResponseModel": ".types",
    "UnitTestToolCallEvaluationModelInput": ".types",
    "UnitTestToolCallEvaluationModelOutput": ".types",
    "UnitTestToolCallParameter": ".types",
    "UnitTestToolCallParameterEval": ".types",
    "UnitTestToolCallParameterEval_Anything": ".types",
    "UnitTestToolCallParameterEval_Exact": ".types",
    "UnitTestToolCallParameterEval_Llm": ".types",
    "UnitTestToolCallParameterEval_Regex": ".types",
    "UnitTestWorkflowNodeTransitionEvaluationNodeId": ".types",
    "UnprocessableEntityError": ".errors",
    "UpdateAgentRuleParams": ".types",
    "UpdateAssetParams": ".types",
    "UpdateAudioNativeProjectRequest": ".types",
    "UpdateBasicAuthRequest": ".types",
    "UpdateBookingPageAppearanceParams": ".types",
    "UpdateBookingPageSettingsParams": ".types",
    "UpdateBusinessInfoParams": ".types",
    "UpdateCalendarEventParams": ".types",
    "UpdateChapterRequest": ".types",
    "UpdateClientParams": ".types",
    "UpdateCustomerFacingConfigParams": ".types",
    "UpdateEnvironmentVariableRequestValuesValue": ".environment_variables",
    "UpdateGroupSessionSeatsParams": ".types",
    "UpdateHolidayParams": ".types",
    "UpdateLocationParams": ".types",
    "UpdateOAuth2ClientCredsRequest": ".types",
    "UpdateOAuth2JwtRequest": ".types",
    "UpdateOAuth2JwtRequestAlgorithm": ".types",
    "UpdateOAuth2JwtRequestTokenResponseField": ".types",
    "UpdateOrderRequest": ".types",
    "UpdateOrderResponse": ".types",
    "UpdateProductParams": ".types",
    "UpdateProjectRequest": ".types",
    "UpdatePronunciationDictionariesRequest": ".types",
    "UpdateResponseUnitTestRequest": ".types",
    "UpdateServiceParams": ".types",
    "UpdateSimulationTestRequest": ".types",
    "UpdateStaffParams": ".types",
    "UpdateToolCallUnitTestRequest": ".types",
    "UpdateWorkspaceMemberResponseModel": ".types",
    "UpsertOrderItemRequest": ".types",
    "UpsertOrderItemResponse": ".types",
    "UrlAvatar": ".types",
    "UrlModel": ".types",
    "UrlSecretAuthResponse": ".types",
    "UsageAggregationInterval": ".types",
    "UsageCharactersResponseModel": ".types",
    "User": ".types",
    "UserAccessManagementActivityId": ".types",
    "UserFeedback": ".types",
    "UserFeedbackScore": ".types",
    "UserModel": ".types",
    "UserTranscriptPayload": ".types",
    "UserTypeId": ".types",
    "UsersSortBy": ".types",
    "UtteranceResponseModel": ".types",
    "VadConfig": ".types",
    "VadConfigWorkflowOverride": ".types",
    "ValidationError": ".types",
    "ValidationErrorLocItem": ".types",
    "Verbosity": ".types",
    "VerificationAttemptResponse": ".types",
    "VerifiedVoiceLanguageResponseModel": ".types",
    "VerifyPvcVoiceCaptchaResponseModel": ".types",
    "VideoAnalysis": ".types",
    "VideoAnalysisResult": ".types",
    "VideoAnalysisStatus": ".types",
    "VideoKeyMoment": ".types",
    "VideoSegment": ".types",
    "VideoSubject": ".types",
    "VisitedAgentRef": ".types",
    "Voice": ".types",
    "VoiceCategory": ".types",
    "VoiceDesignPreviewResponse": ".types",
    "VoiceDesignRequestModelModelId": ".text_to_voice",
    "VoiceGenerationParameterOptionResponse": ".types",
    "VoiceGenerationParameterResponse": ".types",
    "VoiceMailDetectionResultSuccessModel": ".types",
    "VoicePreviewResponseModel": ".types",
    "VoiceResponseModelCategory": ".types",
    "VoiceResponseModelLabellingStatus": ".types",
    "VoiceResponseModelRecordingQuality": ".types",
    "VoiceResponseModelSafetyControl": ".types",
    "VoiceSample": ".types",
    "VoiceSamplePreviewResponseModel": ".types",
    "VoiceSampleVisualWaveformResponseModel": ".types",
    "VoiceSegment": ".types",
    "VoiceSettings": ".types",
    "VoiceSharingModerationCheckResponseModel": ".types",
    "VoiceSharingResponse": ".types",
    "VoiceSharingResponseModelCategory": ".types",
    "VoiceSharingState": ".types",
    "VoiceStatisticsResponseModel": ".types",
    "VoiceVerificationResponse": ".types",
    "VoicemailDetectionToolConfig": ".types",
    "VoicesGetSharedRequestCategory": ".voices",
    "VoicesGetSharedRequestSort": ".voices",
    "VoicesUpdateRequestLabels": ".voices",
    "WebhookAuthMethodType": ".types",
    "WebhookEventType": ".types",
    "WebhookHmacSettings": ".types",
    "WebhookToolApiSchemaConfigInput": ".types",
    "WebhookToolApiSchemaConfigInputAuthConnection": ".types",
    "WebhookToolApiSchemaConfigInputContentType": ".types",
    "WebhookToolApiSchemaConfigInputMethod": ".types",
    "WebhookToolApiSchemaConfigInputRequestHeadersValue": ".types",
    "WebhookToolApiSchemaConfigOutput": ".types",
    "WebhookToolApiSchemaConfigOutputAuthConnection": ".types",
    "WebhookToolApiSchemaConfigOutputContentType": ".types",
    "WebhookToolApiSchemaConfigOutputMethod": ".types",
    "WebhookToolApiSchemaConfigOutputRequestHeadersValue": ".types",
    "WebhookToolConfigInput": ".types",
    "WebhookToolConfigOutput": ".types",
    "WebhookTranscriptFormat": ".types",
    "WebhookUsageType": ".types",
    "WebsocketTtsClientMessageMulti": ".types",
    "WebsocketTtsServerMessageMulti": ".types",
    "WhatsAppAuthResponse": ".types",
    "WhatsAppConversationInfo": ".types",
    "WhatsAppConversationInfoDirection": ".types",
    "WhatsAppOutboundCallResponse": ".types",
    "WhatsAppOutboundMessageResponse": ".types",
    "WhatsAppTemplateBodyComponentParams": ".types",
    "WhatsAppTemplateButtonComponentParams": ".types",
    "WhatsAppTemplateDocumentParam": ".types",
    "WhatsAppTemplateDocumentParamDetails": ".types",
    "WhatsAppTemplateHeaderComponentParams": ".types",
    "WhatsAppTemplateHeaderComponentParamsParametersItem": ".types",
    "WhatsAppTemplateHeaderComponentParamsParametersItem_Document": ".types",
    "WhatsAppTemplateHeaderComponentParamsParametersItem_Image": ".types",
    "WhatsAppTemplateHeaderComponentParamsParametersItem_Location": ".types",
    "WhatsAppTemplateHeaderComponentParamsParametersItem_Text": ".types",
    "WhatsAppTemplateImageParam": ".types",
    "WhatsAppTemplateImageParamDetails": ".types",
    "WhatsAppTemplateLocationParam": ".types",
    "WhatsAppTemplateLocationParamDetails": ".types",
    "WhatsAppTemplateTextParam": ".types",
    "WidgetConfig": ".types",
    "WidgetConfigInputAvatar": ".types",
    "WidgetConfigInputAvatar_Image": ".types",
    "WidgetConfigInputAvatar_Orb": ".types",
    "WidgetConfigInputAvatar_Url": ".types",
    "WidgetConfigInputSyntaxHighlightTheme": ".types",
    "WidgetConfigOutputAvatar": ".types",
    "WidgetConfigOutputAvatar_Image": ".types",
    "WidgetConfigOutputAvatar_Orb": ".types",
    "WidgetConfigOutputAvatar_Url": ".types",
    "WidgetConfigOutputSyntaxHighlightTheme": ".types",
    "WidgetConfigResponse": ".types",
    "WidgetConfigResponseModelAvatar": ".types",
    "WidgetConfigResponseModelAvatar_Image": ".types",
    "WidgetConfigResponseModelAvatar_Orb": ".types",
    "WidgetConfigResponseModelAvatar_Url": ".types",
    "WidgetConfigResponseModelSyntaxHighlightTheme": ".types",
    "WidgetEndFeedbackConfig": ".types",
    "WidgetEndFeedbackType": ".types",
    "WidgetExpandable": ".types",
    "WidgetFeedbackMode": ".types",
    "WidgetLanguagePreset": ".types",
    "WidgetLanguagePresetResponse": ".types",
    "WidgetPlacement": ".types",
    "WidgetStyles": ".types",
    "WidgetTermsTranslation": ".types",
    "WidgetTextContents": ".types",
    "WordTimestamp": ".types",
    "WorkflowEdgeModelInput": ".types",
    "WorkflowEdgeModelInputBackwardCondition": ".types",
    "WorkflowEdgeModelInputBackwardCondition_Expression": ".types",
    "WorkflowEdgeModelInputBackwardCondition_Llm": ".types",
    "WorkflowEdgeModelInputBackwardCondition_Result": ".types",
    "WorkflowEdgeModelInputBackwardCondition_Unconditional": ".types",
    "WorkflowEdgeModelInputForwardCondition": ".types",
    "WorkflowEdgeModelInputForwardCondition_Expression": ".types",
    "WorkflowEdgeModelInputForwardCondition_Llm": ".types",
    "WorkflowEdgeModelInputForwardCondition_Result": ".types",
    "WorkflowEdgeModelInputForwardCondition_Unconditional": ".types",
    "WorkflowEdgeModelOutput": ".types",
    "WorkflowEdgeModelOutputBackwardCondition": ".types",
    "WorkflowEdgeModelOutputBackwardCondition_Expression": ".types",
    "WorkflowEdgeModelOutputBackwardCondition_Llm": ".types",
    "WorkflowEdgeModelOutputBackwardCondition_Result": ".types",
    "WorkflowEdgeModelOutputBackwardCondition_Unconditional": ".types",
    "WorkflowEdgeModelOutputForwardCondition": ".types",
    "WorkflowEdgeModelOutputForwardCondition_Expression": ".types",
    "WorkflowEdgeModelOutputForwardCondition_Llm": ".types",
    "WorkflowEdgeModelOutputForwardCondition_Result": ".types",
    "WorkflowEdgeModelOutputForwardCondition_Unconditional": ".types",
    "WorkflowEndNodeModelInput": ".types",
    "WorkflowEndNodeModelOutput": ".types",
    "WorkflowExpressionConditionModelInput": ".types",
    "WorkflowExpressionConditionModelOutput": ".types",
    "WorkflowFeaturesUsageCommonModel": ".types",
    "WorkflowLlmConditionModelInput": ".types",
    "WorkflowLlmConditionModelOutput": ".types",
    "WorkflowOverrideAgentNodeModelInput": ".types",
    "WorkflowOverrideAgentNodeModelOutput": ".types",
    "WorkflowPhoneNumberNodeModelInput": ".types",
    "WorkflowPhoneNumberNodeModelInputCustomSipHeadersItem": ".types",
    "WorkflowPhoneNumberNodeModelInputCustomSipHeadersItem_Dynamic": ".types",
    "WorkflowPhoneNumberNodeModelInputCustomSipHeadersItem_Static": ".types",
    "WorkflowPhoneNumberNodeModelInputPostDialDigits": ".types",
    "WorkflowPhoneNumberNodeModelInputPostDialDigits_Dynamic": ".types",
    "WorkflowPhoneNumberNodeModelInputPostDialDigits_Static": ".types",
    "WorkflowPhoneNumberNodeModelInputTransferDestination": ".types",
    "WorkflowPhoneNumberNodeModelInputTransferDestination_Phone": ".types",
    "WorkflowPhoneNumberNodeModelInputTransferDestination_PhoneDynamicVariable": ".types",
    "WorkflowPhoneNumberNodeModelInputTransferDestination_SipUri": ".types",
    "WorkflowPhoneNumberNodeModelInputTransferDestination_SipUriDynamicVariable": ".types",
    "WorkflowPhoneNumberNodeModelOutput": ".types",
    "WorkflowPhoneNumberNodeModelOutputCustomSipHeadersItem": ".types",
    "WorkflowPhoneNumberNodeModelOutputCustomSipHeadersItem_Dynamic": ".types",
    "WorkflowPhoneNumberNodeModelOutputCustomSipHeadersItem_Static": ".types",
    "WorkflowPhoneNumberNodeModelOutputPostDialDigits": ".types",
    "WorkflowPhoneNumberNodeModelOutputPostDialDigits_Dynamic": ".types",
    "WorkflowPhoneNumberNodeModelOutputPostDialDigits_Static": ".types",
    "WorkflowPhoneNumberNodeModelOutputTransferDestination": ".types",
    "WorkflowPhoneNumberNodeModelOutputTransferDestination_Phone": ".types",
    "WorkflowPhoneNumberNodeModelOutputTransferDestination_PhoneDynamicVariable": ".types",
    "WorkflowPhoneNumberNodeModelOutputTransferDestination_SipUri": ".types",
    "WorkflowPhoneNumberNodeModelOutputTransferDestination_SipUriDynamicVariable": ".types",
    "WorkflowResultConditionModelInput": ".types",
    "WorkflowResultConditionModelOutput": ".types",
    "WorkflowStandaloneAgentNodeModelInput": ".types",
    "WorkflowStandaloneAgentNodeModelOutput": ".types",
    "WorkflowStartNodeModelInput": ".types",
    "WorkflowStartNodeModelOutput": ".types",
    "WorkflowToolEdgeStepModel": ".types",
    "WorkflowToolLocator": ".types",
    "WorkflowToolMaxIterationsExceededStepModel": ".types",
    "WorkflowToolNestedToolsStepModelInput": ".types",
    "WorkflowToolNestedToolsStepModelInputResultsItem": ".types",
    "WorkflowToolNestedToolsStepModelOutput": ".types",
    "WorkflowToolNestedToolsStepModelOutputResultsItem": ".types",
    "WorkflowToolNodeModelInput": ".types",
    "WorkflowToolNodeModelOutput": ".types",
    "WorkflowToolResponseModelInput": ".types",
    "WorkflowToolResponseModelInputStepsItem": ".types",
    "WorkflowToolResponseModelInputStepsItem_Edge": ".types",
    "WorkflowToolResponseModelInputStepsItem_MaxIterationsExceeded": ".types",
    "WorkflowToolResponseModelInputStepsItem_NestedTools": ".types",
    "WorkflowToolResponseModelOutput": ".types",
    "WorkflowToolResponseModelOutputStepsItem": ".types",
    "WorkflowToolResponseModelOutputStepsItem_Edge": ".types",
    "WorkflowToolResponseModelOutputStepsItem_MaxIterationsExceeded": ".types",
    "WorkflowToolResponseModelOutputStepsItem_NestedTools": ".types",
    "WorkflowUnconditionalModelInput": ".types",
    "WorkflowUnconditionalModelOutput": ".types",
    "WorkspaceAnalyticsQueryResponseModel": ".types",
    "WorkspaceAnalyticsQueryResponseModelColumnTypesItem": ".types",
    "WorkspaceAnalyticsQueryResponseModelRowsItemItem": ".types",
    "WorkspaceApiKeyListResponseModel": ".types",
    "WorkspaceApiKeyResponseModel": ".types",
    "WorkspaceAuditLogEntryResponse": ".types",
    "WorkspaceAuditLogEntryResponseActivityId": ".types",
    "WorkspaceAuditLogsPageResponse": ".types",
    "WorkspaceBatchCallsResponse": ".types",
    "WorkspaceCreateApiKeyResponseModel": ".types",
    "WorkspaceCreateWebhookResponseModel": ".types",
    "WorkspaceGroupByNameResponseModel": ".types",
    "WorkspaceGroupPermission": ".types",
    "WorkspaceGroupResponseModel": ".types",
    "WorkspaceGroupResponseModelGroupPvcLimit": ".types",
    "WorkspaceGroupResponseModelGroupUsageLimit": ".types",
    "WorkspaceResourceType": ".types",
    "WorkspaceServiceAccountListResponseModel": ".types",
    "WorkspaceServiceAccountResponseModel": ".types",
    "WorkspaceWebhookListResponseModel": ".types",
    "WorkspaceWebhookResponseModel": ".types",
    "WorkspaceWebhookUsageResponseModel": ".types",
    "__version__": ".version",
    "audio_isolation": ".audio_isolation",
    "audio_native": ".audio_native",
    "conversational_ai": ".conversational_ai",
    "dubbing": ".dubbing",
    "environment_variables": ".environment_variables",
    "forced_alignment": ".forced_alignment",
    "history": ".history",
    "models": ".models",
    "music": ".music",
    "play": ".play",
    "productions": ".productions",
    "pronunciation_dictionaries": ".pronunciation_dictionaries",
    "samples": ".samples",
    "save": ".play",
    "service_accounts": ".service_accounts",
    "speech_engine": ".speech_engine",
    "speech_engine_upstream": ".speech_engine_upstream",
    "speech_to_speech": ".speech_to_speech",
    "speech_to_text": ".speech_to_text",
    "stream": ".play",
    "studio": ".studio",
    "text_to_dialogue": ".text_to_dialogue",
    "text_to_sound_effects": ".text_to_sound_effects",
    "text_to_speech": ".text_to_speech",
    "text_to_voice": ".text_to_voice",
    "tokens": ".tokens",
    "usage": ".usage",
    "user": ".user",
    "v_1_realtime_translation": ".v_1_realtime_translation",
    "v_1_speech_to_text_realtime": ".v_1_speech_to_text_realtime",
    "v_1_text_to_dialogue_stream_input": ".v_1_text_to_dialogue_stream_input",
    "v_1_text_to_speech_voice_id_multi_stream_input": ".v_1_text_to_speech_voice_id_multi_stream_input",
    "v_1_text_to_speech_voice_id_stream_input": ".v_1_text_to_speech_voice_id_stream_input",
    "voices": ".voices",
    "webhooks": ".webhooks",
    "workspace": ".workspace",
    "workspaces": ".workspaces",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AccountChangeActivityId",
    "ActorModel",
    "AddChapterResponseModel",
    "AddKnowledgeBaseResponseModel",
    "AddProjectRequest",
    "AddProjectResponseModel",
    "AddPronunciationDictionaryResponseModel",
    "AddPronunciationDictionaryResponseModelPermissionOnResource",
    "AddSharingVoiceRequest",
    "AddVoiceIvcResponseModel",
    "AddVoiceResponseModel",
    "AddWorkspaceGroupMemberResponseModel",
    "AddWorkspaceInviteResponseModel",
    "AdditionalFormatResponseModel",
    "AdditionalFormats",
    "AdhocAgentConfigOverrideForTestRequestModel",
    "Age",
    "AgentBranchBasicInfo",
    "AgentBranchResponse",
    "AgentBranchSummary",
    "AgentCallLimits",
    "AgentConfig",
    "AgentConfigApiModelWorkflowOverrideInput",
    "AgentConfigApiModelWorkflowOverrideOutput",
    "AgentConfigOverrideConfig",
    "AgentConfigOverrideInput",
    "AgentConfigOverrideOutput",
    "AgentDefinitionSource",
    "AgentDeploymentPercentageStrategy",
    "AgentDeploymentRequest",
    "AgentDeploymentRequestItem",
    "AgentDeploymentResponse",
    "AgentFailureResponseExample",
    "AgentMetadata",
    "AgentMetadataDbModel",
    "AgentMetadataResponseModel",
    "AgentPlatformSettingsRequestModel",
    "AgentPlatformSettingsResponseModel",
    "AgentResponsePayload",
    "AgentSimulatedChatTestResponseModel",
    "AgentSortBy",
    "AgentSuccessfulResponseExample",
    "AgentSummaryBatchSuccessfulResponseModel",
    "AgentSummaryResponseModel",
    "AgentTestEntityType",
    "AgentTestFolderPathSegmentResponseModel",
    "AgentTestingSettings",
    "AgentTopicResponseModel",
    "AgentTransfer",
    "AgentTrustContext",
    "AgentVersionMetadata",
    "AgentVersionParents",
    "AgentWorkflowRequestModel",
    "AgentWorkflowRequestModelNodesValue",
    "AgentWorkflowRequestModelNodesValue_End",
    "AgentWorkflowRequestModelNodesValue_OverrideAgent",
    "AgentWorkflowRequestModelNodesValue_PhoneNumber",
    "AgentWorkflowRequestModelNodesValue_StandaloneAgent",
    "AgentWorkflowRequestModelNodesValue_Start",
    "AgentWorkflowRequestModelNodesValue_Tool",
    "AgentWorkflowResponseModel",
    "AgentWorkflowResponseModelNodesValue",
    "AgentWorkflowResponseModelNodesValue_End",
    "AgentWorkflowResponseModelNodesValue_OverrideAgent",
    "AgentWorkflowResponseModelNodesValue_PhoneNumber",
    "AgentWorkflowResponseModelNodesValue_StandaloneAgent",
    "AgentWorkflowResponseModelNodesValue_Start",
    "AgentWorkflowResponseModelNodesValue_Tool",
    "AgentWorkspaceOverridesInput",
    "AgentWorkspaceOverridesOutput",
    "AlertingMonitorConfig",
    "AlertingSettings",
    "AlertingWebhookNotifier",
    "Alignment",
    "AllowedOutputFormats",
    "AllowlistItem",
    "AnalysisProperty",
    "AnalysisPropertyConstantValue",
    "AnalysisPropertyType",
    "AnalysisScope",
    "ApiIntegrationOAuth2AuthCodeResponse",
    "ApiIntegrationOAuth2AuthCodeResponseScopeSeparator",
    "ApiIntegrationOAuth2CustomAppResponse",
    "ApiIntegrationOAuth2CustomAppResponseScopeSeparator",
    "ApiIntegrationWebhookOverrides",
    "ApiIntegrationWebhookOverridesRequestHeadersValue",
    "ApiIntegrationWebhookOverridesSchemaOverridesValue",
    "ApiIntegrationWebhookOverridesSchemaOverridesValue_Constant",
    "ApiIntegrationWebhookOverridesSchemaOverridesValue_DynamicVariable",
    "ApiIntegrationWebhookOverridesSchemaOverridesValue_Llm",
    "ApiIntegrationWebhookOverridesSchemaOverridesValue_Omit",
    "ApiIntegrationWebhookToolConfigInput",
    "ApiIntegrationWebhookToolConfigOutput",
    "ArrayJsonSchemaPropertyInput",
    "ArrayJsonSchemaPropertyInputConstantValueItem",
    "ArrayJsonSchemaPropertyInputItems",
    "ArrayJsonSchemaPropertyOutput",
    "ArrayJsonSchemaPropertyOutputConstantValueItem",
    "ArrayJsonSchemaPropertyOutputItems",
    "AsrConversationalConfig",
    "AsrConversationalConfigOverride",
    "AsrConversationalConfigOverrideConfig",
    "AsrConversationalConfigWorkflowOverride",
    "AsrInputFormat",
    "AsrProvider",
    "AsrQuality",
    "AssetTranscription",
    "AssetTranscriptionData",
    "AssetTranscriptionStatus",
    "AstAdditionOperatorNodeInput",
    "AstAdditionOperatorNodeOutput",
    "AstAndOperatorNodeInput",
    "AstAndOperatorNodeOutput",
    "AstBooleanNodeInput",
    "AstBooleanNodeOutput",
    "AstConditionalOperatorNodeInput",
    "AstConditionalOperatorNodeOutput",
    "AstDivisionOperatorNodeInput",
    "AstDivisionOperatorNodeOutput",
    "AstDynamicVariableNodeInput",
    "AstDynamicVariableNodeOutput",
    "AstEqualsOperatorNodeInput",
    "AstEqualsOperatorNodeOutput",
    "AstGreaterThanOperatorNodeInput",
    "AstGreaterThanOperatorNodeOutput",
    "AstGreaterThanOrEqualsOperatorNodeInput",
    "AstGreaterThanOrEqualsOperatorNodeOutput",
    "AstLessThanOperatorNodeInput",
    "AstLessThanOperatorNodeOutput",
    "AstLessThanOrEqualsOperatorNodeInput",
    "AstLessThanOrEqualsOperatorNodeOutput",
    "AstMultiplicationOperatorNodeInput",
    "AstMultiplicationOperatorNodeOutput",
    "AstNodeInput",
    "AstNodeInput_AddOperator",
    "AstNodeInput_AndOperator",
    "AstNodeInput_BooleanLiteral",
    "AstNodeInput_ConditionalOperator",
    "AstNodeInput_DivOperator",
    "AstNodeInput_DynamicVariable",
    "AstNodeInput_EqOperator",
    "AstNodeInput_GtOperator",
    "AstNodeInput_GteOperator",
    "AstNodeInput_Llm",
    "AstNodeInput_LtOperator",
    "AstNodeInput_LteOperator",
    "AstNodeInput_MulOperator",
    "AstNodeInput_NeqOperator",
    "AstNodeInput_NullLiteral",
    "AstNodeInput_NumberLiteral",
    "AstNodeInput_OrOperator",
    "AstNodeInput_StringLiteral",
    "AstNodeInput_SubOperator",
    "AstNodeOutput",
    "AstNodeOutput_AddOperator",
    "AstNodeOutput_AndOperator",
    "AstNodeOutput_BooleanLiteral",
    "AstNodeOutput_ConditionalOperator",
    "AstNodeOutput_DivOperator",
    "AstNodeOutput_DynamicVariable",
    "AstNodeOutput_EqOperator",
    "AstNodeOutput_GtOperator",
    "AstNodeOutput_GteOperator",
    "AstNodeOutput_Llm",
    "AstNodeOutput_LtOperator",
    "AstNodeOutput_LteOperator",
    "AstNodeOutput_MulOperator",
    "AstNodeOutput_NeqOperator",
    "AstNodeOutput_NullLiteral",
    "AstNodeOutput_NumberLiteral",
    "AstNodeOutput_OrOperator",
    "AstNodeOutput_StringLiteral",
    "AstNodeOutput_SubOperator",
    "AstNotEqualsOperatorNodeInput",
    "AstNotEqualsOperatorNodeOutput",
    "AstNullNodeInput",
    "AstNullNodeOutput",
    "AstNumberNodeInput",
    "AstNumberNodeOutput",
    "AstOrOperatorNodeInput",
    "AstOrOperatorNodeOutput",
    "AstStringNodeInput",
    "AstStringNodeOutput",
    "AstSubtractionOperatorNodeInput",
    "AstSubtractionOperatorNodeOutput",
    "AstllmNodeInput",
    "AstllmNodeInputPrompt",
    "AstllmNodeInputValueSchema",
    "AstllmNodeOutput",
    "AsyncConversationMetadata",
    "AsyncConversationMetadataDeliveryStatus",
    "AsyncElevenLabs",
    "AttachedTestModel",
    "AudioAnalysis",
    "AudioAnalysisResult",
    "AudioAnalysisStatus",
    "AudioFormat",
    "AudioFormatEnum",
    "AudioIsolationConvertRequestFileFormat",
    "AudioIsolationHistoryItemResponseModel",
    "AudioIsolationStreamRequestFileFormat",
    "AudioKeyMoment",
    "AudioNativeCreateProjectResponseModel",
    "AudioNativeCreateRequestApplyTextNormalization",
    "AudioNativeEditContentResponseModel",
    "AudioNativeProjectSettingsResponseModel",
    "AudioNativeProjectSettingsResponseModelStatus",
    "AudioOutput",
    "AudioOutputMulti",
    "AudioRefChunk",
    "AudioSegment",
    "AudioWithTimestampsAndVoiceSegmentsResponseModel",
    "AudioWithTimestampsResponse",
    "AuthConnectionDependencies",
    "AuthConnectionDependenciesMcpServersItem",
    "AuthConnectionDependenciesMcpServersItem_Available",
    "AuthConnectionDependenciesMcpServersItem_Unknown",
    "AuthConnectionDependenciesToolsItem",
    "AuthConnectionDependenciesToolsItem_Available",
    "AuthConnectionDependenciesToolsItem_Unknown",
    "AuthConnectionLocator",
    "AuthSettings",
    "AuthenticationActivityId",
    "AuthorizationMethod",
    "AutoSyncInfo",
    "BackgroundSoundConfig",
    "BackgroundSoundConfigWorkflowOverride",
    "BackgroundSoundPresetId",
    "BackgroundSoundSourceType",
    "BackupLlmDefault",
    "BackupLlmDisabled",
    "BackupLlmOverride",
    "BadRequestError",
    "BadRequestErrorBody",
    "BaseTurnConfig",
    "BasicAuthResponse",
    "BatchCallDetailedResponse",
    "BatchCallRecipientStatus",
    "BatchCallResponse",
    "BatchCallStatus",
    "BatchCallWhatsAppParams",
    "BatchFailureResponseModel",
    "BearerAuthResponse",
    "BehaviorOverride",
    "BillingPeriod",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess",
    "BodyComposeMusicV1MusicPostCompositionPlan",
    "BodyComposeMusicV1MusicPostModelId",
    "BodyComposeMusicWithADetailedResponseV1MusicDetailedPostCompositionPlan",
    "BodyComposeMusicWithADetailedResponseV1MusicDetailedPostModelId",
    "BodyCreatePodcastV1StudioPodcastsPostApplyTextNormalization",
    "BodyCreatePodcastV1StudioPodcastsPostDurationScale",
    "BodyCreatePodcastV1StudioPodcastsPostMode",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Conversation",
    "BodyCreatePodcastV1StudioPodcastsPostSource",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Text",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Url",
    "BodyStreamComposedMusicV1MusicStreamPostCompositionPlan",
    "BodyStreamComposedMusicV1MusicStreamPostModelId",
    "BodyTextToDialogueFullWithTimestampsApplyTextNormalization",
    "BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPostApplyTextNormalization",
    "BodyTextToDialogueMultiVoiceV1TextToDialoguePostApplyTextNormalization",
    "BodyTextToDialogueStreamWithTimestampsApplyTextNormalization",
    "BodyTextToSpeechFullApplyTextNormalization",
    "BodyTextToSpeechFullWithTimestampsApplyTextNormalization",
    "BodyTextToSpeechStreamApplyTextNormalization",
    "BodyTextToSpeechStreamWithTimestampsApplyTextNormalization",
    "BranchProtectionStatus",
    "BreakdownTypes",
    "BucketingStatus",
    "BuiltInToolsInput",
    "BuiltInToolsOutput",
    "BuiltInToolsWorkflowOverrideInput",
    "BuiltInToolsWorkflowOverrideOutput",
    "CancelCalendarEventParams",
    "CancelGroupSessionForAllParams",
    "CancelGroupSessionRegistrationParams",
    "CanvasPlacement",
    "CaptionStyleCharacterAnimationModel",
    "CaptionStyleCharacterAnimationModelEnterType",
    "CaptionStyleCharacterAnimationModelExitType",
    "CaptionStyleHorizontalPlacementModel",
    "CaptionStyleHorizontalPlacementModelAlign",
    "CaptionStyleModel",
    "CaptionStyleModelTextAlign",
    "CaptionStyleModelTextBlendMode",
    "CaptionStyleModelTextStyle",
    "CaptionStyleModelTextTransform",
    "CaptionStyleModelTextWeight",
    "CaptionStyleSectionAnimationModel",
    "CaptionStyleSectionAnimationModelEnterType",
    "CaptionStyleSectionAnimationModelExitType",
    "CaptionStyleTemplateModel",
    "CaptionStyleVerticalPlacementModel",
    "CaptionStyleVerticalPlacementModelAlign",
    "CaptionStyleWordAnimationModel",
    "CaptionStyleWordAnimationModelEnterType",
    "CaptionStyleWordAnimationModelExitType",
    "ChapterContentBlockExtendableNodeResponseModel",
    "ChapterContentBlockInputModel",
    "ChapterContentBlockInputModelSubType",
    "ChapterContentBlockResponseModel",
    "ChapterContentBlockResponseModelNodesItem",
    "ChapterContentBlockResponseModelNodesItem_Other",
    "ChapterContentBlockResponseModelNodesItem_TtsNode",
    "ChapterContentBlockTtsNodeResponseModel",
    "ChapterContentInputModel",
    "ChapterContentParagraphTtsNodeInputModel",
    "ChapterContentResponseModel",
    "ChapterResponse",
    "ChapterSnapshotExtendedResponseModel",
    "ChapterSnapshotResponse",
    "ChapterSnapshotsResponse",
    "ChapterState",
    "ChapterStatisticsResponse",
    "ChapterWithContentResponseModel",
    "ChapterWithContentResponseModelState",
    "CharacterAlignmentModel",
    "CharacterAlignmentResponseModel",
    "CharacterRefreshPeriod",
    "CharacterUsageResponse",
    "ChatSourceMedium",
    "CheckServiceAvailabilityParams",
    "ClientEvent",
    "ClientToolConfigInput",
    "ClientToolConfigOutput",
    "ClipAnimation",
    "ClipAnimationEnterEffect",
    "ClipAnimationExitEffect",
    "CloseConnection",
    "CloseContext",
    "ClosePayload",
    "CloseSocket",
    "ColumnFilter",
    "ColumnFilterOperation",
    "ColumnFilterValuesItem",
    "ColumnUnit",
    "CommitStrategy",
    "CommittedTranscriptPayload",
    "CommittedTranscriptWithTimestampsPayload",
    "CompositionPlan",
    "CompositionPlanChunksItem",
    "ConfigEntityType",
    "ConflictError",
    "ConstantSchemaOverride",
    "ConstantSchemaOverrideConstantValue",
    "ConstantSchemaOverrideConstantValueFourItem",
    "ContentConfig",
    "ContentGuardrailInput",
    "ContentGuardrailInputTriggerAction",
    "ContentGuardrailInputTriggerAction_EndCall",
    "ContentGuardrailInputTriggerAction_Retry",
    "ContentGuardrailOutput",
    "ContentGuardrailOutputTriggerAction",
    "ContentGuardrailOutputTriggerAction_EndCall",
    "ContentGuardrailOutputTriggerAction_Retry",
    "ContentThresholdGuardrail",
    "ContentThresholdGuardrailThreshold",
    "ContextualUpdateInfo",
    "Contributor",
    "ConvAiDynamicVariable",
    "ConvAiEnvVarLocator",
    "ConvAiFileUploadResponseModel",
    "ConvAiSecretLocator",
    "ConvAiStoredSecretDependencies",
    "ConvAiStoredSecretDependenciesAgentsItem",
    "ConvAiStoredSecretDependenciesAgentsItem_Available",
    "ConvAiStoredSecretDependenciesAgentsItem_Unknown",
    "ConvAiStoredSecretDependenciesMcpServersItem",
    "ConvAiStoredSecretDependenciesMcpServersItem_Available",
    "ConvAiStoredSecretDependenciesMcpServersItem_Unknown",
    "ConvAiStoredSecretDependenciesToolsItem",
    "ConvAiStoredSecretDependenciesToolsItem_Available",
    "ConvAiStoredSecretDependenciesToolsItem_Unknown",
    "ConvAiUserSecretDbModel",
    "ConvAiWebhooks",
    "ConvAiWorkspaceStoredSecretConfig",
    "ConversationAsrUsageModel",
    "ConversationChargingCommonModel",
    "ConversationConfigClientOverrideConfigInput",
    "ConversationConfigClientOverrideConfigOutput",
    "ConversationConfigClientOverrideInput",
    "ConversationConfigClientOverrideOutput",
    "ConversationConfigInput",
    "ConversationConfigOutput",
    "ConversationConfigOverride",
    "ConversationConfigOverrideConfig",
    "ConversationConfigWorkflowOverrideInput",
    "ConversationConfigWorkflowOverrideOutput",
    "ConversationDeletionSettings",
    "ConversationFeedbackType",
    "ConversationHistoryAnalysisCommonModel",
    "ConversationHistoryBatchCallModel",
    "ConversationHistoryElevenAssistantCommonModel",
    "ConversationHistoryErrorCommonModel",
    "ConversationHistoryEvaluationCriteriaResultCommonModel",
    "ConversationHistoryExotelPhoneCallModel",
    "ConversationHistoryFeedbackCommonModel",
    "ConversationHistoryMetadataCommonModel",
    "ConversationHistoryMetadataCommonModelPhoneCall",
    "ConversationHistoryMetadataCommonModelPhoneCall_Exotel",
    "ConversationHistoryMetadataCommonModelPhoneCall_SipTrunking",
    "ConversationHistoryMetadataCommonModelPhoneCall_Twilio",
    "ConversationHistoryMultivoiceMessageModel",
    "ConversationHistoryMultivoiceMessagePartModel",
    "ConversationHistoryRagUsageCommonModel",
    "ConversationHistoryRedactionConfig",
    "ConversationHistorySipTrunkingPhoneCallModel",
    "ConversationHistoryTranscriptApiIntegrationWebhookToolsResultCommonModelInput",
    "ConversationHistoryTranscriptApiIntegrationWebhookToolsResultCommonModelOutput",
    "ConversationHistoryTranscriptCommonModelInput",
    "ConversationHistoryTranscriptCommonModelInputRole",
    "ConversationHistoryTranscriptCommonModelInputToolResultsItem",
    "ConversationHistoryTranscriptCommonModelOutput",
    "ConversationHistoryTranscriptCommonModelOutputRole",
    "ConversationHistoryTranscriptCommonModelOutputToolResultsItem",
    "ConversationHistoryTranscriptFileInputResponseModel",
    "ConversationHistoryTranscriptOtherToolsResultCommonModel",
    "ConversationHistoryTranscriptOtherToolsResultCommonModelType",
    "ConversationHistoryTranscriptResponseModel",
    "ConversationHistoryTranscriptResponseModelRole",
    "ConversationHistoryTranscriptResponseModelToolResultsItem",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInput",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_EndCallSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_KnowledgeBaseRagSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_LanguageDetectionSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_PlayDtmfError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_PlayDtmfSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_SkipTurnSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TestingToolResult",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToAgentError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToAgentSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberExotelSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberSipSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_TransferToNumberTwilioSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelInputResult_VoicemailDetectionSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutput",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_EndCallSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_KnowledgeBaseRagSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_LanguageDetectionSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_PlayDtmfError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_PlayDtmfSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_SkipTurnSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TestingToolResult",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToAgentError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToAgentSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberExotelSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberSipSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_TransferToNumberTwilioSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelOutputResult_VoicemailDetectionSuccess",
    "ConversationHistoryTranscriptToolCallApiIntegrationWebhookDetailsInput",
    "ConversationHistoryTranscriptToolCallApiIntegrationWebhookDetailsOutput",
    "ConversationHistoryTranscriptToolCallClientDetails",
    "ConversationHistoryTranscriptToolCallCommonModelInput",
    "ConversationHistoryTranscriptToolCallCommonModelInputToolDetails",
    "ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_ApiIntegrationWebhook",
    "ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_Client",
    "ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_Mcp",
    "ConversationHistoryTranscriptToolCallCommonModelInputToolDetails_Webhook",
    "ConversationHistoryTranscriptToolCallCommonModelOutput",
    "ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails",
    "ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_ApiIntegrationWebhook",
    "ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_Client",
    "ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_Mcp",
    "ConversationHistoryTranscriptToolCallCommonModelOutputToolDetails_Webhook",
    "ConversationHistoryTranscriptToolCallMcpDetails",
    "ConversationHistoryTranscriptToolCallWebhookDetails",
    "ConversationHistoryTranscriptWorkflowToolsResultCommonModelInput",
    "ConversationHistoryTranscriptWorkflowToolsResultCommonModelOutput",
    "ConversationHistoryTwilioPhoneCallModel",
    "ConversationInitiationClientDataConfigInput",
    "ConversationInitiationClientDataConfigOutput",
    "ConversationInitiationClientDataInternal",
    "ConversationInitiationClientDataRequestInput",
    "ConversationInitiationClientDataRequestOutput",
    "ConversationInitiationClientDataWebhook",
    "ConversationInitiationClientDataWebhookRequestHeadersValue",
    "ConversationInitiationSource",
    "ConversationInitiationSourceInfo",
    "ConversationProduct",
    "ConversationSentimentAnalysis",
    "ConversationSentimentAnalysisOverallLabel",
    "ConversationSignedUrlResponseModel",
    "ConversationSimulationSpecification",
    "ConversationSource",
    "ConversationSummaryResponseModel",
    "ConversationSummaryResponseModelStatus",
    "ConversationTagResponseModel",
    "ConversationTokenPurpose",
    "ConversationTokenResponseModel",
    "ConversationTtsUsageModel",
    "ConversationTurnMetrics",
    "ConversationUserResponseModel",
    "ConversationVoiceRewardModel",
    "ConversationVoiceUsageModel",
    "ConversationalConfig",
    "ConversationalConfigApiModelWorkflowOverrideInput",
    "ConversationalConfigApiModelWorkflowOverrideOutput",
    "ConvertChapterResponseModel",
    "ConvertProjectResponseModel",
    "CreateAgentBranchResponseModel",
    "CreateAgentResponseModel",
    "CreateAgentRuleParams",
    "CreateAgentTestFolderResponseModel",
    "CreateAgentTestResponseModel",
    "CreateAssetParams",
    "CreateAudioNativeProjectRequest",
    "CreateAuthConnectionEnvironmentVariableRequest",
    "CreateBasicAuthRequest",
    "CreateBearerAuthRequest",
    "CreateClientAppointmentParams",
    "CreateClientInteractionParams",
    "CreateClientParams",
    "CreateCustomHeaderAuthRequest",
    "CreateExotelPhoneNumberRequest",
    "CreateHolidayParams",
    "CreateLocationParams",
    "CreateMtlsAuthRequest",
    "CreateOAuth2ClientCredsRequest",
    "CreateOAuth2JwtRequest",
    "CreateOAuth2JwtRequestAlgorithm",
    "CreateOAuth2JwtRequestTokenResponseField",
    "CreateOrderRequest",
    "CreateOrderResponse",
    "CreatePhoneNumberResponseModel",
    "CreatePreviouslyGeneratedVoiceRequest",
    "CreatePrivateKeyJwtRequest",
    "CreatePrivateKeyJwtRequestAlgorithm",
    "CreateProductParams",
    "CreatePronunciationDictionaryResponseModel",
    "CreateResponseUnitTestRequest",
    "CreateSecretEnvironmentVariableRequest",
    "CreateServiceParams",
    "CreateSimulationTestRequest",
    "CreateSipTrunkPhoneNumberRequest",
    "CreateStaffParams",
    "CreateStringEnvironmentVariableRequest",
    "CreateToolCallUnitTestRequest",
    "CreateTranscriptRequest",
    "CreateTwilioPhoneNumberRequest",
    "CueOptionsRequest",
    "Currency",
    "CustomGuardrailConfig",
    "CustomGuardrailConfigModel",
    "CustomGuardrailConfigTriggerAction",
    "CustomGuardrailConfigTriggerAction_EndCall",
    "CustomGuardrailConfigTriggerAction_Retry",
    "CustomGuardrailInput",
    "CustomGuardrailOutput",
    "CustomGuardrailsConfigInput",
    "CustomGuardrailsConfigOutput",
    "CustomHeaderAuthResponse",
    "CustomLlm",
    "CustomLlmApiKey",
    "CustomLlmAuthConnection",
    "CustomLlmRequestHeadersValue",
    "CustomLlmapiType",
    "CustomSipHeader",
    "CustomSipHeaderWithDynamicVariable",
    "DashboardCallSuccessChartModel",
    "DashboardCriteriaChartModel",
    "DashboardDataCollectionChartModel",
    "DataCollectionResultCommonModel",
    "DefaultSharingGroupResponseModel",
    "DefaultSharingGroupResponseModelPermissionLevel",
    "DeleteAgentRuleParams",
    "DeleteAssetParams",
    "DeleteCalendarEventParams",
    "DeleteChapterRequest",
    "DeleteChapterResponseModel",
    "DeleteClientInteractionParams",
    "DeleteClientParams",
    "DeleteDubbingResponseModel",
    "DeleteGroupSessionParams",
    "DeleteHistoryItemResponse",
    "DeleteHolidayParams",
    "DeleteLocationParams",
    "DeleteProductParams",
    "DeleteProjectRequest",
    "DeleteProjectResponseModel",
    "DeleteSampleResponse",
    "DeleteServiceParams",
    "DeleteStaffParams",
    "DeleteVoiceResponseModel",
    "DeleteVoiceSampleResponseModel",
    "DeleteWorkspaceGroupMemberResponseModel",
    "DeleteWorkspaceInviteResponseModel",
    "DeleteWorkspaceWebhookResponseModel",
    "DeliverableInfo",
    "DependentAvailableAgentIdentifier",
    "DependentAvailableAgentIdentifierAccessLevel",
    "DependentAvailableMcpServerIdentifier",
    "DependentAvailableMcpServerIdentifierAccessLevel",
    "DependentAvailableToolIdentifier",
    "DependentAvailableToolIdentifierAccessLevel",
    "DependentBranchInfo",
    "DependentIntegrationConnectionIdentifier",
    "DependentPhoneNumberIdentifier",
    "DependentUnknownAgentIdentifier",
    "DependentUnknownMcpServerIdentifier",
    "DependentUnknownToolIdentifier",
    "DetailedMusicResponse",
    "DetailedMusicResponseCompositionPlan",
    "DetectedEntity",
    "DeviceModel",
    "DialogueInput",
    "DialogueInputResponseModel",
    "DialogueTextAlignment",
    "DirectPublishingReadResponseModel",
    "DirectPublishingReadResponseModelDisplayMode",
    "DirectPublishingReadResponseModelGenreItem",
    "DirectPublishingReadResponseModelPayoutType",
    "DirectPublishingReadResponseModelTargetAudience",
    "DiscountResponseModel",
    "DoDubbingResponse",
    "DocumentUsageModeEnum",
    "DocxExportOptions",
    "DtmfInputConfig",
    "DubOrderItemRequest",
    "DubbedSegment",
    "DubbingCreateRequestMode",
    "DubbingListRequestCreationSourcesItem",
    "DubbingListRequestDubbingModelsItem",
    "DubbingListRequestDubbingStatus",
    "DubbingListRequestDubbingStatusesItem",
    "DubbingListRequestFilterByCreator",
    "DubbingListRequestOrderBy",
    "DubbingListRequestOrderDirection",
    "DubbingMediaMetadata",
    "DubbingMediaReference",
    "DubbingMetadataPageResponseModel",
    "DubbingMetadataResponse",
    "DubbingRenderResponseModel",
    "DubbingResource",
    "DubbingTranscript",
    "DubbingTranscriptCharacter",
    "DubbingTranscriptResponseModel",
    "DubbingTranscriptUtterance",
    "DubbingTranscriptWord",
    "DubbingTranscriptsResponseModel",
    "DubbingTranscriptsResponseModelTranscriptFormat",
    "DynamicVariableAssignment",
    "DynamicVariableNestedValueTypeInput",
    "DynamicVariableNestedValueTypeOutput",
    "DynamicVariableSchemaOverride",
    "DynamicVariableUpdateCommonModel",
    "DynamicVariableValueTypeInput",
    "DynamicVariableValueTypeOutput",
    "DynamicVariablesConfigInput",
    "DynamicVariablesConfigOutput",
    "DynamicVariablesConfigWorkflowOverrideInput",
    "DynamicVariablesConfigWorkflowOverrideOutput",
    "Eagerness",
    "EditChapterResponseModel",
    "EditProjectResponseModel",
    "EditVoiceResponseModel",
    "EditVoiceSettingsRequest",
    "EditVoiceSettingsResponseModel",
    "ElevenLabs",
    "ElevenLabsEnvironment",
    "EmbedVariant",
    "EmbeddingModelEnum",
    "EndCallToolConfig",
    "EndCallToolResultModel",
    "EndCallTriggerAction",
    "EndProcedureToolConfigInput",
    "EndProcedureToolConfigOutput",
    "EndProcedureToolErrorStatus",
    "EntityManagementActivityId",
    "EntryBehavior",
    "EnvironmentAuthConnectionLocator",
    "EnvironmentVariableAuthConnectionValue",
    "EnvironmentVariableAuthConnectionValueRequest",
    "EnvironmentVariableResponse",
    "EnvironmentVariableResponseType",
    "EnvironmentVariableResponseValues",
    "EnvironmentVariableSecretValue",
    "EnvironmentVariableSecretValueRequest",
    "EnvironmentVariablesCreateRequestBody",
    "EnvironmentVariablesCreateRequestBody_AuthConnection",
    "EnvironmentVariablesCreateRequestBody_Secret",
    "EnvironmentVariablesCreateRequestBody_String",
    "EnvironmentVariablesListRequestType",
    "EnvironmentVariablesListResponse",
    "ErrorPayload",
    "EvaluationSettingsInput",
    "EvaluationSettingsOutput",
    "EvaluationSuccessResult",
    "ExactParameterEvaluationStrategy",
    "ExotelApiSubdomain",
    "ExotelOutboundCallResponse",
    "ExportOptions",
    "ExportOptions_Docx",
    "ExportOptions_Html",
    "ExportOptions_Pdf",
    "ExportOptions_SegmentedJson",
    "ExportOptions_Srt",
    "ExportOptions_Txt",
    "ExtendedSubscriptionResponseModelMaxCreditLimitExtension",
    "ExtendedSubscriptionResponseModelPendingChange",
    "ExternalFileSyncInfo",
    "ExternalFolderSyncInfo",
    "ExternalSyncType",
    "FeatureStatusCommonModel",
    "FeaturesUsageCommonModel",
    "FeedbackItem",
    "FileInputConfig",
    "FileInputConfigWorkflowOverride",
    "FinalOutput",
    "FinalOutputMulti",
    "FineTuningResponse",
    "FineTuningResponseModelStateValue",
    "FlushContext",
    "FocusGuardrail",
    "ForbiddenError",
    "ForcedAlignmentCharacterResponseModel",
    "ForcedAlignmentResponseModel",
    "ForcedAlignmentWordResponseModel",
    "Gender",
    "GenerateVoiceRequest",
    "GenerationChunkInput",
    "GenerationChunkInputConditionStrength",
    "GenerationChunkInputContextAdherence",
    "GenerationChunkOutput",
    "GenerationChunkOutputConditionStrength",
    "GenerationChunkOutputContextAdherence",
    "GenerationConfig",
    "GenerationSourceContext",
    "GenesysRegion",
    "GetAgentEmbedResponseModel",
    "GetAgentKnowledgebaseSizeResponseModel",
    "GetAgentLinkResponseModel",
    "GetAgentResponseModel",
    "GetAgentResponseModelPhoneNumbersItem",
    "GetAgentResponseModelPhoneNumbersItem_Exotel",
    "GetAgentResponseModelPhoneNumbersItem_SipTrunk",
    "GetAgentResponseModelPhoneNumbersItem_Twilio",
    "GetAgentTestFolderResponseModel",
    "GetAgentTopicsResponseModel",
    "GetAgentsPageResponseModel",
    "GetAnalyticsSummaryParams",
    "GetAppointmentByConfirmationNumberParams",
    "GetAudioIsolationHistoryResponseModel",
    "GetAudioNativeProjectSettingsResponseModel",
    "GetBookingPageSettingsParams",
    "GetBookingSlugStatusParams",
    "GetChapterRequest",
    "GetChapterSnapshotsRequest",
    "GetChaptersRequest",
    "GetChaptersResponse",
    "GetClientAppointmentsParams",
    "GetClientByPhoneParams",
    "GetConvAiDashboardSettingsResponseModel",
    "GetConvAiDashboardSettingsResponseModelChartsItem",
    "GetConvAiDashboardSettingsResponseModelChartsItem_CallSuccess",
    "GetConvAiDashboardSettingsResponseModelChartsItem_Criteria",
    "GetConvAiDashboardSettingsResponseModelChartsItem_DataCollection",
    "GetConvAiSettingsResponseModel",
    "GetConversationResponseModel",
    "GetConversationResponseModelStatus",
    "GetConversationTagsPageResponseModel",
    "GetConversationUsersPageResponseModel",
    "GetConversationsPageResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown",
    "GetKnowledgeBaseFileResponseModel",
    "GetKnowledgeBaseFolderResponseModel",
    "GetKnowledgeBaseListResponseModel",
    "GetKnowledgeBaseListResponseModelDocumentsItem",
    "GetKnowledgeBaseListResponseModelDocumentsItem_File",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Folder",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Text",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Url",
    "GetKnowledgeBaseSummaryFileResponseModel",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryFolderResponseModel",
    "GetKnowledgeBaseSummaryFolderResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryFolderResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryFolderResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryTextResponseModel",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryUrlResponseModel",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseTextResponseModel",
    "GetKnowledgeBaseUrlResponseModel",
    "GetLibraryVoicesResponse",
    "GetLiveCountResponse",
    "GetOrCreateRagIndexRequestModel",
    "GetPhoneNumberExotelResponseModel",
    "GetPhoneNumberInboundSipTrunkConfigResponseModel",
    "GetPhoneNumberOutboundSipTrunkConfigResponseModel",
    "GetPhoneNumberResponse",
    "GetPhoneNumberSipTrunkResponseModel",
    "GetPhoneNumberTwilioResponseModel",
    "GetProjectRequest",
    "GetProjectsRequest",
    "GetProjectsResponse",
    "GetPronunciationDictionariesMetadataResponseModel",
    "GetPronunciationDictionariesResponse",
    "GetPronunciationDictionaryMetadataResponse",
    "GetPronunciationDictionaryMetadataResponseModelPermissionOnResource",
    "GetPronunciationDictionaryResponse",
    "GetPronunciationDictionaryWithRulesResponseModel",
    "GetPronunciationDictionaryWithRulesResponseModelPermissionOnResource",
    "GetPronunciationDictionaryWithRulesResponseModelRulesItem",
    "GetPronunciationDictionaryWithRulesResponseModelRulesItem_Alias",
    "GetPronunciationDictionaryWithRulesResponseModelRulesItem_Phoneme",
    "GetResponseUnitTestResponseModel",
    "GetScheduleParams",
    "GetSecretDependenciesResponseModel",
    "GetSecretDependenciesResponseModelDependencies",
    "GetSecretDependenciesResponseModelDependenciesOneItem",
    "GetSecretDependenciesResponseModelDependenciesOneItem_Available",
    "GetSecretDependenciesResponseModelDependenciesOneItem_Unknown",
    "GetSecretDependenciesResponseModelDependenciesZeroItem",
    "GetSecretDependenciesResponseModelDependenciesZeroItem_Available",
    "GetSecretDependenciesResponseModelDependenciesZeroItem_Unknown",
    "GetSimulationTestResponseModel",
    "GetSipLogMessagesResponse",
    "GetSpeechHistoryResponse",
    "GetTestInvocationsPageResponseModel",
    "GetTestSuiteInvocationResponseModel",
    "GetTestsPageResponseModel",
    "GetTestsSummariesByIdsResponseModel",
    "GetToolCallUnitTestResponseModel",
    "GetToolDependentAgentsResponseModel",
    "GetToolDependentAgentsResponseModelAgentsItem",
    "GetToolDependentAgentsResponseModelAgentsItem_Available",
    "GetToolDependentAgentsResponseModelAgentsItem_Unknown",
    "GetToolExecutionsPageResponseModel",
    "GetVoicesResponse",
    "GetVoicesV2Response",
    "GetWhatsAppAccountResponse",
    "GetWorkspaceSecretsResponseModel",
    "GroupManagementActivityId",
    "GuardrailExecutionMode",
    "GuardrailsV1Input",
    "GuardrailsV1Output",
    "HistoryAlignmentResponseModel",
    "HistoryAlignmentsResponseModel",
    "HistoryItemResponse",
    "HistoryListRequestSortDirection",
    "HistoryListRequestSource",
    "HtmlExportOptions",
    "HttpRequestModel",
    "HttpValidationError",
    "Icon",
    "ImageAnalysis",
    "ImageAnalysisResult",
    "ImageAnalysisStatus",
    "ImageAvatar",
    "ImageSubject",
    "InboundSipTrunkConfigRequestModel",
    "InitPayload",
    "InitialiseContext",
    "InitializeConnection",
    "InitializeConnectionMulti",
    "InputAudioChunkPayload",
    "IntegrationType",
    "InteractionBudget",
    "InvoiceResponse",
    "InvoiceResponseModelPaymentIntentStatus",
    "InvoiceResponseModelPaymentIntentStatussesItem",
    "ItemId",
    "KeepContextAlive",
    "KnowledgeBaseContentSearchResponseModel",
    "KnowledgeBaseContentSearchResult",
    "KnowledgeBaseContentSearchResultDocument",
    "KnowledgeBaseContentSearchResultDocument_File",
    "KnowledgeBaseContentSearchResultDocument_Folder",
    "KnowledgeBaseContentSearchResultDocument_Text",
    "KnowledgeBaseContentSearchResultDocument_Url",
    "KnowledgeBaseDependentType",
    "KnowledgeBaseDocumentChunkResponseModel",
    "KnowledgeBaseDocumentChunksResponseModel",
    "KnowledgeBaseDocumentMetadataResponseModel",
    "KnowledgeBaseDocumentType",
    "KnowledgeBaseFolderPathSegmentResponseModel",
    "KnowledgeBaseFolderPathSegmentSummaryResponseModel",
    "KnowledgeBaseLocator",
    "KnowledgeBaseRagToolConfig",
    "KnowledgeBaseRagToolResultModel",
    "KnowledgeBaseRagToolStatus",
    "KnowledgeBaseSortBy",
    "KnowledgeBaseSourceFileUrlResponseModel",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModel",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModelData",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModelData_File",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModelData_Folder",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModelData_Text",
    "KnowledgeBaseSummaryBatchSuccessfulResponseModelData_Url",
    "LanguageAddedResponse",
    "LanguageDetectionToolConfig",
    "LanguageDetectionToolResultModel",
    "LanguageInfo",
    "LanguagePairInfo",
    "LanguagePresetInput",
    "LanguagePresetOutput",
    "LanguagePresetTranslation",
    "LanguageResponse",
    "LanguagesResponse",
    "LanguagesResponse_Pair",
    "LanguagesResponse_Single",
    "LeaveMessageParams",
    "LibraryVoiceResponse",
    "LibraryVoiceResponseModelCategory",
    "ListAgentRulesParams",
    "ListAssetsParams",
    "ListAuthConnectionsResponse",
    "ListAuthConnectionsResponseAuthConnectionsItem",
    "ListAuthConnectionsResponseAuthConnectionsItem_ApiIntegrationOauth2AuthCode",
    "ListAuthConnectionsResponseAuthConnectionsItem_ApiIntegrationOauth2CustomApp",
    "ListAuthConnectionsResponseAuthConnectionsItem_BasicAuth",
    "ListAuthConnectionsResponseAuthConnectionsItem_BearerAuth",
    "ListAuthConnectionsResponseAuthConnectionsItem_CustomHeaderAuth",
    "ListAuthConnectionsResponseAuthConnectionsItem_Mtls",
    "ListAuthConnectionsResponseAuthConnectionsItem_Oauth2ClientCredentials",
    "ListAuthConnectionsResponseAuthConnectionsItem_Oauth2Jwt",
    "ListAuthConnectionsResponseAuthConnectionsItem_PrivateKeyJwt",
    "ListAuthConnectionsResponseAuthConnectionsItem_SlackBotAuth",
    "ListAuthConnectionsResponseAuthConnectionsItem_UrlSecret",
    "ListAuthConnectionsResponseAuthConnectionsItem_WhatsappAuth",
    "ListCalendarEventsParams",
    "ListClientInteractionsParams",
    "ListClientsParams",
    "ListCustomerFacingAgentsParams",
    "ListGroupSessionsParams",
    "ListHolidaysParams",
    "ListLocationsParams",
    "ListMcpToolsResponseModel",
    "ListOrdersResponse",
    "ListProductsParams",
    "ListResponseAgentBranchSummary",
    "ListResponseMeta",
    "ListServicesParams",
    "ListSpeechEnginesResponse",
    "ListStaffParams",
    "ListWhatsAppAccountsResponse",
    "LiteralJsonSchemaProperty",
    "LiteralJsonSchemaPropertyConstantValue",
    "LiteralJsonSchemaPropertyType",
    "LivekitStackType",
    "Llm",
    "LlmCategoryUsage",
    "LlmDeprecationConfigModel",
    "LlmDeprecationInfoModel",
    "LlmInfoModelInput",
    "LlmInfoModelOutput",
    "LlmInputOutputTokensUsage",
    "LlmListResponseModelInput",
    "LlmListResponseModelOutput",
    "LlmLiteralJsonSchemaProperty",
    "LlmLiteralJsonSchemaPropertyType",
    "LlmParameterEvaluationStrategy",
    "LlmReasoningEffort",
    "LlmSchemaOverride",
    "LlmTokensCategoryUsage",
    "LlmUsageCalculatorLlmResponseModel",
    "LlmUsageCalculatorResponseModel",
    "LlmUsageInput",
    "LlmUsageOutput",
    "LoadMemoryEntryToolErrorStatus",
    "LoadableMemoryEntry",
    "LockReason",
    "ManualSource",
    "ManualVerificationFileResponse",
    "ManualVerificationResponse",
    "MatchAnythingParameterEvaluationStrategy",
    "McpApprovalPolicy",
    "McpServerConfigInput",
    "McpServerConfigInputAuthConnection",
    "McpServerConfigInputRequestHeadersValue",
    "McpServerConfigInputSecretToken",
    "McpServerConfigInputUrl",
    "McpServerConfigOutput",
    "McpServerConfigOutputAuthConnection",
    "McpServerConfigOutputRequestHeadersValue",
    "McpServerConfigOutputSecretToken",
    "McpServerConfigOutputUrl",
    "McpServerMetadataResponseModel",
    "McpServerResponseModel",
    "McpServerResponseModelDependentAgentsItem",
    "McpServerResponseModelDependentAgentsItem_Available",
    "McpServerResponseModelDependentAgentsItem_Unknown",
    "McpServerTransport",
    "McpServersResponseModel",
    "McpToolApprovalHash",
    "McpToolApprovalPolicy",
    "McpToolConfigOverrideInput",
    "McpToolConfigOverrideInputInputOverridesValue",
    "McpToolConfigOverrideInputInputOverridesValue_Constant",
    "McpToolConfigOverrideInputInputOverridesValue_DynamicVariable",
    "McpToolConfigOverrideInputInputOverridesValue_Llm",
    "McpToolConfigOverrideInputInputOverridesValue_Omit",
    "McpToolConfigOverrideOutput",
    "McpToolConfigOverrideOutputInputOverridesValue",
    "McpToolConfigOverrideOutputInputOverridesValue_Constant",
    "McpToolConfigOverrideOutputInputOverridesValue_DynamicVariable",
    "McpToolConfigOverrideOutputInputOverridesValue_Llm",
    "McpToolConfigOverrideOutputInputOverridesValue_Omit",
    "MediaCodec",
    "MediaId",
    "MemoryEntrySearchResult",
    "MemoryEntrySearchResultSource",
    "MessageSearchSortBy",
    "MessagesSearchResponse",
    "MessagesSearchResult",
    "MetricRecord",
    "MetricType",
    "MockNoMatchBehavior",
    "MockingStrategy",
    "Model",
    "ModelRatesResponseModel",
    "ModelSettingsResponseModel",
    "ModerationConfig",
    "ModerationGuardrailInput",
    "ModerationGuardrailOutput",
    "MtlsAuthResponse",
    "MultichannelSpeechToTextResponseModel",
    "MultipartMusicResponse",
    "MusicAllowedOutputFormats",
    "MusicComposeDetailedRequestOutputFormat",
    "MusicComposeRequestOutputFormat",
    "MusicExploreSongSourceContext",
    "MusicGenerationMode",
    "MusicOnlyOutputFormats",
    "MusicOutputFormat",
    "MusicPrompt",
    "MusicSeparateStemsRequestStemVariationId",
    "MusicStreamRequestOutputFormat",
    "MusicUploadResponse",
    "MusicUploadResponseCompositionPlan",
    "MusicVideoToMusicRequestModelId",
    "NonStreamingOutputFormats",
    "NormalizedAlignment",
    "NotFoundError",
    "OAuth2ClientCredsResponse",
    "OAuth2JwtResponse",
    "OAuth2JwtResponseAlgorithm",
    "OAuth2JwtResponseTokenResponseField",
    "OAuthConnectionStatus",
    "ObjectJsonSchemaPropertyInput",
    "ObjectJsonSchemaPropertyInputPropertiesValue",
    "ObjectJsonSchemaPropertyOutput",
    "ObjectJsonSchemaPropertyOutputPropertiesValue",
    "OmitSchemaOverride",
    "OpenAiAudioConfig",
    "OpenAiAudioFormat",
    "OpenAiAudioInputConfig",
    "OpenAiAudioInputFormat",
    "OpenAiAudioOutputConfig",
    "OpenAiAudioOutputFormat",
    "OpenAiFunctionTool",
    "OpenAiSessionConfig",
    "OpenAiSessionConfigMaxResponseOutputTokens",
    "OpenAiSessionConfigToolChoice",
    "OpenAiSessionConfigToolsItem",
    "OpenAiSessionConfigToolsItem_Function",
    "OpenAiSessionConfigToolsItem_Mcp",
    "OpenAiToolChoiceFunction",
    "OpenAiToolChoiceFunctionInner",
    "OpenAiTurnDetection",
    "OpenAimcpTool",
    "OpenAimcpToolRequireApproval",
    "OptInSmsReminderParams",
    "OptOutSmsReminderParams",
    "OrbAvatar",
    "OrchestratorToolMockBehaviorConfig",
    "OrderDeliverablesResponse",
    "OrderId",
    "OrderItemInfo",
    "OrderItemKind",
    "OrderItemRequestInput",
    "OrderItemRequestInput_Dub",
    "OrderItemRequestInput_Subtitles",
    "OrderItemRequestOutput",
    "OrderItemRequestOutput_Dub",
    "OrderItemRequestOutput_Subtitles",
    "OrderMediaResponse",
    "OrderRequestState",
    "OrderResponse",
    "OrderState",
    "OrderSummary",
    "OutboundCallRecipient",
    "OutboundCallRecipientResponseModel",
    "OutboundSipTrunkConfigRequestModel",
    "OutputFormat",
    "PairedLanguagesResponse",
    "PartialTranscriptPayload",
    "PatchWorkspaceWebhookResponseModel",
    "PdfExportOptions",
    "PendingBlocksMetadataModel",
    "PendingCancellationResponseModel",
    "PendingClipTask",
    "PendingClipTaskType",
    "PendingExternalAudiosMetadataModel",
    "PendingSubscriptionSwitchResponseModel",
    "PendingSubscriptionSwitchResponseModelNextTier",
    "PermissionType",
    "PhoneNumberAgentInfo",
    "PhoneNumberDynamicVariableTransferDestination",
    "PhoneNumberTransfer",
    "PhoneNumberTransferCustomSipHeadersItem",
    "PhoneNumberTransferCustomSipHeadersItem_Dynamic",
    "PhoneNumberTransferCustomSipHeadersItem_Static",
    "PhoneNumberTransferDestination",
    "PhoneNumberTransferPostDialDigits",
    "PhoneNumberTransferPostDialDigits_Dynamic",
    "PhoneNumberTransferPostDialDigits_Static",
    "PhoneNumberTransferTransferDestination",
    "PhoneNumberTransferTransferDestination_Phone",
    "PhoneNumberTransferTransferDestination_PhoneDynamicVariable",
    "PhoneNumberTransferTransferDestination_SipUri",
    "PhoneNumberTransferTransferDestination_SipUriDynamicVariable",
    "PingPayload",
    "PlayDtmfResultErrorModel",
    "PlayDtmfResultSuccessModel",
    "PlayDtmfToolConfig",
    "PodcastBulletinMode",
    "PodcastBulletinModeData",
    "PodcastConversationMode",
    "PodcastConversationModeData",
    "PodcastProjectResponseModel",
    "PodcastTextSource",
    "PodcastUrlSource",
    "PongPayload",
    "PositionInput",
    "PositionOutput",
    "PostAgentAvatarResponseModel",
    "PostDialDigitsDynamicVariable",
    "PostDialDigitsStatic",
    "PostWorkspaceSecretResponseModel",
    "PreToolSpeechMode",
    "PreviewAudioDbModel",
    "Price",
    "PrivacyConfigInput",
    "PrivacyConfigOutput",
    "PrivateKeyJwtResponse",
    "PrivateKeyJwtResponseAlgorithm",
    "ProcedureAtVersionInput",
    "ProcedureAtVersionOutput",
    "ProcedureRefResponseModel",
    "ProcedureType",
    "ProjectCreationMetaResponseModel",
    "ProjectCreationMetaResponseModelStatus",
    "ProjectCreationMetaResponseModelType",
    "ProjectExtendedResponse",
    "ProjectExtendedResponseModelAccessLevel",
    "ProjectExtendedResponseModelApplyTextNormalization",
    "ProjectExtendedResponseModelAspectRatio",
    "ProjectExtendedResponseModelAssetsItem",
    "ProjectExtendedResponseModelAssetsItem_Audio",
    "ProjectExtendedResponseModelAssetsItem_Image",
    "ProjectExtendedResponseModelAssetsItem_Video",
    "ProjectExtendedResponseModelFiction",
    "ProjectExtendedResponseModelSourceType",
    "ProjectExtendedResponseModelTargetAudience",
    "ProjectExternalAudioResponseModel",
    "ProjectExternalAudioResponseModelSourceContext",
    "ProjectExternalAudioResponseModelSourceContext_MusicExploreSong",
    "ProjectExternalAudioResponseModelSourceContext_Sfx",
    "ProjectExternalAudioResponseModelSourceContext_Song",
    "ProjectImageResponseModel",
    "ProjectMutedTracksResponseModel",
    "ProjectResponse",
    "ProjectResponseModelAccessLevel",
    "ProjectResponseModelAspectRatio",
    "ProjectResponseModelFiction",
    "ProjectResponseModelSourceType",
    "ProjectResponseModelTargetAudience",
    "ProjectSnapshotExtendedResponseModel",
    "ProjectSnapshotResponse",
    "ProjectSnapshotsResponse",
    "ProjectState",
    "ProjectVideoResponseModel",
    "ProjectVideoThumbnailSheetResponseModel",
    "ProjectVoiceResponseModel",
    "PromptAgent",
    "PromptAgentApiModelInput",
    "PromptAgentApiModelInputBackupLlmConfig",
    "PromptAgentApiModelInputBackupLlmConfig_Default",
    "PromptAgentApiModelInputBackupLlmConfig_Disabled",
    "PromptAgentApiModelInputBackupLlmConfig_Override",
    "PromptAgentApiModelInputToolsItem",
    "PromptAgentApiModelInputToolsItem_ApiIntegrationWebhook",
    "PromptAgentApiModelInputToolsItem_Client",
    "PromptAgentApiModelInputToolsItem_Mcp",
    "PromptAgentApiModelInputToolsItem_Smb",
    "PromptAgentApiModelInputToolsItem_System",
    "PromptAgentApiModelInputToolsItem_Webhook",
    "PromptAgentApiModelOutput",
    "PromptAgentApiModelOutputBackupLlmConfig",
    "PromptAgentApiModelOutputBackupLlmConfig_Default",
    "PromptAgentApiModelOutputBackupLlmConfig_Disabled",
    "PromptAgentApiModelOutputBackupLlmConfig_Override",
    "PromptAgentApiModelOutputToolsItem",
    "PromptAgentApiModelOutputToolsItem_ApiIntegrationWebhook",
    "PromptAgentApiModelOutputToolsItem_Client",
    "PromptAgentApiModelOutputToolsItem_Mcp",
    "PromptAgentApiModelOutputToolsItem_Smb",
    "PromptAgentApiModelOutputToolsItem_System",
    "PromptAgentApiModelOutputToolsItem_Webhook",
    "PromptAgentApiModelOverrideConfig",
    "PromptAgentApiModelOverrideInput",
    "PromptAgentApiModelOverrideOutput",
    "PromptAgentApiModelWorkflowOverrideInput",
    "PromptAgentApiModelWorkflowOverrideInputBackupLlmConfig",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_ApiIntegrationWebhook",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_Client",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_Mcp",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_Smb",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_System",
    "PromptAgentApiModelWorkflowOverrideInputToolsItem_Webhook",
    "PromptAgentApiModelWorkflowOverrideOutput",
    "PromptAgentApiModelWorkflowOverrideOutputBackupLlmConfig",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_ApiIntegrationWebhook",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_Client",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_Mcp",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_Smb",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_System",
    "PromptAgentApiModelWorkflowOverrideOutputToolsItem_Webhook",
    "PromptAgentDbModel",
    "PromptEvaluationCriteria",
    "PromptInjectionGuardrail",
    "PronunciationDictionariesCreateFromFileRequestWorkspaceAccess",
    "PronunciationDictionariesListRequestSort",
    "PronunciationDictionaryAliasRuleRequestModel",
    "PronunciationDictionaryAliasRuleResponseModel",
    "PronunciationDictionaryLocator",
    "PronunciationDictionaryLocatorResponseModel",
    "PronunciationDictionaryPhonemeRuleRequestModel",
    "PronunciationDictionaryPhonemeRuleResponseModel",
    "PronunciationDictionaryRulesResponseModel",
    "PronunciationDictionaryVersionLocator",
    "PronunciationDictionaryVersionResponseModel",
    "PronunciationDictionaryVersionResponseModelPermissionOnResource",
    "PydanticPronunciationDictionaryVersionLocator",
    "QualityPresetType",
    "QueryParamsJsonSchema",
    "QuoteInfo",
    "RagChunkMetadata",
    "RagConfig",
    "RagConfigWorkflowOverride",
    "RagDocumentIndexResponseModel",
    "RagDocumentIndexUsage",
    "RagDocumentIndexesResponseModel",
    "RagIndexBatchSuccessfulResponseModel",
    "RagIndexOverviewEmbeddingModelResponseModel",
    "RagIndexOverviewResponseModel",
    "RagIndexStatus",
    "RagRetrievalInfo",
    "ReadLegalTerms",
    "ReadMetadataChapterDbModel",
    "ReaderResourceResponseModel",
    "ReaderResourceResponseModelResourceType",
    "RealtimeAudioOptions",
    "RealtimeConfigSnapshot",
    "RealtimeConfigSnapshotParents",
    "RealtimeConnection",
    "RealtimeEvents",
    "RealtimeUrlOptions",
    "RealtimeVoiceSettings",
    "ReceiveMessage",
    "ReceiveMessageMulti",
    "ReceiveRttMessage",
    "ReceiveTextToDialogueWebsocketMessage",
    "ReceiveTranscription",
    "ReceiveUpstreamMessage",
    "RecordingResponse",
    "ReferenceVideo",
    "ReferencedToolCommonModel",
    "ReferencedToolCommonModelType",
    "RegexParameterEvaluationStrategy",
    "RegionConfigRequest",
    "RegionalProcessingSurchargeInfo",
    "RegisterForGroupSessionParams",
    "RegisterMediaResponse",
    "RemoveMemberFromGroupRequest",
    "RemoveOrderItemResponse",
    "Render",
    "RenderStatus",
    "RenderType",
    "ReportKnowledgeGapParams",
    "RequestPvcManualVerificationResponseModel",
    "RequiredConstraint",
    "RequiredConstraints",
    "ResourceAccessInfo",
    "ResourceAccessInfoAccessSource",
    "ResourceAccessInfoAnonymousAccessLevelOverride",
    "ResourceAccessInfoRole",
    "ResourceMetadataResponseModel",
    "ResourceMetadataResponseModelAnonymousAccessLevelOverride",
    "ResponseFilter",
    "ResponseFilterMode",
    "ResponseUnitTestModel",
    "RestoreCalendarEventParams",
    "RetryTriggerAction",
    "ReviewResponseModel",
    "ReviewResponseModelRejectReasonsItem",
    "ReviewResponseModelReviewStatus",
    "ReviewStatus",
    "RttAudioPayload",
    "RttEndOfStreamPayload",
    "RttErrorPayload",
    "RttFinalTranscriptPayload",
    "RttInputAudioChunkPayload",
    "RttInputFormatEnum",
    "RttOutputFormatEnum",
    "RttPartialTranscriptPayload",
    "RttSessionStartedPayload",
    "RttStatusPayload",
    "RttTranslationPayload",
    "SafetyCommonModelInput",
    "SafetyCommonModelOutput",
    "SafetyEvaluation",
    "SafetyResponseModel",
    "SafetyRule",
    "SampleConfigDbModel",
    "SampleConfigDbModelParentType",
    "SaveVoicePreviewRequest",
    "SayNodeLiteralMessageInput",
    "SayNodeLiteralMessageOutput",
    "SayNodePromptMessageInput",
    "SayNodePromptMessageOutput",
    "ScheduleGroupSessionParams",
    "ScopedAnalysisResult",
    "ScribeAuthErrorPayload",
    "ScribeChunkSizeExceededErrorPayload",
    "ScribeErrorPayload",
    "ScribeInputErrorPayload",
    "ScribeInsufficientAudioActivityErrorPayload",
    "ScribeQueueOverflowErrorPayload",
    "ScribeQuotaExceededErrorPayload",
    "ScribeRateLimitedErrorPayload",
    "ScribeResourceExhaustedErrorPayload",
    "ScribeSessionTimeLimitExceededErrorPayload",
    "ScribeThrottledErrorPayload",
    "ScribeTranscriberErrorPayload",
    "ScribeUnacceptedTermsErrorPayload",
    "SearchClientsParams",
    "SearchHighlightSegment",
    "SeatType",
    "SecretDependencyResourceType",
    "SecretDependencyType",
    "SectionSource",
    "SegmentCreateResponse",
    "SegmentDeleteResponse",
    "SegmentDubResponse",
    "SegmentMigrationResponse",
    "SegmentSubtitleFrame",
    "SegmentTranscriptionResponse",
    "SegmentTranslationResponse",
    "SegmentUpdateResponse",
    "SegmentedJsonExportOptions",
    "SendMessage",
    "SendMessageMulti",
    "SendRttMessage",
    "SendText",
    "SendTextMulti",
    "SendUpstreamMessage",
    "SessionStartedPayload",
    "SessionStartedPayloadConfig",
    "SessionStartedPayloadConfigCommitStrategy",
    "SetBookingSlugParams",
    "SeverityId",
    "SfxSourceContext",
    "ShareOptionResponseModel",
    "ShareOptionResponseModelType",
    "SimilarVoice",
    "SimilarVoicesForSpeakerResponse",
    "SimulationTestModel",
    "SimulationToolMockBehaviorConfig",
    "SingleLanguagesResponse",
    "SingleTestRunRequestModel",
    "SingleUseTokenResponseModel",
    "SingleUseTokenType",
    "SipLogMessage",
    "SipLogMessageDirection",
    "SipMediaEncryptionEnum",
    "SipTrunkCredentialsRequestModel",
    "SipTrunkOutboundCallResponse",
    "SipTrunkTransportEnum",
    "SipUriDynamicVariableTransferDestination",
    "SipUriTransferDestination",
    "SkipTurnToolConfig",
    "SkipTurnToolResponseModel",
    "SlackBotAuthResponse",
    "SmsConversationInfo",
    "SmsConversationInfoDirection",
    "SoftTimeoutConfig",
    "SoftTimeoutConfigOverride",
    "SoftTimeoutConfigOverrideConfig",
    "SoftTimeoutConfigWorkflowOverride",
    "SongMetadata",
    "SongSection",
    "SongSourceContext",
    "SortDirection",
    "SpeakerAudioResponseModel",
    "SpeakerCreatedResponse",
    "SpeakerResponseModel",
    "SpeakerSegment",
    "SpeakerSeparationResponseModel",
    "SpeakerSeparationResponseModelStatus",
    "SpeakerTrack",
    "SpeakerUpdatedResponse",
    "SpeechEngineConfig",
    "SpeechEngineConfigRequestHeadersValue",
    "SpeechEngineConversationInitiationClientDataConfig",
    "SpeechEngineResponse",
    "SpeechEngineSummaryResponse",
    "SpeechHistoryItemResponse",
    "SpeechHistoryItemResponseModelSource",
    "SpeechHistoryItemResponseModelVoiceCategory",
    "SpeechToSpeechConvertRequestFileFormat",
    "SpeechToSpeechConvertRequestOutputFormat",
    "SpeechToSpeechStreamRequestFileFormat",
    "SpeechToSpeechStreamRequestOutputFormat",
    "SpeechToTextCharacterResponseModel",
    "SpeechToTextChunkResponseModel",
    "SpeechToTextConvertRequestEntityDetection",
    "SpeechToTextConvertRequestEntityRedaction",
    "SpeechToTextConvertRequestFileFormat",
    "SpeechToTextConvertRequestModelId",
    "SpeechToTextConvertRequestTimestampsGranularity",
    "SpeechToTextConvertRequestWebhookMetadata",
    "SpeechToTextConvertResponse",
    "SpeechToTextWebhookResponseModel",
    "SpeechToTextWordResponseModel",
    "SpeechToTextWordResponseModelType",
    "SpellingPatience",
    "SrtExportOptions",
    "StartProcedureToolConfigInput",
    "StartProcedureToolConfigOutput",
    "StartProcedureToolErrorStatus",
    "StartPvcVoiceTrainingResponseModel",
    "StartSpeakerSeparationResponseModel",
    "StatusId",
    "StreamingAudioChunkWithTimestampsAndVoiceSegmentsResponseModel",
    "StreamingAudioChunkWithTimestampsResponse",
    "StudioAgentSettingsModel",
    "StudioAgentToolSettingsModel",
    "StudioClipReference",
    "StudioClipReferenceClipType",
    "StudioTextStyleOutlineModel",
    "StudioTextStyleShadowModel",
    "SubmitBusinessInfoParams",
    "SubmitOrderResponse",
    "Subscription",
    "SubscriptionResponse",
    "SubscriptionResponseModelMaxCreditLimitExtension",
    "SubscriptionStatusType",
    "SubtitleOrderItemRequest",
    "SuggestedAudioTag",
    "SupportedVoice",
    "SystemEvaluationCriteria",
    "SystemToolConfigInput",
    "SystemToolConfigInputParams",
    "SystemToolConfigInputParams_EndCall",
    "SystemToolConfigInputParams_EndProcedure",
    "SystemToolConfigInputParams_KnowledgeBaseRag",
    "SystemToolConfigInputParams_LanguageDetection",
    "SystemToolConfigInputParams_PlayKeypadTouchTone",
    "SystemToolConfigInputParams_SkipTurn",
    "SystemToolConfigInputParams_StartProcedure",
    "SystemToolConfigInputParams_TransferToAgent",
    "SystemToolConfigInputParams_TransferToNumber",
    "SystemToolConfigInputParams_VoicemailDetection",
    "SystemToolConfigOutput",
    "SystemToolConfigOutputParams",
    "SystemToolConfigOutputParams_EndCall",
    "SystemToolConfigOutputParams_EndProcedure",
    "SystemToolConfigOutputParams_KnowledgeBaseRag",
    "SystemToolConfigOutputParams_LanguageDetection",
    "SystemToolConfigOutputParams_PlayKeypadTouchTone",
    "SystemToolConfigOutputParams_SkipTurn",
    "SystemToolConfigOutputParams_StartProcedure",
    "SystemToolConfigOutputParams_TransferToAgent",
    "SystemToolConfigOutputParams_TransferToNumber",
    "SystemToolConfigOutputParams_VoicemailDetection",
    "TelephonyCallConfig",
    "TelephonyDirection",
    "TelephonyProvider",
    "TestConditionRationaleCommonModel",
    "TestConditionResultCommonModel",
    "TestFromConversationMetadataInput",
    "TestFromConversationMetadataOutput",
    "TestInvocationSummaryResponseModel",
    "TestRunMetadata",
    "TestRunMetadataTestType",
    "TestRunResultBucket",
    "TestRunResultSummary",
    "TestRunStatus",
    "TestSharingMode",
    "TestToolResultModel",
    "TestType",
    "TestsFeatureUsageCommonModel",
    "TextNormalisationType",
    "TextToDialogueConvertRequestOutputFormat",
    "TextToDialogueConvertWithTimestampsRequestOutputFormat",
    "TextToDialogueWebsocketApplyTextNormalizationEnum",
    "TextToDialogueWebsocketAudioChunk",
    "TextToDialogueWebsocketClientMessage",
    "TextToDialogueWebsocketError",
    "TextToDialogueWebsocketFinal",
    "TextToDialogueWebsocketFinalAudioForTurn",
    "TextToDialogueWebsocketOutputFormatEnum",
    "TextToDialogueWebsocketVoiceInput",
    "TextToDialogueWebsocketVoiceSettings",
    "TextToSpeechApplyTextNormalizationEnum",
    "TextToSpeechCommitStrategy",
    "TextToSpeechConvertRequestOutputFormat",
    "TextToSpeechConvertWithTimestampsRequestOutputFormat",
    "TextToSpeechOutputFormatEnum",
    "TextToSpeechRequest",
    "TextToSpeechStreamRequest",
    "TextToSpeechStreamRequestOutputFormat",
    "TextToSpeechStreamWithTimestampsRequest",
    "TextToSpeechStreamWithTimestampsRequestOutputFormat",
    "TextToSpeechWithTimestampsRequest",
    "ThresholdGuardrail",
    "TimeRange",
    "ToDialogueSettingsResponseModel",
    "TokenResponseModel",
    "TooEarlyError",
    "Tool",
    "ToolAnnotations",
    "ToolCallSoundBehavior",
    "ToolCallSoundType",
    "ToolCallUnitTestModel",
    "ToolErrorHandlingMode",
    "ToolExecution",
    "ToolExecutionMode",
    "ToolExecutionResponseModel",
    "ToolExecutionResponseModelToolCallDetails",
    "ToolExecutionResponseModelToolCallDetails_ApiIntegrationWebhook",
    "ToolExecutionResponseModelToolCallDetails_Client",
    "ToolExecutionResponseModelToolCallDetails_Mcp",
    "ToolExecutionResponseModelToolCallDetails_Webhook",
    "ToolExecutionTaskSupport",
    "ToolMockConfig",
    "ToolRequestModel",
    "ToolRequestModelToolConfig",
    "ToolRequestModelToolConfig_Client",
    "ToolRequestModelToolConfig_Mcp",
    "ToolRequestModelToolConfig_System",
    "ToolRequestModelToolConfig_Webhook",
    "ToolResponseMockConfigInput",
    "ToolResponseMockConfigOutput",
    "ToolResponseModel",
    "ToolResponseModelToolConfig",
    "ToolResponseModelToolConfig_Client",
    "ToolResponseModelToolConfig_Mcp",
    "ToolResponseModelToolConfig_System",
    "ToolResponseModelToolConfig_Webhook",
    "ToolSortBy",
    "ToolType",
    "ToolTypeFilter",
    "ToolUsageStatsResponseModel",
    "ToolsResponseModel",
    "TopicDiscoverySettings",
    "TranscriptMessage",
    "TranscriptMessageRole",
    "TranscriptionWord",
    "TranscriptionWordType",
    "TransferBranchInfoDefaultingToMain",
    "TransferBranchInfoTrafficSplit",
    "TransferToAgentToolConfig",
    "TransferToAgentToolResultErrorModel",
    "TransferToAgentToolResultSuccessModel",
    "TransferToAgentToolResultSuccessModelBranchInfo",
    "TransferToAgentToolResultSuccessModelBranchInfo_DefaultingToMain",
    "TransferToAgentToolResultSuccessModelBranchInfo_TrafficSplit",
    "TransferToNumberResultErrorModel",
    "TransferToNumberResultExotelSuccessModel",
    "TransferToNumberResultSipSuccessModel",
    "TransferToNumberResultTwilioSuccessModel",
    "TransferToNumberToolConfigInput",
    "TransferToNumberToolConfigOutput",
    "TransferTypeEnum",
    "TtsConversationalConfigInput",
    "TtsConversationalConfigOutput",
    "TtsConversationalConfigOverride",
    "TtsConversationalConfigOverrideConfig",
    "TtsConversationalConfigWorkflowOverrideInput",
    "TtsConversationalConfigWorkflowOverrideOutput",
    "TtsConversationalModel",
    "TtsModelFamily",
    "TtsOptimizeStreamingLatency",
    "TtsOutputFormat",
    "TurnConfig",
    "TurnConfigOverride",
    "TurnConfigOverrideConfig",
    "TurnConfigWorkflowOverride",
    "TurnDetectionType",
    "TurnEagerness",
    "TurnMode",
    "TurnModel",
    "TwilioEdgeLocation",
    "TwilioOutboundCallResponse",
    "TwilioRegionId",
    "TxtExportOptions",
    "UnauthorizedError",
    "UnitTestRunResponseModel",
    "UnitTestRunResponseModelTestInfo",
    "UnitTestRunResponseModelTestInfo_Llm",
    "UnitTestRunResponseModelTestInfo_Simulation",
    "UnitTestRunResponseModelTestInfo_Tool",
    "UnitTestSummaryResponseModel",
    "UnitTestToolCallEvaluationModelInput",
    "UnitTestToolCallEvaluationModelOutput",
    "UnitTestToolCallParameter",
    "UnitTestToolCallParameterEval",
    "UnitTestToolCallParameterEval_Anything",
    "UnitTestToolCallParameterEval_Exact",
    "UnitTestToolCallParameterEval_Llm",
    "UnitTestToolCallParameterEval_Regex",
    "UnitTestWorkflowNodeTransitionEvaluationNodeId",
    "UnprocessableEntityError",
    "UpdateAgentRuleParams",
    "UpdateAssetParams",
    "UpdateAudioNativeProjectRequest",
    "UpdateBasicAuthRequest",
    "UpdateBookingPageAppearanceParams",
    "UpdateBookingPageSettingsParams",
    "UpdateBusinessInfoParams",
    "UpdateCalendarEventParams",
    "UpdateChapterRequest",
    "UpdateClientParams",
    "UpdateCustomerFacingConfigParams",
    "UpdateEnvironmentVariableRequestValuesValue",
    "UpdateGroupSessionSeatsParams",
    "UpdateHolidayParams",
    "UpdateLocationParams",
    "UpdateOAuth2ClientCredsRequest",
    "UpdateOAuth2JwtRequest",
    "UpdateOAuth2JwtRequestAlgorithm",
    "UpdateOAuth2JwtRequestTokenResponseField",
    "UpdateOrderRequest",
    "UpdateOrderResponse",
    "UpdateProductParams",
    "UpdateProjectRequest",
    "UpdatePronunciationDictionariesRequest",
    "UpdateResponseUnitTestRequest",
    "UpdateServiceParams",
    "UpdateSimulationTestRequest",
    "UpdateStaffParams",
    "UpdateToolCallUnitTestRequest",
    "UpdateWorkspaceMemberResponseModel",
    "UpsertOrderItemRequest",
    "UpsertOrderItemResponse",
    "UrlAvatar",
    "UrlModel",
    "UrlSecretAuthResponse",
    "UsageAggregationInterval",
    "UsageCharactersResponseModel",
    "User",
    "UserAccessManagementActivityId",
    "UserFeedback",
    "UserFeedbackScore",
    "UserModel",
    "UserTranscriptPayload",
    "UserTypeId",
    "UsersSortBy",
    "UtteranceResponseModel",
    "VadConfig",
    "VadConfigWorkflowOverride",
    "ValidationError",
    "ValidationErrorLocItem",
    "Verbosity",
    "VerificationAttemptResponse",
    "VerifiedVoiceLanguageResponseModel",
    "VerifyPvcVoiceCaptchaResponseModel",
    "VideoAnalysis",
    "VideoAnalysisResult",
    "VideoAnalysisStatus",
    "VideoKeyMoment",
    "VideoSegment",
    "VideoSubject",
    "VisitedAgentRef",
    "Voice",
    "VoiceCategory",
    "VoiceDesignPreviewResponse",
    "VoiceDesignRequestModelModelId",
    "VoiceGenerationParameterOptionResponse",
    "VoiceGenerationParameterResponse",
    "VoiceMailDetectionResultSuccessModel",
    "VoicePreviewResponseModel",
    "VoiceResponseModelCategory",
    "VoiceResponseModelLabellingStatus",
    "VoiceResponseModelRecordingQuality",
    "VoiceResponseModelSafetyControl",
    "VoiceSample",
    "VoiceSamplePreviewResponseModel",
    "VoiceSampleVisualWaveformResponseModel",
    "VoiceSegment",
    "VoiceSettings",
    "VoiceSharingModerationCheckResponseModel",
    "VoiceSharingResponse",
    "VoiceSharingResponseModelCategory",
    "VoiceSharingState",
    "VoiceStatisticsResponseModel",
    "VoiceVerificationResponse",
    "VoicemailDetectionToolConfig",
    "VoicesGetSharedRequestCategory",
    "VoicesGetSharedRequestSort",
    "VoicesUpdateRequestLabels",
    "WebhookAuthMethodType",
    "WebhookEventType",
    "WebhookHmacSettings",
    "WebhookToolApiSchemaConfigInput",
    "WebhookToolApiSchemaConfigInputAuthConnection",
    "WebhookToolApiSchemaConfigInputContentType",
    "WebhookToolApiSchemaConfigInputMethod",
    "WebhookToolApiSchemaConfigInputRequestHeadersValue",
    "WebhookToolApiSchemaConfigOutput",
    "WebhookToolApiSchemaConfigOutputAuthConnection",
    "WebhookToolApiSchemaConfigOutputContentType",
    "WebhookToolApiSchemaConfigOutputMethod",
    "WebhookToolApiSchemaConfigOutputRequestHeadersValue",
    "WebhookToolConfigInput",
    "WebhookToolConfigOutput",
    "WebhookTranscriptFormat",
    "WebhookUsageType",
    "WebsocketTtsClientMessageMulti",
    "WebsocketTtsServerMessageMulti",
    "WhatsAppAuthResponse",
    "WhatsAppConversationInfo",
    "WhatsAppConversationInfoDirection",
    "WhatsAppOutboundCallResponse",
    "WhatsAppOutboundMessageResponse",
    "WhatsAppTemplateBodyComponentParams",
    "WhatsAppTemplateButtonComponentParams",
    "WhatsAppTemplateDocumentParam",
    "WhatsAppTemplateDocumentParamDetails",
    "WhatsAppTemplateHeaderComponentParams",
    "WhatsAppTemplateHeaderComponentParamsParametersItem",
    "WhatsAppTemplateHeaderComponentParamsParametersItem_Document",
    "WhatsAppTemplateHeaderComponentParamsParametersItem_Image",
    "WhatsAppTemplateHeaderComponentParamsParametersItem_Location",
    "WhatsAppTemplateHeaderComponentParamsParametersItem_Text",
    "WhatsAppTemplateImageParam",
    "WhatsAppTemplateImageParamDetails",
    "WhatsAppTemplateLocationParam",
    "WhatsAppTemplateLocationParamDetails",
    "WhatsAppTemplateTextParam",
    "WidgetConfig",
    "WidgetConfigInputAvatar",
    "WidgetConfigInputAvatar_Image",
    "WidgetConfigInputAvatar_Orb",
    "WidgetConfigInputAvatar_Url",
    "WidgetConfigInputSyntaxHighlightTheme",
    "WidgetConfigOutputAvatar",
    "WidgetConfigOutputAvatar_Image",
    "WidgetConfigOutputAvatar_Orb",
    "WidgetConfigOutputAvatar_Url",
    "WidgetConfigOutputSyntaxHighlightTheme",
    "WidgetConfigResponse",
    "WidgetConfigResponseModelAvatar",
    "WidgetConfigResponseModelAvatar_Image",
    "WidgetConfigResponseModelAvatar_Orb",
    "WidgetConfigResponseModelAvatar_Url",
    "WidgetConfigResponseModelSyntaxHighlightTheme",
    "WidgetEndFeedbackConfig",
    "WidgetEndFeedbackType",
    "WidgetExpandable",
    "WidgetFeedbackMode",
    "WidgetLanguagePreset",
    "WidgetLanguagePresetResponse",
    "WidgetPlacement",
    "WidgetStyles",
    "WidgetTermsTranslation",
    "WidgetTextContents",
    "WordTimestamp",
    "WorkflowEdgeModelInput",
    "WorkflowEdgeModelInputBackwardCondition",
    "WorkflowEdgeModelInputBackwardCondition_Expression",
    "WorkflowEdgeModelInputBackwardCondition_Llm",
    "WorkflowEdgeModelInputBackwardCondition_Result",
    "WorkflowEdgeModelInputBackwardCondition_Unconditional",
    "WorkflowEdgeModelInputForwardCondition",
    "WorkflowEdgeModelInputForwardCondition_Expression",
    "WorkflowEdgeModelInputForwardCondition_Llm",
    "WorkflowEdgeModelInputForwardCondition_Result",
    "WorkflowEdgeModelInputForwardCondition_Unconditional",
    "WorkflowEdgeModelOutput",
    "WorkflowEdgeModelOutputBackwardCondition",
    "WorkflowEdgeModelOutputBackwardCondition_Expression",
    "WorkflowEdgeModelOutputBackwardCondition_Llm",
    "WorkflowEdgeModelOutputBackwardCondition_Result",
    "WorkflowEdgeModelOutputBackwardCondition_Unconditional",
    "WorkflowEdgeModelOutputForwardCondition",
    "WorkflowEdgeModelOutputForwardCondition_Expression",
    "WorkflowEdgeModelOutputForwardCondition_Llm",
    "WorkflowEdgeModelOutputForwardCondition_Result",
    "WorkflowEdgeModelOutputForwardCondition_Unconditional",
    "WorkflowEndNodeModelInput",
    "WorkflowEndNodeModelOutput",
    "WorkflowExpressionConditionModelInput",
    "WorkflowExpressionConditionModelOutput",
    "WorkflowFeaturesUsageCommonModel",
    "WorkflowLlmConditionModelInput",
    "WorkflowLlmConditionModelOutput",
    "WorkflowOverrideAgentNodeModelInput",
    "WorkflowOverrideAgentNodeModelOutput",
    "WorkflowPhoneNumberNodeModelInput",
    "WorkflowPhoneNumberNodeModelInputCustomSipHeadersItem",
    "WorkflowPhoneNumberNodeModelInputCustomSipHeadersItem_Dynamic",
    "WorkflowPhoneNumberNodeModelInputCustomSipHeadersItem_Static",
    "WorkflowPhoneNumberNodeModelInputPostDialDigits",
    "WorkflowPhoneNumberNodeModelInputPostDialDigits_Dynamic",
    "WorkflowPhoneNumberNodeModelInputPostDialDigits_Static",
    "WorkflowPhoneNumberNodeModelInputTransferDestination",
    "WorkflowPhoneNumberNodeModelInputTransferDestination_Phone",
    "WorkflowPhoneNumberNodeModelInputTransferDestination_PhoneDynamicVariable",
    "WorkflowPhoneNumberNodeModelInputTransferDestination_SipUri",
    "WorkflowPhoneNumberNodeModelInputTransferDestination_SipUriDynamicVariable",
    "WorkflowPhoneNumberNodeModelOutput",
    "WorkflowPhoneNumberNodeModelOutputCustomSipHeadersItem",
    "WorkflowPhoneNumberNodeModelOutputCustomSipHeadersItem_Dynamic",
    "WorkflowPhoneNumberNodeModelOutputCustomSipHeadersItem_Static",
    "WorkflowPhoneNumberNodeModelOutputPostDialDigits",
    "WorkflowPhoneNumberNodeModelOutputPostDialDigits_Dynamic",
    "WorkflowPhoneNumberNodeModelOutputPostDialDigits_Static",
    "WorkflowPhoneNumberNodeModelOutputTransferDestination",
    "WorkflowPhoneNumberNodeModelOutputTransferDestination_Phone",
    "WorkflowPhoneNumberNodeModelOutputTransferDestination_PhoneDynamicVariable",
    "WorkflowPhoneNumberNodeModelOutputTransferDestination_SipUri",
    "WorkflowPhoneNumberNodeModelOutputTransferDestination_SipUriDynamicVariable",
    "WorkflowResultConditionModelInput",
    "WorkflowResultConditionModelOutput",
    "WorkflowStandaloneAgentNodeModelInput",
    "WorkflowStandaloneAgentNodeModelOutput",
    "WorkflowStartNodeModelInput",
    "WorkflowStartNodeModelOutput",
    "WorkflowToolEdgeStepModel",
    "WorkflowToolLocator",
    "WorkflowToolMaxIterationsExceededStepModel",
    "WorkflowToolNestedToolsStepModelInput",
    "WorkflowToolNestedToolsStepModelInputResultsItem",
    "WorkflowToolNestedToolsStepModelOutput",
    "WorkflowToolNestedToolsStepModelOutputResultsItem",
    "WorkflowToolNodeModelInput",
    "WorkflowToolNodeModelOutput",
    "WorkflowToolResponseModelInput",
    "WorkflowToolResponseModelInputStepsItem",
    "WorkflowToolResponseModelInputStepsItem_Edge",
    "WorkflowToolResponseModelInputStepsItem_MaxIterationsExceeded",
    "WorkflowToolResponseModelInputStepsItem_NestedTools",
    "WorkflowToolResponseModelOutput",
    "WorkflowToolResponseModelOutputStepsItem",
    "WorkflowToolResponseModelOutputStepsItem_Edge",
    "WorkflowToolResponseModelOutputStepsItem_MaxIterationsExceeded",
    "WorkflowToolResponseModelOutputStepsItem_NestedTools",
    "WorkflowUnconditionalModelInput",
    "WorkflowUnconditionalModelOutput",
    "WorkspaceAnalyticsQueryResponseModel",
    "WorkspaceAnalyticsQueryResponseModelColumnTypesItem",
    "WorkspaceAnalyticsQueryResponseModelRowsItemItem",
    "WorkspaceApiKeyListResponseModel",
    "WorkspaceApiKeyResponseModel",
    "WorkspaceAuditLogEntryResponse",
    "WorkspaceAuditLogEntryResponseActivityId",
    "WorkspaceAuditLogsPageResponse",
    "WorkspaceBatchCallsResponse",
    "WorkspaceCreateApiKeyResponseModel",
    "WorkspaceCreateWebhookResponseModel",
    "WorkspaceGroupByNameResponseModel",
    "WorkspaceGroupPermission",
    "WorkspaceGroupResponseModel",
    "WorkspaceGroupResponseModelGroupPvcLimit",
    "WorkspaceGroupResponseModelGroupUsageLimit",
    "WorkspaceResourceType",
    "WorkspaceServiceAccountListResponseModel",
    "WorkspaceServiceAccountResponseModel",
    "WorkspaceWebhookListResponseModel",
    "WorkspaceWebhookResponseModel",
    "WorkspaceWebhookUsageResponseModel",
    "__version__",
    "audio_isolation",
    "audio_native",
    "conversational_ai",
    "dubbing",
    "environment_variables",
    "forced_alignment",
    "history",
    "models",
    "music",
    "play",
    "productions",
    "pronunciation_dictionaries",
    "samples",
    "save",
    "service_accounts",
    "speech_engine",
    "speech_engine_upstream",
    "speech_to_speech",
    "speech_to_text",
    "stream",
    "studio",
    "text_to_dialogue",
    "text_to_sound_effects",
    "text_to_speech",
    "text_to_voice",
    "tokens",
    "usage",
    "user",
    "v_1_realtime_translation",
    "v_1_speech_to_text_realtime",
    "v_1_text_to_dialogue_stream_input",
    "v_1_text_to_speech_voice_id_multi_stream_input",
    "v_1_text_to_speech_voice_id_stream_input",
    "voices",
    "webhooks",
    "workspace",
    "workspaces",
]
